/* Generated by Cython 0.25.2 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_25_2"
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x03030000 || (PY_MAJOR_VERSION == 2 && PY_VERSION_HEX >= 0x02070000)
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_FASTCALL
  #define METH_FASTCALL 0x80
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject **args,
                                              Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE___javabridge
#define __PYX_HAVE_API___javabridge
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#include "jni.h"
#include "mac_javabridge_utils.h"
#include "stdlib.h"
#include "string.h"
#include "pythread.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER) && defined (_M_X64)
    #define __Pyx_sst_abs(value) _abs64(value)
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "_javabridge.pyx",
  "__init__.pxd",
  "type.pxd",
  "bool.pxd",
  "complex.pxd",
};
/* BufferFormatStructs.proto */
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":725
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":726
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":727
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":728
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":732
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":733
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":734
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":735
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":739
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":740
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":749
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":750
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":751
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":753
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":754
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":755
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":757
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":758
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":760
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":761
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":762
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);


/*--- Type declarations ---*/
struct __pyx_obj_11_javabridge_JB_Object;
struct __pyx_obj_11_javabridge_JB_Class;
struct __pyx_obj_11_javabridge___JB_MethodID;
struct __pyx_obj_11_javabridge___JB_FieldID;
struct __pyx_obj_11_javabridge_JB_VM;
struct __pyx_obj_11_javabridge_JB_Env;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":764
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":765
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":766
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":768
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;

/* "_javabridge.pyx":465
 *             pass
 * 
 * cdef class JB_Object:             # <<<<<<<<<<<<<<
 *     '''Represents a Java object.'''
 *     cdef:
 */
struct __pyx_obj_11_javabridge_JB_Object {
  PyObject_HEAD
  jobject o;
  PyObject *gc_collect;
};


/* "_javabridge.pyx":494
 *         return str(<int>(self.o))
 * 
 * cdef class JB_Class:             # <<<<<<<<<<<<<<
 *     '''A Java class'''
 *     cdef:
 */
struct __pyx_obj_11_javabridge_JB_Class {
  PyObject_HEAD
  jclass c;
};


/* "_javabridge.pyx":503
 *         return "<Java class at 0x%x>"%<int>(self.c)
 * 
 * cdef class __JB_MethodID:             # <<<<<<<<<<<<<<
 *     '''A method ID as returned by get_method_id'''
 *     cdef:
 */
struct __pyx_obj_11_javabridge___JB_MethodID {
  PyObject_HEAD
  jmethodID id;
  PyObject *sig;
  PyObject *is_static;
};


/* "_javabridge.pyx":517
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))
 * 
 * cdef class __JB_FieldID:             # <<<<<<<<<<<<<<
 *     '''A field ID as returned by get_field_id'''
 *     cdef:
 */
struct __pyx_obj_11_javabridge___JB_FieldID {
  PyObject_HEAD
  jfieldID id;
  PyObject *sig;
  PyObject *is_static;
};


/* "_javabridge.pyx":603
 *                          (len(args), orig_sig))
 * 
 * cdef class JB_VM:             # <<<<<<<<<<<<<<
 *     '''Represents the Java virtual machine'''
 *     cdef JavaVM *vm
 */
struct __pyx_obj_11_javabridge_JB_VM {
  PyObject_HEAD
  JavaVM *vm;
};


/* "_javabridge.pyx":738
 *             self.vm = NULL
 * 
 * cdef class JB_Env:             # <<<<<<<<<<<<<<
 *     '''
 *     Represents the Java VM and the Java execution environment as
 */
struct __pyx_obj_11_javabridge_JB_Env {
  PyObject_HEAD
  JNIEnv *env;
};


/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    ((likely((cfunc)->func)) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
             ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
              (PY_VERSION_HEX >= 0x030600B1 && (cfunc)->flag == METH_FASTCALL ?  (*(__Pyx_PyCFunctionFast)(cfunc)->func)(self, &PyTuple_GET_ITEM(__pyx_empty_tuple, 0), 0, NULL) :\
                __Pyx__CallUnboundCMethod0(cfunc, self))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = PyThreadState_GET();
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* UnicodeAsUCS4.proto */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* object_ord.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Ord(c)\
    (likely(PyUnicode_Check(c)) ? (long)__Pyx_PyUnicode_AsPy_UCS4(c) : __Pyx__PyObject_Ord(c))
#else
#define __Pyx_PyObject_Ord(c) __Pyx__PyObject_Ord(c)
#endif
static long __Pyx__PyObject_Ord(PyObject* c);

/* pyobject_as_double.proto */
static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyInt_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?\
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* ArgTypeTest.proto */
static CYTHON_INLINE int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact);

/* None.proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* None.proto */
static CYTHON_INLINE long __Pyx_mod_long(long, long);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_EqObjC(op1, op2, intval, inplace)\
    PyObject_RichCompare(op1, op2, Py_EQ)
    #endif

/* None.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t, Py_ssize_t);

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* BufferFormatCheck.proto */
static CYTHON_INLINE int  __Pyx_GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type); // PROTO

/* BufferFallbackError.proto */
static void __Pyx_RaiseBufferFallbackError(void);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* None.proto */
static Py_ssize_t __Pyx_zeros[] = {0, 0, 0, 0, 0, 0, 0, 0};
static Py_ssize_t __Pyx_minusones[] = {-1, -1, -1, -1, -1, -1, -1, -1};

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jint(jint value);

/* Print.proto */
static int __Pyx_Print(PyObject*, PyObject *, int);
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jbyte(jbyte value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jchar(jchar value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jshort(jshort value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jlong(jlong value);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE jbyte __Pyx_PyInt_As_jbyte(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE jshort __Pyx_PyInt_As_jshort(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE jint __Pyx_PyInt_As_jint(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE jlong __Pyx_PyInt_As_jlong(PyObject *);

/* PrintOne.proto */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* PyIdentifierFromString.proto */
#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

/* ModuleImport.proto */
static PyObject *__Pyx_ImportModule(const char *name);

/* TypeImport.proto */
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython.version' */

/* Module declarations from 'cpython.exc' */

/* Module declarations from 'cpython.module' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'cpython.tuple' */

/* Module declarations from 'cpython.list' */

/* Module declarations from 'cpython.sequence' */

/* Module declarations from 'cpython.mapping' */

/* Module declarations from 'cpython.iterator' */

/* Module declarations from 'cpython.number' */

/* Module declarations from 'cpython.int' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.bool' */
static PyTypeObject *__pyx_ptype_7cpython_4bool_bool = 0;

/* Module declarations from 'cpython.long' */

/* Module declarations from 'cpython.float' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.complex' */
static PyTypeObject *__pyx_ptype_7cpython_7complex_complex = 0;

/* Module declarations from 'cpython.string' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.instance' */

/* Module declarations from 'cpython.function' */

/* Module declarations from 'cpython.method' */

/* Module declarations from 'cpython.weakref' */

/* Module declarations from 'cpython.getargs' */

/* Module declarations from 'cpython.pythread' */

/* Module declarations from 'cpython.pystate' */

/* Module declarations from 'cpython.cobject' */

/* Module declarations from 'cpython.oldbuffer' */

/* Module declarations from 'cpython.set' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.pycapsule' */

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'cython' */

/* Module declarations from '_javabridge_osspecific' */

/* Module declarations from '_javabridge' */
static PyTypeObject *__pyx_ptype_11_javabridge_ndarray = 0;
static PyTypeObject *__pyx_ptype_11_javabridge_JB_Object = 0;
static PyTypeObject *__pyx_ptype_11_javabridge_JB_Class = 0;
static PyTypeObject *__pyx_ptype_11_javabridge___JB_MethodID = 0;
static PyTypeObject *__pyx_ptype_11_javabridge___JB_FieldID = 0;
static PyTypeObject *__pyx_ptype_11_javabridge_JB_VM = 0;
static PyTypeObject *__pyx_ptype_11_javabridge_JB_Env = 0;
static PyObject *__pyx_f_11_javabridge_fill_values(PyObject *, PyObject *, jvalue **); /*proto*/
static PyObject *__pyx_f_11_javabridge_make_jb_object(struct __pyx_obj_11_javabridge_JB_Env *, jobject); /*proto*/
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t = { "uint8_t", NULL, sizeof(__pyx_t_5numpy_uint8_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_uint8_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_uint8_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t = { "int16_t", NULL, sizeof(__pyx_t_5numpy_int16_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int16_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int16_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t = { "int32_t", NULL, sizeof(__pyx_t_5numpy_int32_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int32_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int32_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t = { "int64_t", NULL, sizeof(__pyx_t_5numpy_int64_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int64_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int64_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t = { "float32_t", NULL, sizeof(__pyx_t_5numpy_float32_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t = { "float64_t", NULL, sizeof(__pyx_t_5numpy_float64_t), { 0 }, 0, 'R', 0, 0 };
#define __Pyx_MODULE_NAME "_javabridge"
int __pyx_module_is_main__javabridge = 0;

/* Implementation of '_javabridge' */
static PyObject *__pyx_builtin_chr;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_ImportError;
static const char __pyx_k_B[] = "B";
static const char __pyx_k_C[] = "C";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_F[] = "F";
static const char __pyx_k_I[] = "I";
static const char __pyx_k_J[] = "J";
static const char __pyx_k_L[] = "L";
static const char __pyx_k_S[] = "S";
static const char __pyx_k_V[] = "V";
static const char __pyx_k_Z[] = "Z";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_v[] = "v";
static const char __pyx_k__6[] = "";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_vm[] = "__vm";
static const char __pyx_k__15[] = "[";
static const char __pyx_k__16[] = ";";
static const char __pyx_k__37[] = "(";
static const char __pyx_k__38[] = ")";
static const char __pyx_k_chr[] = "chr";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_env[] = "env";
static const char __pyx_k_jbo[] = "jbo";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_len[] = "len";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_set[] = "set";
static const char __pyx_k_sig[] = "sig";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_reap[] = "reap";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_vm_2[] = "vm";
static const char __pyx_k_wait[] = "wait";
static const char __pyx_k_Event[] = "Event";
static const char __pyx_k_bool8[] = "bool8";
static const char __pyx_k_clear[] = "clear";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_field[] = "field";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_int16[] = "int16";
static const char __pyx_k_int32[] = "int32";
static const char __pyx_k_int64[] = "int64";
static const char __pyx_k_klass[] = "klass";
static const char __pyx_k_local[] = "local";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_shape[] = "shape";
static const char __pyx_k_uint8[] = "uint8";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_astype[] = "astype";
static const char __pyx_k_detach[] = "detach";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_get_vm[] = "get_vm";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_method[] = "method";
static const char __pyx_k_set_vm[] = "set_vm";
static const char __pyx_k_to_die[] = "to_die";
static const char __pyx_k_unichr[] = "unichr";
static const char __pyx_k_utf_16[] = "utf-16";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_float32[] = "float32";
static const char __pyx_k_float64[] = "float64";
static const char __pyx_k_get_env[] = "get_env";
static const char __pyx_k_new_env[] = "new_env";
static const char __pyx_k_old_env[] = "old_env";
static const char __pyx_k_options[] = "options";
static const char __pyx_k_set_env[] = "set_env";
static const char __pyx_k_timeout[] = "timeout";
static const char __pyx_k_envstack[] = "envstack";
static const char __pyx_k_jni_exit[] = "jni_exit";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_env_stack[] = "env_stack";
static const char __pyx_k_is_active[] = "is_active";
static const char __pyx_k_is_static[] = "is_static";
static const char __pyx_k_jb_attach[] = "jb_attach";
static const char __pyx_k_jb_detach[] = "jb_detach";
static const char __pyx_k_jni_enter[] = "jni_enter";
static const char __pyx_k_jvm_enter[] = "jvm_enter";
static const char __pyx_k_threading[] = "threading";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_class_name[] = "class_name";
static const char __pyx_k_javabridge[] = "_javabridge";
static const char __pyx_k_wake_event[] = "__wake_event";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_dead_objects[] = "__dead_objects";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_JB_Env_at_0x_x[] = "<JB_Env at 0x%x>";
static const char __pyx_k_path_to_libjli[] = "path_to_libjli";
static const char __pyx_k_path_to_libjvm[] = "path_to_libjvm";
static const char __pyx_k_set_wake_event[] = "set_wake_event";
static const char __pyx_k_Bad_signature_s[] = "Bad signature: %s";
static const char __pyx_k_dealloc_jobject[] = "dealloc_jobject";
static const char __pyx_k_attach_as_daemon[] = "attach_as_daemon";
static const char __pyx_k_get_thread_local[] = "get_thread_local";
static const char __pyx_k_set_thread_local[] = "set_thread_local";
static const char __pyx_k_thread_local_env[] = "__thread_local_env";
static const char __pyx_k_mac_poll_run_loop[] = "mac_poll_run_loop";
static const char __pyx_k_mac_run_loop_init[] = "mac_run_loop_init";
static const char __pyx_k_mac_stop_run_loop[] = "mac_stop_run_loop";
static const char __pyx_k_Java_class_at_0x_x[] = "<Java class at 0x%x>";
static const char __pyx_k_mac_enter_run_loop[] = "mac_enter_run_loop";
static const char __pyx_k_mac_is_main_thread[] = "mac_is_main_thread";
static const char __pyx_k_mac_reset_run_loop[] = "mac_reset_run_loop";
static const char __pyx_k_Failed_to_get_class[] = "Failed to get class ";
static const char __pyx_k_Java_object_at_0x_x[] = "<Java object at 0x%x>";
static const char __pyx_k_wait_for_wake_event[] = "wait_for_wake_event";
static const char __pyx_k_Unhandled_signature_s[] = "Unhandled signature: %s";
static const char __pyx_k_s_is_not_a_Java_object[] = "%s is not a Java object";
static const char __pyx_k_Bad_function_signature_s[] = "Bad function signature: %s";
static const char __pyx_k_Failed_to_allocate_string[] = "Failed to allocate string";
static const char __pyx_k_ndarray_is_not_C_contiguous[] = "ndarray is not C contiguous";
static const char __pyx_k_Java_field_with_sig_s_at_0x_x[] = "<Java field with sig=%s at 0x%x>";
static const char __pyx_k_Java_method_with_sig_s_at_0x_x[] = "<Java method with sig=%s at 0x%x>";
static const char __pyx_k_of_arguments_d_in_call_did_not[] = "# of arguments (%d) in call did not match signature (%s)";
static const char __pyx_k_Argument_must_be_a_jobject_in_a[] = "Argument must be a jobject in a capsule";
static const char __pyx_k_Failed_to_allocate_double_array[] = "Failed to allocate double array of size %d";
static const char __pyx_k_Failed_to_allocate_int_array_of[] = "Failed to allocate int array of size %d";
static const char __pyx_k_Failed_to_allocate_object_array[] = "Failed to allocate object array of size %d";
static const char __pyx_k_Failed_to_create_Java_VM_Return[] = "Failed to create Java VM. Return code = %d";
static const char __pyx_k_Unhandled_return_type_Signature[] = "Unhandled return type. Signature = %s";
static const char __pyx_k_home_leek_projects_leekamentsky[] = "/home/leek/projects/leekamentsky/python-javabridge/_javabridge.pyx";
static const char __pyx_k_javabridge_pyx_low_level_interf[] = "_javabridge.pyx - low-level interface to the JVM\n\npython-javabridge is licensed under the BSD license.  See the\naccompanying file LICENSE for details.\n\nCopyright (c) 2003-2009 Massachusetts Institute of Technology\nCopyright (c) 2009-2013 Broad Institute\nAll rights reserved.\n\n";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_unknown_dtype_code_in_numpy_pxd[] = "unknown dtype code in numpy.pxd (%d)";
static const char __pyx_k_Capsule_did_not_contain_a_jobjec[] = "Capsule did not contain a jobject";
static const char __pyx_k_Class_None_on_call_to_get_method[] = "Class = None on call to get_method_id";
static const char __pyx_k_Failed_to_allocate_JavaVMInitArg[] = "Failed to allocate JavaVMInitArgs";
static const char __pyx_k_Failed_to_allocate_byte_array_of[] = "Failed to allocate byte array of size %d";
static const char __pyx_k_Failed_to_allocate_float_array_o[] = "Failed to allocate float array of size %d";
static const char __pyx_k_Failed_to_allocate_long_array_of[] = "Failed to allocate long array of size %d";
static const char __pyx_k_Failed_to_allocate_short_array_o[] = "Failed to allocate short array of size %d";
static const char __pyx_k_Failed_to_attach_to_current_thre[] = "Failed to attach to current thread. Return code = %d";
static const char __pyx_k_Failed_to_make_new_global_refere[] = "Failed to make new global reference";
static const char __pyx_k_Format_string_allocated_too_shor[] = "Format string allocated too short, see comment in numpy.pxd";
static const char __pyx_k_Method_ID_is_None_check_your_met[] = "Method ID is None - check your method ID call";
static const char __pyx_k_Non_native_byte_order_not_suppor[] = "Non-native byte order not supported";
static const char __pyx_k_Too_few_arguments_d_for_signatur[] = "Too few arguments (%d) for signature (%s)";
static const char __pyx_k_call_method_called_with_a_static[] = "call_method called with a static method. Use call_static_method instead";
static const char __pyx_k_ndarray_is_not_Fortran_contiguou[] = "ndarray is not Fortran contiguous";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_set_env_called_with_non_environm[] = "set_env called with non-environment capsule";
static const char __pyx_k_set_env_called_with_something_ot[] = "set_env called with something other than a wrapped environment";
static const char __pyx_k_set_vm_called_with_non_environme[] = "set_vm called with non-environment capsule";
static const char __pyx_k_set_vm_called_with_something_oth[] = "set_vm called with something other than a wrapped environment";
static const char __pyx_k_static_call_method_called_with_a[] = "static_call_method called with an object method. Use call_method instead";
static const char __pyx_k_Format_string_allocated_too_shor_2[] = "Format string allocated too short.";
static PyObject *__pyx_kp_s_Argument_must_be_a_jobject_in_a;
static PyObject *__pyx_n_s_B;
static PyObject *__pyx_kp_s_Bad_function_signature_s;
static PyObject *__pyx_kp_s_Bad_signature_s;
static PyObject *__pyx_n_s_C;
static PyObject *__pyx_kp_s_Capsule_did_not_contain_a_jobjec;
static PyObject *__pyx_kp_s_Class_None_on_call_to_get_method;
static PyObject *__pyx_n_s_D;
static PyObject *__pyx_n_s_Event;
static PyObject *__pyx_n_s_F;
static PyObject *__pyx_kp_s_Failed_to_allocate_JavaVMInitArg;
static PyObject *__pyx_kp_s_Failed_to_allocate_byte_array_of;
static PyObject *__pyx_kp_s_Failed_to_allocate_double_array;
static PyObject *__pyx_kp_s_Failed_to_allocate_float_array_o;
static PyObject *__pyx_kp_s_Failed_to_allocate_int_array_of;
static PyObject *__pyx_kp_s_Failed_to_allocate_long_array_of;
static PyObject *__pyx_kp_s_Failed_to_allocate_object_array;
static PyObject *__pyx_kp_s_Failed_to_allocate_short_array_o;
static PyObject *__pyx_kp_s_Failed_to_allocate_string;
static PyObject *__pyx_kp_s_Failed_to_attach_to_current_thre;
static PyObject *__pyx_kp_s_Failed_to_create_Java_VM_Return;
static PyObject *__pyx_kp_s_Failed_to_get_class;
static PyObject *__pyx_kp_s_Failed_to_make_new_global_refere;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor_2;
static PyObject *__pyx_n_s_I;
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_n_s_IndexError;
static PyObject *__pyx_n_s_J;
static PyObject *__pyx_kp_s_JB_Env_at_0x_x;
static PyObject *__pyx_kp_s_Java_class_at_0x_x;
static PyObject *__pyx_kp_s_Java_field_with_sig_s_at_0x_x;
static PyObject *__pyx_kp_s_Java_method_with_sig_s_at_0x_x;
static PyObject *__pyx_kp_s_Java_object_at_0x_x;
static PyObject *__pyx_n_s_L;
static PyObject *__pyx_n_s_MemoryError;
static PyObject *__pyx_kp_s_Method_ID_is_None_check_your_met;
static PyObject *__pyx_kp_u_Non_native_byte_order_not_suppor;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_n_s_S;
static PyObject *__pyx_kp_s_Too_few_arguments_d_for_signatur;
static PyObject *__pyx_kp_s_Unhandled_return_type_Signature;
static PyObject *__pyx_kp_s_Unhandled_signature_s;
static PyObject *__pyx_n_s_V;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_Z;
static PyObject *__pyx_kp_s__15;
static PyObject *__pyx_kp_s__16;
static PyObject *__pyx_kp_s__37;
static PyObject *__pyx_kp_s__38;
static PyObject *__pyx_kp_s__6;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_astype;
static PyObject *__pyx_n_s_attach_as_daemon;
static PyObject *__pyx_n_s_bool8;
static PyObject *__pyx_n_s_c;
static PyObject *__pyx_kp_s_call_method_called_with_a_static;
static PyObject *__pyx_n_s_chr;
static PyObject *__pyx_n_s_class_name;
static PyObject *__pyx_n_s_clear;
static PyObject *__pyx_n_s_dead_objects;
static PyObject *__pyx_n_s_dealloc_jobject;
static PyObject *__pyx_n_s_default;
static PyObject *__pyx_n_s_detach;
static PyObject *__pyx_n_s_dtype;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_n_s_enumerate;
static PyObject *__pyx_n_s_env;
static PyObject *__pyx_n_s_env_stack;
static PyObject *__pyx_n_s_envstack;
static PyObject *__pyx_n_s_field;
static PyObject *__pyx_n_s_file;
static PyObject *__pyx_n_s_find;
static PyObject *__pyx_n_s_float32;
static PyObject *__pyx_n_s_float64;
static PyObject *__pyx_n_s_get_env;
static PyObject *__pyx_n_s_get_thread_local;
static PyObject *__pyx_n_s_get_vm;
static PyObject *__pyx_kp_s_home_leek_projects_leekamentsky;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_int16;
static PyObject *__pyx_n_s_int32;
static PyObject *__pyx_n_s_int64;
static PyObject *__pyx_n_s_is_active;
static PyObject *__pyx_n_s_is_static;
static PyObject *__pyx_n_s_javabridge;
static PyObject *__pyx_n_s_jb_attach;
static PyObject *__pyx_n_s_jb_detach;
static PyObject *__pyx_n_s_jbo;
static PyObject *__pyx_n_s_jni_enter;
static PyObject *__pyx_n_s_jni_exit;
static PyObject *__pyx_n_s_jvm_enter;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_klass;
static PyObject *__pyx_n_s_len;
static PyObject *__pyx_n_s_local;
static PyObject *__pyx_n_s_m;
static PyObject *__pyx_n_s_mac_enter_run_loop;
static PyObject *__pyx_n_s_mac_is_main_thread;
static PyObject *__pyx_n_s_mac_poll_run_loop;
static PyObject *__pyx_n_s_mac_reset_run_loop;
static PyObject *__pyx_n_s_mac_run_loop_init;
static PyObject *__pyx_n_s_mac_stop_run_loop;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_method;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_u_ndarray_is_not_C_contiguous;
static PyObject *__pyx_kp_u_ndarray_is_not_Fortran_contiguou;
static PyObject *__pyx_n_s_new_env;
static PyObject *__pyx_n_s_np;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_kp_s_numpy_core_multiarray_failed_to;
static PyObject *__pyx_kp_s_numpy_core_umath_failed_to_impor;
static PyObject *__pyx_n_s_o;
static PyObject *__pyx_kp_s_of_arguments_d_in_call_did_not;
static PyObject *__pyx_n_s_old_env;
static PyObject *__pyx_n_s_options;
static PyObject *__pyx_n_s_path_to_libjli;
static PyObject *__pyx_n_s_path_to_libjvm;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_reap;
static PyObject *__pyx_kp_s_s_is_not_a_Java_object;
static PyObject *__pyx_n_s_set;
static PyObject *__pyx_n_s_set_env;
static PyObject *__pyx_kp_s_set_env_called_with_non_environm;
static PyObject *__pyx_kp_s_set_env_called_with_something_ot;
static PyObject *__pyx_n_s_set_thread_local;
static PyObject *__pyx_n_s_set_vm;
static PyObject *__pyx_kp_s_set_vm_called_with_non_environme;
static PyObject *__pyx_kp_s_set_vm_called_with_something_oth;
static PyObject *__pyx_n_s_set_wake_event;
static PyObject *__pyx_n_s_shape;
static PyObject *__pyx_n_s_sig;
static PyObject *__pyx_kp_s_static_call_method_called_with_a;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_thread_local_env;
static PyObject *__pyx_n_s_threading;
static PyObject *__pyx_n_s_timeout;
static PyObject *__pyx_n_s_to_die;
static PyObject *__pyx_n_s_uint8;
static PyObject *__pyx_n_s_unichr;
static PyObject *__pyx_kp_u_unknown_dtype_code_in_numpy_pxd;
static PyObject *__pyx_kp_s_utf_16;
static PyObject *__pyx_kp_s_utf_8;
static PyObject *__pyx_n_s_v;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_version_info;
static PyObject *__pyx_n_s_vm;
static PyObject *__pyx_n_s_vm_2;
static PyObject *__pyx_n_s_wait;
static PyObject *__pyx_n_s_wait_for_wake_event;
static PyObject *__pyx_n_s_wake_event;
static PyObject *__pyx_n_s_zeros;
static PyObject *__pyx_pf_11_javabridge_mac_run_loop_init(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_2mac_reset_run_loop(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_4mac_enter_run_loop(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6mac_poll_run_loop(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_11_javabridge_8mac_stop_run_loop(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_10mac_is_main_thread(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_12wait_for_wake_event(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_14set_wake_event(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_16get_vm(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_18get_thread_local(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_11_javabridge_20set_thread_local(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_22get_env(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_24jb_attach(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_26jb_detach(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_28jni_enter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_env); /* proto */
static PyObject *__pyx_pf_11_javabridge_30jni_exit(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_32jvm_enter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_vm); /* proto */
static PyObject *__pyx_pf_11_javabridge_34reap(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static int __pyx_pf_11_javabridge_9JB_Object___cinit__(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_9JB_Object_2__repr__(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static void __pyx_pf_11_javabridge_9JB_Object_4__dealloc__(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_9JB_Object_6addr(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static int __pyx_pf_11_javabridge_8JB_Class___cinit__(struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_8JB_Class_2__repr__(struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_self); /* proto */
static int __pyx_pf_11_javabridge_13__JB_MethodID___cinit__(struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_13__JB_MethodID_2__repr__(struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_self); /* proto */
static int __pyx_pf_11_javabridge_12__JB_FieldID___cinit__(struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_12__JB_FieldID_2__repr__(struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_set_vm(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_capsule); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_2is_active(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_4create(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_6create_mac(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options, PyObject *__pyx_v_class_name, PyObject *__pyx_v_path_to_libjvm, PyObject *__pyx_v_path_to_libjli); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_8attach(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_10attach_as_daemon(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_12detach(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_5JB_VM_14destroy(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static int __pyx_pf_11_javabridge_6JB_Env___init__(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_2__repr__(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_4set_env(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_capsule); /* proto */
static void __pyx_pf_11_javabridge_6JB_Env_6__dealloc__(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_8dealloc_jobject(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_10get_version(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_12find_class(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_14get_object_class(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_16is_instance_of(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_18exception_occurred(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_20exception_describe(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_22exception_clear(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_24get_method_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_26get_static_method_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_28from_reflected_method(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_method, char *__pyx_v_sig, PyObject *__pyx_v_is_static); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_30call_method(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_32call_static_method(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_34get_field_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_36get_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_38get_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_40get_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_42get_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_44get_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_46get_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_48get_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_50get_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_52get_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_54set_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_56set_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_58set_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_60set_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_62set_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_64set_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_66set_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_68set_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_70set_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_72get_static_field_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_74get_static_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_76get_static_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_78get_static_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_80get_static_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_82get_static_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_84get_static_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_86get_static_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_88get_static_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_90get_static_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_92set_static_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_94set_static_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_96set_static_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_98set_static_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_100set_static_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_102set_static_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_104set_static_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_106set_static_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_108set_static_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_110set_static_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_112new_object(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_114new_string(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_u); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_116new_string_utf(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_118get_string(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_120get_string_utf(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_122get_array_length(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_124get_boolean_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_126get_byte_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_128get_short_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_130get_int_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_132get_long_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_134get_float_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_136get_double_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_138get_object_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_140make_boolean_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_142make_byte_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_144make_short_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_146make_int_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_148make_long_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_150make_float_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_152make_double_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_154make_object_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, int __pyx_v_len, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_klass); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_156set_object_array_element(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo, int __pyx_v_index, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_v); /* proto */
static PyObject *__pyx_pf_11_javabridge_6JB_Env_158make_jb_object(CYTHON_UNUSED struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_pCapsule); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_tp_new_11_javabridge_JB_Object(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11_javabridge_JB_Class(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11_javabridge___JB_MethodID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11_javabridge___JB_FieldID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11_javabridge_JB_VM(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11_javabridge_JB_Env(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop = {0, &__pyx_n_s_pop, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_slice__7;
static PyObject *__pyx_slice__8;
static PyObject *__pyx_slice__9;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_slice__10;
static PyObject *__pyx_slice__11;
static PyObject *__pyx_slice__12;
static PyObject *__pyx_slice__13;
static PyObject *__pyx_slice__14;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__88;
static PyObject *__pyx_codeobj__65;
static PyObject *__pyx_codeobj__66;
static PyObject *__pyx_codeobj__67;
static PyObject *__pyx_codeobj__69;
static PyObject *__pyx_codeobj__70;
static PyObject *__pyx_codeobj__71;
static PyObject *__pyx_codeobj__72;
static PyObject *__pyx_codeobj__73;
static PyObject *__pyx_codeobj__74;
static PyObject *__pyx_codeobj__76;
static PyObject *__pyx_codeobj__78;
static PyObject *__pyx_codeobj__79;
static PyObject *__pyx_codeobj__80;
static PyObject *__pyx_codeobj__81;
static PyObject *__pyx_codeobj__83;
static PyObject *__pyx_codeobj__85;
static PyObject *__pyx_codeobj__87;
static PyObject *__pyx_codeobj__89;

/* "_javabridge.pyx":319
 *     int CreateJavaVM(JavaVM **pvm, void **pEnv, void *args) nogil
 * 
 * def mac_run_loop_init():             # <<<<<<<<<<<<<<
 *     MacRunLoopInit()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_1mac_run_loop_init(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_11_javabridge_1mac_run_loop_init = {"mac_run_loop_init", (PyCFunction)__pyx_pw_11_javabridge_1mac_run_loop_init, METH_NOARGS, 0};
static PyObject *__pyx_pw_11_javabridge_1mac_run_loop_init(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_run_loop_init (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_mac_run_loop_init(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_mac_run_loop_init(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_run_loop_init", 0);

  /* "_javabridge.pyx":320
 * 
 * def mac_run_loop_init():
 *     MacRunLoopInit()             # <<<<<<<<<<<<<<
 * 
 * def mac_reset_run_loop():
 */
  MacRunLoopInit();

  /* "_javabridge.pyx":319
 *     int CreateJavaVM(JavaVM **pvm, void **pEnv, void *args) nogil
 * 
 * def mac_run_loop_init():             # <<<<<<<<<<<<<<
 *     MacRunLoopInit()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":322
 *     MacRunLoopInit()
 * 
 * def mac_reset_run_loop():             # <<<<<<<<<<<<<<
 *     '''Reset the run loop's internal state so that it's ready to run
 *     '''
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_3mac_reset_run_loop(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_2mac_reset_run_loop[] = "Reset the run loop's internal state so that it's ready to run\n    ";
static PyMethodDef __pyx_mdef_11_javabridge_3mac_reset_run_loop = {"mac_reset_run_loop", (PyCFunction)__pyx_pw_11_javabridge_3mac_reset_run_loop, METH_NOARGS, __pyx_doc_11_javabridge_2mac_reset_run_loop};
static PyObject *__pyx_pw_11_javabridge_3mac_reset_run_loop(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_reset_run_loop (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_2mac_reset_run_loop(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_2mac_reset_run_loop(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_reset_run_loop", 0);

  /* "_javabridge.pyx":325
 *     '''Reset the run loop's internal state so that it's ready to run
 *     '''
 *     with nogil:             # <<<<<<<<<<<<<<
 *         MacRunLoopReset()
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      #endif
      /*try:*/ {

        /* "_javabridge.pyx":326
 *     '''
 *     with nogil:
 *         MacRunLoopReset()             # <<<<<<<<<<<<<<
 * 
 * def mac_enter_run_loop():
 */
        MacRunLoopReset();
      }

      /* "_javabridge.pyx":325
 *     '''Reset the run loop's internal state so that it's ready to run
 *     '''
 *     with nogil:             # <<<<<<<<<<<<<<
 *         MacRunLoopReset()
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "_javabridge.pyx":322
 *     MacRunLoopInit()
 * 
 * def mac_reset_run_loop():             # <<<<<<<<<<<<<<
 *     '''Reset the run loop's internal state so that it's ready to run
 *     '''
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":328
 *         MacRunLoopReset()
 * 
 * def mac_enter_run_loop():             # <<<<<<<<<<<<<<
 *     '''Enter the run loop and stay there until mac_stop_run_loop is called
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5mac_enter_run_loop(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_4mac_enter_run_loop[] = "Enter the run loop and stay there until mac_stop_run_loop is called\n    \n    This enters the main run loop in the main thread and stays in the\n    run loop until some other thread calls MacStopRunLoop.\n    ";
static PyMethodDef __pyx_mdef_11_javabridge_5mac_enter_run_loop = {"mac_enter_run_loop", (PyCFunction)__pyx_pw_11_javabridge_5mac_enter_run_loop, METH_NOARGS, __pyx_doc_11_javabridge_4mac_enter_run_loop};
static PyObject *__pyx_pw_11_javabridge_5mac_enter_run_loop(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_enter_run_loop (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_4mac_enter_run_loop(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_4mac_enter_run_loop(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_enter_run_loop", 0);

  /* "_javabridge.pyx":334
 *     run loop until some other thread calls MacStopRunLoop.
 *     '''
 *     with nogil:             # <<<<<<<<<<<<<<
 *         MacRunLoopRun()
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      #endif
      /*try:*/ {

        /* "_javabridge.pyx":335
 *     '''
 *     with nogil:
 *         MacRunLoopRun()             # <<<<<<<<<<<<<<
 * 
 * def mac_poll_run_loop(timeout):
 */
        MacRunLoopRun();
      }

      /* "_javabridge.pyx":334
 *     run loop until some other thread calls MacStopRunLoop.
 *     '''
 *     with nogil:             # <<<<<<<<<<<<<<
 *         MacRunLoopRun()
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "_javabridge.pyx":328
 *         MacRunLoopReset()
 * 
 * def mac_enter_run_loop():             # <<<<<<<<<<<<<<
 *     '''Enter the run loop and stay there until mac_stop_run_loop is called
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":337
 *         MacRunLoopRun()
 * 
 * def mac_poll_run_loop(timeout):             # <<<<<<<<<<<<<<
 *     MacRunLoopRunInMode(timeout)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_7mac_poll_run_loop(PyObject *__pyx_self, PyObject *__pyx_v_timeout); /*proto*/
static PyMethodDef __pyx_mdef_11_javabridge_7mac_poll_run_loop = {"mac_poll_run_loop", (PyCFunction)__pyx_pw_11_javabridge_7mac_poll_run_loop, METH_O, 0};
static PyObject *__pyx_pw_11_javabridge_7mac_poll_run_loop(PyObject *__pyx_self, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_poll_run_loop (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6mac_poll_run_loop(__pyx_self, ((PyObject *)__pyx_v_timeout));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6mac_poll_run_loop(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  __Pyx_RefNannySetupContext("mac_poll_run_loop", 0);

  /* "_javabridge.pyx":338
 * 
 * def mac_poll_run_loop(timeout):
 *     MacRunLoopRunInMode(timeout)             # <<<<<<<<<<<<<<
 * 
 * def mac_stop_run_loop():
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_timeout); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 338, __pyx_L1_error)
  MacRunLoopRunInMode(__pyx_t_1);

  /* "_javabridge.pyx":337
 *         MacRunLoopRun()
 * 
 * def mac_poll_run_loop(timeout):             # <<<<<<<<<<<<<<
 *     MacRunLoopRunInMode(timeout)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.mac_poll_run_loop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":340
 *     MacRunLoopRunInMode(timeout)
 * 
 * def mac_stop_run_loop():             # <<<<<<<<<<<<<<
 *     '''Signal the run loop to stop
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_9mac_stop_run_loop(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_8mac_stop_run_loop[] = "Signal the run loop to stop\n    \n    Wait for the main thread to enter the run loop, if necessary, then\n    signal the run loop to stop.\n    ";
static PyMethodDef __pyx_mdef_11_javabridge_9mac_stop_run_loop = {"mac_stop_run_loop", (PyCFunction)__pyx_pw_11_javabridge_9mac_stop_run_loop, METH_NOARGS, __pyx_doc_11_javabridge_8mac_stop_run_loop};
static PyObject *__pyx_pw_11_javabridge_9mac_stop_run_loop(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_stop_run_loop (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_8mac_stop_run_loop(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_8mac_stop_run_loop(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_stop_run_loop", 0);

  /* "_javabridge.pyx":346
 *     signal the run loop to stop.
 *     '''
 *     with nogil:             # <<<<<<<<<<<<<<
 *         MacRunLoopStop()
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      #endif
      /*try:*/ {

        /* "_javabridge.pyx":347
 *     '''
 *     with nogil:
 *         MacRunLoopStop()             # <<<<<<<<<<<<<<
 * 
 * def mac_is_main_thread():
 */
        MacRunLoopStop();
      }

      /* "_javabridge.pyx":346
 *     signal the run loop to stop.
 *     '''
 *     with nogil:             # <<<<<<<<<<<<<<
 *         MacRunLoopStop()
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "_javabridge.pyx":340
 *     MacRunLoopRunInMode(timeout)
 * 
 * def mac_stop_run_loop():             # <<<<<<<<<<<<<<
 *     '''Signal the run loop to stop
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":349
 *         MacRunLoopStop()
 * 
 * def mac_is_main_thread():             # <<<<<<<<<<<<<<
 *     '''Return True if the current thread runs the main OS/X run loop
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_11mac_is_main_thread(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_10mac_is_main_thread[] = "Return True if the current thread runs the main OS/X run loop\n    \n    ";
static PyMethodDef __pyx_mdef_11_javabridge_11mac_is_main_thread = {"mac_is_main_thread", (PyCFunction)__pyx_pw_11_javabridge_11mac_is_main_thread, METH_NOARGS, __pyx_doc_11_javabridge_10mac_is_main_thread};
static PyObject *__pyx_pw_11_javabridge_11mac_is_main_thread(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mac_is_main_thread (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_10mac_is_main_thread(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_10mac_is_main_thread(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("mac_is_main_thread", 0);

  /* "_javabridge.pyx":353
 * 
 *     '''
 *     return MacIsMainThread() != 0             # <<<<<<<<<<<<<<
 * 
 * #####################################################
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((MacIsMainThread() != 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":349
 *         MacRunLoopStop()
 * 
 * def mac_is_main_thread():             # <<<<<<<<<<<<<<
 *     '''Return True if the current thread runs the main OS/X run loop
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.mac_is_main_thread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":375
 * __wake_event = threading.Event()
 * 
 * def wait_for_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wait for dead objects to be enqueued or other event on monitor thread'''
 *     __wake_event.wait()
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_13wait_for_wake_event(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_12wait_for_wake_event[] = "Wait for dead objects to be enqueued or other event on monitor thread";
static PyMethodDef __pyx_mdef_11_javabridge_13wait_for_wake_event = {"wait_for_wake_event", (PyCFunction)__pyx_pw_11_javabridge_13wait_for_wake_event, METH_NOARGS, __pyx_doc_11_javabridge_12wait_for_wake_event};
static PyObject *__pyx_pw_11_javabridge_13wait_for_wake_event(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wait_for_wake_event (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_12wait_for_wake_event(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_12wait_for_wake_event(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("wait_for_wake_event", 0);

  /* "_javabridge.pyx":377
 * def wait_for_wake_event():
 *     '''Wait for dead objects to be enqueued or other event on monitor thread'''
 *     __wake_event.wait()             # <<<<<<<<<<<<<<
 *     __wake_event.clear()
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_wake_event); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_wait); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":378
 *     '''Wait for dead objects to be enqueued or other event on monitor thread'''
 *     __wake_event.wait()
 *     __wake_event.clear()             # <<<<<<<<<<<<<<
 * 
 * def set_wake_event():
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_wake_event); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_clear); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":375
 * __wake_event = threading.Event()
 * 
 * def wait_for_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wait for dead objects to be enqueued or other event on monitor thread'''
 *     __wake_event.wait()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_javabridge.wait_for_wake_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":380
 *     __wake_event.clear()
 * 
 * def set_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wake up the monitor thread'''
 *     __wake_event.set()
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_15set_wake_event(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_14set_wake_event[] = "Wake up the monitor thread";
static PyMethodDef __pyx_mdef_11_javabridge_15set_wake_event = {"set_wake_event", (PyCFunction)__pyx_pw_11_javabridge_15set_wake_event, METH_NOARGS, __pyx_doc_11_javabridge_14set_wake_event};
static PyObject *__pyx_pw_11_javabridge_15set_wake_event(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_wake_event (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_14set_wake_event(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_14set_wake_event(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("set_wake_event", 0);

  /* "_javabridge.pyx":382
 * def set_wake_event():
 *     '''Wake up the monitor thread'''
 *     __wake_event.set()             # <<<<<<<<<<<<<<
 * 
 * def get_vm():
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_wake_event); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":380
 *     __wake_event.clear()
 * 
 * def set_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wake up the monitor thread'''
 *     __wake_event.set()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_javabridge.set_wake_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":384
 *     __wake_event.set()
 * 
 * def get_vm():             # <<<<<<<<<<<<<<
 *     global __vm
 *     if __vm is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_17get_vm(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_11_javabridge_17get_vm = {"get_vm", (PyCFunction)__pyx_pw_11_javabridge_17get_vm, METH_NOARGS, 0};
static PyObject *__pyx_pw_11_javabridge_17get_vm(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_vm (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_16get_vm(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_16get_vm(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("get_vm", 0);

  /* "_javabridge.pyx":386
 * def get_vm():
 *     global __vm
 *     if __vm is None:             # <<<<<<<<<<<<<<
 *         __vm = JB_VM()
 *     return __vm
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "_javabridge.pyx":387
 *     global __vm
 *     if __vm is None:
 *         __vm = JB_VM()             # <<<<<<<<<<<<<<
 *     return __vm
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_VM), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_vm, __pyx_t_1) < 0) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_javabridge.pyx":386
 * def get_vm():
 *     global __vm
 *     if __vm is None:             # <<<<<<<<<<<<<<
 *         __vm = JB_VM()
 *     return __vm
 */
  }

  /* "_javabridge.pyx":388
 *     if __vm is None:
 *         __vm = JB_VM()
 *     return __vm             # <<<<<<<<<<<<<<
 * 
 * def get_thread_local(key, default=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":384
 *     __wake_event.set()
 * 
 * def get_vm():             # <<<<<<<<<<<<<<
 *     global __vm
 *     if __vm is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.get_vm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":390
 *     return __vm
 * 
 * def get_thread_local(key, default=None):             # <<<<<<<<<<<<<<
 *     if not hasattr(__thread_local_env, key):
 *         setattr(__thread_local_env, key, default)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_19get_thread_local(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11_javabridge_19get_thread_local = {"get_thread_local", (PyCFunction)__pyx_pw_11_javabridge_19get_thread_local, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11_javabridge_19get_thread_local(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_thread_local (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_thread_local") < 0)) __PYX_ERR(0, 390, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_key = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_thread_local", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 390, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.get_thread_local", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11_javabridge_18get_thread_local(__pyx_self, __pyx_v_key, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_18get_thread_local(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get_thread_local", 0);

  /* "_javabridge.pyx":391
 * 
 * def get_thread_local(key, default=None):
 *     if not hasattr(__thread_local_env, key):             # <<<<<<<<<<<<<<
 *         setattr(__thread_local_env, key, default)
 *     return getattr(__thread_local_env, key)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_thread_local_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_t_1, __pyx_v_key); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
  if (__pyx_t_3) {

    /* "_javabridge.pyx":392
 * def get_thread_local(key, default=None):
 *     if not hasattr(__thread_local_env, key):
 *         setattr(__thread_local_env, key, default)             # <<<<<<<<<<<<<<
 *     return getattr(__thread_local_env, key)
 * 
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_thread_local_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_SetAttr(__pyx_t_1, __pyx_v_key, __pyx_v_default); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_javabridge.pyx":391
 * 
 * def get_thread_local(key, default=None):
 *     if not hasattr(__thread_local_env, key):             # <<<<<<<<<<<<<<
 *         setattr(__thread_local_env, key, default)
 *     return getattr(__thread_local_env, key)
 */
  }

  /* "_javabridge.pyx":393
 *     if not hasattr(__thread_local_env, key):
 *         setattr(__thread_local_env, key, default)
 *     return getattr(__thread_local_env, key)             # <<<<<<<<<<<<<<
 * 
 * def set_thread_local(key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_thread_local_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_key); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":390
 *     return __vm
 * 
 * def get_thread_local(key, default=None):             # <<<<<<<<<<<<<<
 *     if not hasattr(__thread_local_env, key):
 *         setattr(__thread_local_env, key, default)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.get_thread_local", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":395
 *     return getattr(__thread_local_env, key)
 * 
 * def set_thread_local(key, value):             # <<<<<<<<<<<<<<
 *     setattr(__thread_local_env, key, value)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_21set_thread_local(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11_javabridge_21set_thread_local = {"set_thread_local", (PyCFunction)__pyx_pw_11_javabridge_21set_thread_local, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11_javabridge_21set_thread_local(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_thread_local (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_thread_local", 1, 2, 2, 1); __PYX_ERR(0, 395, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_thread_local") < 0)) __PYX_ERR(0, 395, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_thread_local", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 395, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.set_thread_local", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11_javabridge_20set_thread_local(__pyx_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_20set_thread_local(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_thread_local", 0);

  /* "_javabridge.pyx":396
 * 
 * def set_thread_local(key, value):
 *     setattr(__thread_local_env, key, value)             # <<<<<<<<<<<<<<
 * 
 * def get_env():
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_thread_local_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_SetAttr(__pyx_t_1, __pyx_v_key, __pyx_v_value); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":395
 *     return getattr(__thread_local_env, key)
 * 
 * def set_thread_local(key, value):             # <<<<<<<<<<<<<<
 *     setattr(__thread_local_env, key, value)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.set_thread_local", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":398
 *     setattr(__thread_local_env, key, value)
 * 
 * def get_env():             # <<<<<<<<<<<<<<
 *     '''Get the environment for this thread'''
 *     return get_thread_local("env")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_23get_env(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_22get_env[] = "Get the environment for this thread";
static PyMethodDef __pyx_mdef_11_javabridge_23get_env = {"get_env", (PyCFunction)__pyx_pw_11_javabridge_23get_env, METH_NOARGS, __pyx_doc_11_javabridge_22get_env};
static PyObject *__pyx_pw_11_javabridge_23get_env(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_env (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_22get_env(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_22get_env(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_env", 0);

  /* "_javabridge.pyx":400
 * def get_env():
 *     '''Get the environment for this thread'''
 *     return get_thread_local("env")             # <<<<<<<<<<<<<<
 * 
 * def jb_attach():
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_thread_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":398
 *     setattr(__thread_local_env, key, value)
 * 
 * def get_env():             # <<<<<<<<<<<<<<
 *     '''Get the environment for this thread'''
 *     return get_thread_local("env")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.get_env", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":402
 *     return get_thread_local("env")
 * 
 * def jb_attach():             # <<<<<<<<<<<<<<
 *     '''Attach to this thread's environment'''
 *     assert __vm is not None
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_25jb_attach(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_24jb_attach[] = "Attach to this thread's environment";
static PyMethodDef __pyx_mdef_11_javabridge_25jb_attach = {"jb_attach", (PyCFunction)__pyx_pw_11_javabridge_25jb_attach, METH_NOARGS, __pyx_doc_11_javabridge_24jb_attach};
static PyObject *__pyx_pw_11_javabridge_25jb_attach(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jb_attach (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_24jb_attach(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_24jb_attach(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("jb_attach", 0);

  /* "_javabridge.pyx":404
 * def jb_attach():
 *     '''Attach to this thread's environment'''
 *     assert __vm is not None             # <<<<<<<<<<<<<<
 *     assert get_env() is None
 *     assert __vm.is_active()
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!(__pyx_t_2 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 404, __pyx_L1_error)
    }
  }
  #endif

  /* "_javabridge.pyx":405
 *     '''Attach to this thread's environment'''
 *     assert __vm is not None
 *     assert get_env() is None             # <<<<<<<<<<<<<<
 *     assert __vm.is_active()
 *     set_thread_local("env", __vm.attach_as_daemon())
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_env); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!(__pyx_t_2 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 405, __pyx_L1_error)
    }
  }
  #endif

  /* "_javabridge.pyx":406
 *     assert __vm is not None
 *     assert get_env() is None
 *     assert __vm.is_active()             # <<<<<<<<<<<<<<
 *     set_thread_local("env", __vm.attach_as_daemon())
 *     return get_env()
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_active); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 406, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 406, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 406, __pyx_L1_error)
    }
  }
  #endif

  /* "_javabridge.pyx":407
 *     assert get_env() is None
 *     assert __vm.is_active()
 *     set_thread_local("env", __vm.attach_as_daemon())             # <<<<<<<<<<<<<<
 *     return get_env()
 * 
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_attach_as_daemon); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 407, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_env, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_env, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_n_s_env);
    __Pyx_GIVEREF(__pyx_n_s_env);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_7, __pyx_n_s_env);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_7, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":408
 *     assert __vm.is_active()
 *     set_thread_local("env", __vm.attach_as_daemon())
 *     return get_env()             # <<<<<<<<<<<<<<
 * 
 * def jb_detach():
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_env); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":402
 *     return get_thread_local("env")
 * 
 * def jb_attach():             # <<<<<<<<<<<<<<
 *     '''Attach to this thread's environment'''
 *     assert __vm is not None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_javabridge.jb_attach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":410
 *     return get_env()
 * 
 * def jb_detach():             # <<<<<<<<<<<<<<
 *     '''Detach from this thread's environment'''
 *     assert __vm is not None
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_27jb_detach(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_26jb_detach[] = "Detach from this thread's environment";
static PyMethodDef __pyx_mdef_11_javabridge_27jb_detach = {"jb_detach", (PyCFunction)__pyx_pw_11_javabridge_27jb_detach, METH_NOARGS, __pyx_doc_11_javabridge_26jb_detach};
static PyObject *__pyx_pw_11_javabridge_27jb_detach(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jb_detach (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_26jb_detach(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_26jb_detach(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("jb_detach", 0);

  /* "_javabridge.pyx":412
 * def jb_detach():
 *     '''Detach from this thread's environment'''
 *     assert __vm is not None             # <<<<<<<<<<<<<<
 *     assert get_env() is not None
 *     set_thread_local("env", None)
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!(__pyx_t_2 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 412, __pyx_L1_error)
    }
  }
  #endif

  /* "_javabridge.pyx":413
 *     '''Detach from this thread's environment'''
 *     assert __vm is not None
 *     assert get_env() is not None             # <<<<<<<<<<<<<<
 *     set_thread_local("env", None)
 *     __vm.detach()
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_env); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!(__pyx_t_2 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 413, __pyx_L1_error)
    }
  }
  #endif

  /* "_javabridge.pyx":414
 *     assert __vm is not None
 *     assert get_env() is not None
 *     set_thread_local("env", None)             # <<<<<<<<<<<<<<
 *     __vm.detach()
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_javabridge.pyx":415
 *     assert get_env() is not None
 *     set_thread_local("env", None)
 *     __vm.detach()             # <<<<<<<<<<<<<<
 * 
 * def jni_enter(env):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_vm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_detach); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_1) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_javabridge.pyx":410
 *     return get_env()
 * 
 * def jb_detach():             # <<<<<<<<<<<<<<
 *     '''Detach from this thread's environment'''
 *     assert __vm is not None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("_javabridge.jb_detach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":417
 *     __vm.detach()
 * 
 * def jni_enter(env):             # <<<<<<<<<<<<<<
 *     '''Enter Python from Java
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_29jni_enter(PyObject *__pyx_self, PyObject *__pyx_v_env); /*proto*/
static char __pyx_doc_11_javabridge_28jni_enter[] = "Enter Python from Java\n    \n    :param env: pointer to JNIEnv wrapped in a PyCapsule\n    \n    Set this thread's environment to the one passed in through\n    a JNI native call.\n    ";
static PyMethodDef __pyx_mdef_11_javabridge_29jni_enter = {"jni_enter", (PyCFunction)__pyx_pw_11_javabridge_29jni_enter, METH_O, __pyx_doc_11_javabridge_28jni_enter};
static PyObject *__pyx_pw_11_javabridge_29jni_enter(PyObject *__pyx_self, PyObject *__pyx_v_env) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jni_enter (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_28jni_enter(__pyx_self, ((PyObject *)__pyx_v_env));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_28jni_enter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_env) {
  PyObject *__pyx_v_env_stack = NULL;
  PyObject *__pyx_v_old_env = NULL;
  struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_new_env = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("jni_enter", 0);

  /* "_javabridge.pyx":425
 *     a JNI native call.
 *     '''
 *     env_stack = get_thread_local("envstack", None)             # <<<<<<<<<<<<<<
 *     if env_stack is None:
 *         env_stack = []
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_thread_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_env_stack = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":426
 *     '''
 *     env_stack = get_thread_local("envstack", None)
 *     if env_stack is None:             # <<<<<<<<<<<<<<
 *         env_stack = []
 *         set_thread_local("envstack", env_stack)
 */
  __pyx_t_3 = (__pyx_v_env_stack == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":427
 *     env_stack = get_thread_local("envstack", None)
 *     if env_stack is None:
 *         env_stack = []             # <<<<<<<<<<<<<<
 *         set_thread_local("envstack", env_stack)
 *     old_env = get_env()
 */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_env_stack, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "_javabridge.pyx":428
 *     if env_stack is None:
 *         env_stack = []
 *         set_thread_local("envstack", env_stack)             # <<<<<<<<<<<<<<
 *     old_env = get_env()
 *     if old_env is not None:
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_n_s_envstack, __pyx_v_env_stack};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_n_s_envstack, __pyx_v_env_stack};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_n_s_envstack);
      __Pyx_GIVEREF(__pyx_n_s_envstack);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_n_s_envstack);
      __Pyx_INCREF(__pyx_v_env_stack);
      __Pyx_GIVEREF(__pyx_v_env_stack);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_env_stack);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "_javabridge.pyx":426
 *     '''
 *     env_stack = get_thread_local("envstack", None)
 *     if env_stack is None:             # <<<<<<<<<<<<<<
 *         env_stack = []
 *         set_thread_local("envstack", env_stack)
 */
  }

  /* "_javabridge.pyx":429
 *         env_stack = []
 *         set_thread_local("envstack", env_stack)
 *     old_env = get_env()             # <<<<<<<<<<<<<<
 *     if old_env is not None:
 *         env_stack.append(old_env)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_old_env = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":430
 *         set_thread_local("envstack", env_stack)
 *     old_env = get_env()
 *     if old_env is not None:             # <<<<<<<<<<<<<<
 *         env_stack.append(old_env)
 *     new_env = JB_Env()
 */
  __pyx_t_4 = (__pyx_v_old_env != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "_javabridge.pyx":431
 *     old_env = get_env()
 *     if old_env is not None:
 *         env_stack.append(old_env)             # <<<<<<<<<<<<<<
 *     new_env = JB_Env()
 *     new_env.set_env(env)
 */
    __pyx_t_8 = __Pyx_PyObject_Append(__pyx_v_env_stack, __pyx_v_old_env); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 431, __pyx_L1_error)

    /* "_javabridge.pyx":430
 *         set_thread_local("envstack", env_stack)
 *     old_env = get_env()
 *     if old_env is not None:             # <<<<<<<<<<<<<<
 *         env_stack.append(old_env)
 *     new_env = JB_Env()
 */
  }

  /* "_javabridge.pyx":432
 *     if old_env is not None:
 *         env_stack.append(old_env)
 *     new_env = JB_Env()             # <<<<<<<<<<<<<<
 *     new_env.set_env(env)
 *     set_thread_local("env", new_env)
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Env), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_new_env = ((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":433
 *         env_stack.append(old_env)
 *     new_env = JB_Env()
 *     new_env.set_env(env)             # <<<<<<<<<<<<<<
 *     set_thread_local("env", new_env)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_new_env), __pyx_n_s_set_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_env); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_env};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_env};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_INCREF(__pyx_v_env);
      __Pyx_GIVEREF(__pyx_v_env);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_env);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_javabridge.pyx":434
 *     new_env = JB_Env()
 *     new_env.set_env(env)
 *     set_thread_local("env", new_env)             # <<<<<<<<<<<<<<
 * 
 * def jni_exit():
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_n_s_env, ((PyObject *)__pyx_v_new_env)};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_n_s_env, ((PyObject *)__pyx_v_new_env)};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_n_s_env);
    __Pyx_GIVEREF(__pyx_n_s_env);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_n_s_env);
    __Pyx_INCREF(((PyObject *)__pyx_v_new_env));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_new_env));
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_v_new_env));
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_javabridge.pyx":417
 *     __vm.detach()
 * 
 * def jni_enter(env):             # <<<<<<<<<<<<<<
 *     '''Enter Python from Java
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("_javabridge.jni_enter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_env_stack);
  __Pyx_XDECREF(__pyx_v_old_env);
  __Pyx_XDECREF((PyObject *)__pyx_v_new_env);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":436
 *     set_thread_local("env", new_env)
 * 
 * def jni_exit():             # <<<<<<<<<<<<<<
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_31jni_exit(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_30jni_exit[] = "Exit the JNI from Python";
static PyMethodDef __pyx_mdef_11_javabridge_31jni_exit = {"jni_exit", (PyCFunction)__pyx_pw_11_javabridge_31jni_exit, METH_NOARGS, __pyx_doc_11_javabridge_30jni_exit};
static PyObject *__pyx_pw_11_javabridge_31jni_exit(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jni_exit (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_30jni_exit(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_30jni_exit(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_env_stack = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("jni_exit", 0);

  /* "_javabridge.pyx":438
 * def jni_exit():
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")             # <<<<<<<<<<<<<<
 *     if len(env_stack) == 0:
 *         set_thread_local("env", None)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_thread_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_env_stack = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":439
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")
 *     if len(env_stack) == 0:             # <<<<<<<<<<<<<<
 *         set_thread_local("env", None)
 *     else:
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_env_stack); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 439, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 == 0) != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":440
 *     env_stack = get_thread_local("envstack")
 *     if len(env_stack) == 0:
 *         set_thread_local("env", None)             # <<<<<<<<<<<<<<
 *     else:
 *         set_thread_local("env", env_stack.pop())
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_javabridge.pyx":439
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")
 *     if len(env_stack) == 0:             # <<<<<<<<<<<<<<
 *         set_thread_local("env", None)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "_javabridge.pyx":442
 *         set_thread_local("env", None)
 *     else:
 *         set_thread_local("env", env_stack.pop())             # <<<<<<<<<<<<<<
 * 
 * def jvm_enter(vm):
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_Pop(__pyx_v_env_stack); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_env, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_env, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_INCREF(__pyx_n_s_env);
      __Pyx_GIVEREF(__pyx_n_s_env);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_n_s_env);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "_javabridge.pyx":436
 *     set_thread_local("env", new_env)
 * 
 * def jni_exit():             # <<<<<<<<<<<<<<
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("_javabridge.jni_exit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_env_stack);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":444
 *         set_thread_local("env", env_stack.pop())
 * 
 * def jvm_enter(vm):             # <<<<<<<<<<<<<<
 *     '''Initialize the JVM on entry into Python
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_33jvm_enter(PyObject *__pyx_self, PyObject *__pyx_v_vm); /*proto*/
static char __pyx_doc_11_javabridge_32jvm_enter[] = "Initialize the JVM on entry into Python\n    \n    :param vm: pointer to JavaVM wrapped in a PyCapsule\n    \n    Set the global Java VM.\n    ";
static PyMethodDef __pyx_mdef_11_javabridge_33jvm_enter = {"jvm_enter", (PyCFunction)__pyx_pw_11_javabridge_33jvm_enter, METH_O, __pyx_doc_11_javabridge_32jvm_enter};
static PyObject *__pyx_pw_11_javabridge_33jvm_enter(PyObject *__pyx_self, PyObject *__pyx_v_vm) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jvm_enter (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_32jvm_enter(__pyx_self, ((PyObject *)__pyx_v_vm));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_32jvm_enter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_vm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("jvm_enter", 0);

  /* "_javabridge.pyx":451
 *     Set the global Java VM.
 *     '''
 *     get_vm().set_vm(vm)             # <<<<<<<<<<<<<<
 * 
 * def reap():
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_vm); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_vm); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_vm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_vm};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_vm};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_vm);
      __Pyx_GIVEREF(__pyx_v_vm);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_vm);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":444
 *         set_thread_local("env", env_stack.pop())
 * 
 * def jvm_enter(vm):             # <<<<<<<<<<<<<<
 *     '''Initialize the JVM on entry into Python
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("_javabridge.jvm_enter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":453
 *     get_vm().set_vm(vm)
 * 
 * def reap():             # <<<<<<<<<<<<<<
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_35reap(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_34reap[] = "Reap all of the garbage-collected Java objects on the dead_objects list";
static PyMethodDef __pyx_mdef_11_javabridge_35reap = {"reap", (PyCFunction)__pyx_pw_11_javabridge_35reap, METH_NOARGS, __pyx_doc_11_javabridge_34reap};
static PyObject *__pyx_pw_11_javabridge_35reap(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reap (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_34reap(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_34reap(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_env = NULL;
  PyObject *__pyx_v_to_die = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("reap", 0);

  /* "_javabridge.pyx":455
 * def reap():
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:             # <<<<<<<<<<<<<<
 *         env = get_env()
 *         assert env is not None
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_dead_objects); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((__pyx_t_2 > 0) != 0);
  if (__pyx_t_3) {

    /* "_javabridge.pyx":456
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:
 *         env = get_env()             # <<<<<<<<<<<<<<
 *         assert env is not None
 *         try:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_env); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_env = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "_javabridge.pyx":457
 *     if len(__dead_objects) > 0:
 *         env = get_env()
 *         assert env is not None             # <<<<<<<<<<<<<<
 *         try:
 *             while True:
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_3 = (__pyx_v_env != Py_None);
      if (unlikely(!(__pyx_t_3 != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 457, __pyx_L1_error)
      }
    }
    #endif

    /* "_javabridge.pyx":458
 *         env = get_env()
 *         assert env is not None
 *         try:             # <<<<<<<<<<<<<<
 *             while True:
 *                 to_die = __dead_objects.pop()
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "_javabridge.pyx":459
 *         assert env is not None
 *         try:
 *             while True:             # <<<<<<<<<<<<<<
 *                 to_die = __dead_objects.pop()
 *                 env.dealloc_jobject(to_die)
 */
        while (1) {

          /* "_javabridge.pyx":460
 *         try:
 *             while True:
 *                 to_die = __dead_objects.pop()             # <<<<<<<<<<<<<<
 *                 env.dealloc_jobject(to_die)
 *         except IndexError:
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_dead_objects); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 460, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyObject_Pop(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 460, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF_SET(__pyx_v_to_die, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "_javabridge.pyx":461
 *             while True:
 *                 to_die = __dead_objects.pop()
 *                 env.dealloc_jobject(to_die)             # <<<<<<<<<<<<<<
 *         except IndexError:
 *             pass
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_env, __pyx_n_s_dealloc_jobject); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_5) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_to_die); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_to_die};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L4_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_to_die};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L4_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 461, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5); __pyx_t_5 = NULL;
              __Pyx_INCREF(__pyx_v_to_die);
              __Pyx_GIVEREF(__pyx_v_to_die);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_to_die);
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }

        /* "_javabridge.pyx":458
 *         env = get_env()
 *         assert env is not None
 *         try:             # <<<<<<<<<<<<<<
 *             while True:
 *                 to_die = __dead_objects.pop()
 */
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L11_try_end;
      __pyx_L4_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "_javabridge.pyx":462
 *                 to_die = __dead_objects.pop()
 *                 env.dealloc_jobject(to_die)
 *         except IndexError:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
      if (__pyx_t_10) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "_javabridge.pyx":458
 *         env = get_env()
 *         assert env is not None
 *         try:             # <<<<<<<<<<<<<<
 *             while True:
 *                 to_die = __dead_objects.pop()
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L11_try_end:;
    }

    /* "_javabridge.pyx":455
 * def reap():
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:             # <<<<<<<<<<<<<<
 *         env = get_env()
 *         assert env is not None
 */
  }

  /* "_javabridge.pyx":453
 *     get_vm().set_vm(vm)
 * 
 * def reap():             # <<<<<<<<<<<<<<
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("_javabridge.reap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_env);
  __Pyx_XDECREF(__pyx_v_to_die);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":470
 *         jobject o
 *         gc_collect
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.o = NULL
 *         self.gc_collect = False
 */

/* Python wrapper */
static int __pyx_pw_11_javabridge_9JB_Object_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11_javabridge_9JB_Object_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_11_javabridge_9JB_Object___cinit__(((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11_javabridge_9JB_Object___cinit__(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "_javabridge.pyx":471
 *         gc_collect
 *     def __cinit__(self):
 *         self.o = NULL             # <<<<<<<<<<<<<<
 *         self.gc_collect = False
 *     def __repr__(self):
 */
  __pyx_v_self->o = NULL;

  /* "_javabridge.pyx":472
 *     def __cinit__(self):
 *         self.o = NULL
 *         self.gc_collect = False             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<Java object at 0x%x>"%<int>(self.o)
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_self->gc_collect);
  __Pyx_DECREF(__pyx_v_self->gc_collect);
  __pyx_v_self->gc_collect = Py_False;

  /* "_javabridge.pyx":470
 *         jobject o
 *         gc_collect
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.o = NULL
 *         self.gc_collect = False
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":473
 *         self.o = NULL
 *         self.gc_collect = False
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java object at 0x%x>"%<int>(self.o)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_9JB_Object_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11_javabridge_9JB_Object_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_9JB_Object_2__repr__(((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_9JB_Object_2__repr__(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "_javabridge.pyx":474
 *         self.gc_collect = False
 *     def __repr__(self):
 *         return "<Java object at 0x%x>"%<int>(self.o)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(((int)__pyx_v_self->o)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_Java_object_at_0x_x, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":473
 *         self.o = NULL
 *         self.gc_collect = False
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java object at 0x%x>"%<int>(self.o)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Object.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":476
 *         return "<Java object at 0x%x>"%<int>(self.o)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             JB_Object alternate
 */

/* Python wrapper */
static void __pyx_pw_11_javabridge_9JB_Object_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_11_javabridge_9JB_Object_5__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_11_javabridge_9JB_Object_4__dealloc__(((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_11_javabridge_9JB_Object_4__dealloc__(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_alternate = 0;
  PyObject *__pyx_v_env = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  jobject __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "_javabridge.pyx":479
 *         cdef:
 *             JB_Object alternate
 *         if not self.gc_collect:             # <<<<<<<<<<<<<<
 *             return
 *         env = get_env()
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->gc_collect); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 479, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "_javabridge.pyx":480
 *             JB_Object alternate
 *         if not self.gc_collect:
 *             return             # <<<<<<<<<<<<<<
 *         env = get_env()
 *         if env is None:
 */
    goto __pyx_L0;

    /* "_javabridge.pyx":479
 *         cdef:
 *             JB_Object alternate
 *         if not self.gc_collect:             # <<<<<<<<<<<<<<
 *             return
 *         env = get_env()
 */
  }

  /* "_javabridge.pyx":481
 *         if not self.gc_collect:
 *             return
 *         env = get_env()             # <<<<<<<<<<<<<<
 *         if env is None:
 *             alternate = JB_Object()
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_env); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 481, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 481, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_env = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":482
 *             return
 *         env = get_env()
 *         if env is None:             # <<<<<<<<<<<<<<
 *             alternate = JB_Object()
 *             alternate.o = self.o
 */
  __pyx_t_2 = (__pyx_v_env == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":483
 *         env = get_env()
 *         if env is None:
 *             alternate = JB_Object()             # <<<<<<<<<<<<<<
 *             alternate.o = self.o
 *             __dead_objects.append(alternate)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Object), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_alternate = ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "_javabridge.pyx":484
 *         if env is None:
 *             alternate = JB_Object()
 *             alternate.o = self.o             # <<<<<<<<<<<<<<
 *             __dead_objects.append(alternate)
 *             set_wake_event()
 */
    __pyx_t_6 = __pyx_v_self->o;
    __pyx_v_alternate->o = __pyx_t_6;

    /* "_javabridge.pyx":485
 *             alternate = JB_Object()
 *             alternate.o = self.o
 *             __dead_objects.append(alternate)             # <<<<<<<<<<<<<<
 *             set_wake_event()
 *         else:
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_dead_objects); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_3, ((PyObject *)__pyx_v_alternate)); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "_javabridge.pyx":486
 *             alternate.o = self.o
 *             __dead_objects.append(alternate)
 *             set_wake_event()             # <<<<<<<<<<<<<<
 *         else:
 *             env.dealloc_jobject(self)
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_wake_event); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "_javabridge.pyx":482
 *             return
 *         env = get_env()
 *         if env is None:             # <<<<<<<<<<<<<<
 *             alternate = JB_Object()
 *             alternate.o = self.o
 */
    goto __pyx_L4;
  }

  /* "_javabridge.pyx":488
 *             set_wake_event()
 *         else:
 *             env.dealloc_jobject(self)             # <<<<<<<<<<<<<<
 * 
 *     def addr(self):
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_env, __pyx_n_s_dealloc_jobject); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, ((PyObject *)__pyx_v_self)};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, ((PyObject *)__pyx_v_self)};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, ((PyObject *)__pyx_v_self));
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "_javabridge.pyx":476
 *         return "<Java object at 0x%x>"%<int>(self.o)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             JB_Object alternate
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_WriteUnraisable("_javabridge.JB_Object.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 0, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_alternate);
  __Pyx_XDECREF(__pyx_v_env);
  __Pyx_RefNannyFinishContext();
}

/* "_javabridge.pyx":490
 *             env.dealloc_jobject(self)
 * 
 *     def addr(self):             # <<<<<<<<<<<<<<
 *         '''Return the address of the Java object as a string'''
 *         return str(<int>(self.o))
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_9JB_Object_7addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_9JB_Object_6addr[] = "Return the address of the Java object as a string";
static PyObject *__pyx_pw_11_javabridge_9JB_Object_7addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addr (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_9JB_Object_6addr(((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_9JB_Object_6addr(struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("addr", 0);

  /* "_javabridge.pyx":492
 *     def addr(self):
 *         '''Return the address of the Java object as a string'''
 *         return str(<int>(self.o))             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_Class:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(((int)__pyx_v_self->o)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":490
 *             env.dealloc_jobject(self)
 * 
 *     def addr(self):             # <<<<<<<<<<<<<<
 *         '''Return the address of the Java object as a string'''
 *         return str(<int>(self.o))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Object.addr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":498
 *     cdef:
 *         jclass c
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.c = NULL
 *     def __repr__(self):
 */

/* Python wrapper */
static int __pyx_pw_11_javabridge_8JB_Class_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11_javabridge_8JB_Class_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_11_javabridge_8JB_Class___cinit__(((struct __pyx_obj_11_javabridge_JB_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11_javabridge_8JB_Class___cinit__(struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "_javabridge.pyx":499
 *         jclass c
 *     def __cinit__(self):
 *         self.c = NULL             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<Java class at 0x%x>"%<int>(self.c)
 */
  __pyx_v_self->c = NULL;

  /* "_javabridge.pyx":498
 *     cdef:
 *         jclass c
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.c = NULL
 *     def __repr__(self):
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":500
 *     def __cinit__(self):
 *         self.c = NULL
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java class at 0x%x>"%<int>(self.c)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_8JB_Class_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11_javabridge_8JB_Class_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_8JB_Class_2__repr__(((struct __pyx_obj_11_javabridge_JB_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_8JB_Class_2__repr__(struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "_javabridge.pyx":501
 *         self.c = NULL
 *     def __repr__(self):
 *         return "<Java class at 0x%x>"%<int>(self.c)             # <<<<<<<<<<<<<<
 * 
 * cdef class __JB_MethodID:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(((int)__pyx_v_self->c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_Java_class_at_0x_x, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":500
 *     def __cinit__(self):
 *         self.c = NULL
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java class at 0x%x>"%<int>(self.c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Class.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":509
 *         sig
 *         is_static
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.id = NULL
 *         self.sig = ''
 */

/* Python wrapper */
static int __pyx_pw_11_javabridge_13__JB_MethodID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11_javabridge_13__JB_MethodID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_11_javabridge_13__JB_MethodID___cinit__(((struct __pyx_obj_11_javabridge___JB_MethodID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11_javabridge_13__JB_MethodID___cinit__(struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "_javabridge.pyx":510
 *         is_static
 *     def __cinit__(self):
 *         self.id = NULL             # <<<<<<<<<<<<<<
 *         self.sig = ''
 *         self.is_static = False
 */
  __pyx_v_self->id = NULL;

  /* "_javabridge.pyx":511
 *     def __cinit__(self):
 *         self.id = NULL
 *         self.sig = ''             # <<<<<<<<<<<<<<
 *         self.is_static = False
 * 
 */
  __Pyx_INCREF(__pyx_kp_s__6);
  __Pyx_GIVEREF(__pyx_kp_s__6);
  __Pyx_GOTREF(__pyx_v_self->sig);
  __Pyx_DECREF(__pyx_v_self->sig);
  __pyx_v_self->sig = __pyx_kp_s__6;

  /* "_javabridge.pyx":512
 *         self.id = NULL
 *         self.sig = ''
 *         self.is_static = False             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_self->is_static);
  __Pyx_DECREF(__pyx_v_self->is_static);
  __pyx_v_self->is_static = Py_False;

  /* "_javabridge.pyx":509
 *         sig
 *         is_static
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.id = NULL
 *         self.sig = ''
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":514
 *         self.is_static = False
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_13__JB_MethodID_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11_javabridge_13__JB_MethodID_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_13__JB_MethodID_2__repr__(((struct __pyx_obj_11_javabridge___JB_MethodID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_13__JB_MethodID_2__repr__(struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "_javabridge.pyx":515
 * 
 *     def __repr__(self):
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))             # <<<<<<<<<<<<<<
 * 
 * cdef class __JB_FieldID:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(((int)__pyx_v_self->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->sig);
  __Pyx_GIVEREF(__pyx_v_self->sig);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->sig);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Java_method_with_sig_s_at_0x_x, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":514
 *         self.is_static = False
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.__JB_MethodID.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":523
 *         sig
 *         is_static
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.id = NULL
 *         self.sig = ''
 */

/* Python wrapper */
static int __pyx_pw_11_javabridge_12__JB_FieldID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11_javabridge_12__JB_FieldID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_11_javabridge_12__JB_FieldID___cinit__(((struct __pyx_obj_11_javabridge___JB_FieldID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11_javabridge_12__JB_FieldID___cinit__(struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "_javabridge.pyx":524
 *         is_static
 *     def __cinit__(self):
 *         self.id = NULL             # <<<<<<<<<<<<<<
 *         self.sig = ''
 *         self.is_static = False
 */
  __pyx_v_self->id = NULL;

  /* "_javabridge.pyx":525
 *     def __cinit__(self):
 *         self.id = NULL
 *         self.sig = ''             # <<<<<<<<<<<<<<
 *         self.is_static = False
 * 
 */
  __Pyx_INCREF(__pyx_kp_s__6);
  __Pyx_GIVEREF(__pyx_kp_s__6);
  __Pyx_GOTREF(__pyx_v_self->sig);
  __Pyx_DECREF(__pyx_v_self->sig);
  __pyx_v_self->sig = __pyx_kp_s__6;

  /* "_javabridge.pyx":526
 *         self.id = NULL
 *         self.sig = ''
 *         self.is_static = False             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_self->is_static);
  __Pyx_DECREF(__pyx_v_self->is_static);
  __pyx_v_self->is_static = Py_False;

  /* "_javabridge.pyx":523
 *         sig
 *         is_static
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.id = NULL
 *         self.sig = ''
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":528
 *         self.is_static = False
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_12__JB_FieldID_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11_javabridge_12__JB_FieldID_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_12__JB_FieldID_2__repr__(((struct __pyx_obj_11_javabridge___JB_FieldID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_12__JB_FieldID_2__repr__(struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "_javabridge.pyx":529
 * 
 *     def __repr__(self):
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))             # <<<<<<<<<<<<<<
 * 
 * cdef fill_values(orig_sig, args, jvalue **pvalues):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(((int)__pyx_v_self->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->sig);
  __Pyx_GIVEREF(__pyx_v_self->sig);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->sig);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Java_field_with_sig_s_at_0x_x, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":528
 *         self.is_static = False
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.__JB_FieldID.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":531
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))
 * 
 * cdef fill_values(orig_sig, args, jvalue **pvalues):             # <<<<<<<<<<<<<<
 *     cdef:
 *         jvalue *values
 */

static PyObject *__pyx_f_11_javabridge_fill_values(PyObject *__pyx_v_orig_sig, PyObject *__pyx_v_args, jvalue **__pyx_v_pvalues) {
  jvalue *__pyx_v_values;
  int __pyx_v_i;
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbobject = 0;
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_jbclass = 0;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_non_bracket_ind = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  jboolean __pyx_t_9;
  jbyte __pyx_t_10;
  long __pyx_t_11;
  jshort __pyx_t_12;
  jint __pyx_t_13;
  jlong __pyx_t_14;
  double __pyx_t_15;
  int __pyx_t_16;
  jobject __pyx_t_17;
  jclass __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  __Pyx_RefNannySetupContext("fill_values", 0);

  /* "_javabridge.pyx":539
 *         Py_UNICODE *usz
 * 
 *     sig = orig_sig             # <<<<<<<<<<<<<<
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values
 */
  __Pyx_INCREF(__pyx_v_orig_sig);
  __pyx_v_sig = __pyx_v_orig_sig;

  /* "_javabridge.pyx":540
 * 
 *     sig = orig_sig
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))             # <<<<<<<<<<<<<<
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 540, __pyx_L1_error)
  __pyx_v_values = ((jvalue *)malloc(((sizeof(jvalue)) * __pyx_t_1)));

  /* "_javabridge.pyx":541
 *     sig = orig_sig
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values             # <<<<<<<<<<<<<<
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:
 */
  (__pyx_v_pvalues[0]) = __pyx_v_values;

  /* "_javabridge.pyx":542
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):             # <<<<<<<<<<<<<<
 *         if len(sig) == 0:
 *             free(<void *>values)
 */
  __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_v_args)) || PyTuple_CheckExact(__pyx_v_args)) {
    __pyx_t_3 = __pyx_v_args; __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 542, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 542, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 542, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_3);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 542, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_v_i = __pyx_t_2;
    __pyx_t_2 = (__pyx_t_2 + 1);

    /* "_javabridge.pyx":543
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:             # <<<<<<<<<<<<<<
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_sig); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 543, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_6 == 0) != 0);
    if (__pyx_t_7) {

      /* "_javabridge.pyx":544
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:
 *             free(<void *>values)             # <<<<<<<<<<<<<<
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))
 */
      free(((void *)__pyx_v_values));

      /* "_javabridge.pyx":545
 *         if len(sig) == 0:
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%             # <<<<<<<<<<<<<<
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean
 */
      __Pyx_XDECREF(__pyx_r);

      /* "_javabridge.pyx":546
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))             # <<<<<<<<<<<<<<
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 546, __pyx_L1_error)
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_orig_sig);
      __Pyx_GIVEREF(__pyx_v_orig_sig);
      PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_orig_sig);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":545
 *         if len(sig) == 0:
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%             # <<<<<<<<<<<<<<
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean
 */
      __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_of_arguments_d_in_call_did_not, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "_javabridge.pyx":543
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:             # <<<<<<<<<<<<<<
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 */
    }

    /* "_javabridge.pyx":547
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean             # <<<<<<<<<<<<<<
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_Z, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 547, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":548
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte
 */
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_arg); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 548, __pyx_L1_error)
      if (__pyx_t_7) {
        __pyx_t_9 = 1;
      } else {
        __pyx_t_9 = 0;
      }
      (__pyx_v_values[__pyx_v_i]).z = __pyx_t_9;

      /* "_javabridge.pyx":549
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__7, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":547
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean             # <<<<<<<<<<<<<<
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":550
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte             # <<<<<<<<<<<<<<
 *             values[i].b = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_B, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 550, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":551
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char
 */
      __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_v_arg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = __Pyx_PyInt_As_jbyte(__pyx_t_5); if (unlikely((__pyx_t_10 == ((jbyte)-1)) && PyErr_Occurred())) __PYX_ERR(0, 551, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      (__pyx_v_values[__pyx_v_i]).b = __pyx_t_10;

      /* "_javabridge.pyx":552
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'C': #char
 *             values[i].c = ord(arg[0])
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":550
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte             # <<<<<<<<<<<<<<
 *             values[i].b = int(arg)
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":553
 *             values[i].b = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char             # <<<<<<<<<<<<<<
 *             values[i].c = ord(arg[0])
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_C, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":554
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char
 *             values[i].c = ord(arg[0])             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short
 */
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_arg, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = __Pyx_PyObject_Ord(__pyx_t_5); if (unlikely(__pyx_t_11 == (long)(Py_UCS4)-1)) __PYX_ERR(0, 554, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      (__pyx_v_values[__pyx_v_i]).c = __pyx_t_11;

      /* "_javabridge.pyx":555
 *         elif sig[0] == 'C': #char
 *             values[i].c = ord(arg[0])
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__9, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":553
 *             values[i].b = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char             # <<<<<<<<<<<<<<
 *             values[i].c = ord(arg[0])
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":556
 *             values[i].c = ord(arg[0])
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short             # <<<<<<<<<<<<<<
 *             values[i].s = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_S, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":557
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int
 */
      __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_v_arg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = __Pyx_PyInt_As_jshort(__pyx_t_5); if (unlikely((__pyx_t_12 == ((jshort)-1)) && PyErr_Occurred())) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      (__pyx_v_values[__pyx_v_i]).s = __pyx_t_12;

      /* "_javabridge.pyx":558
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__10, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 558, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":556
 *             values[i].c = ord(arg[0])
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short             # <<<<<<<<<<<<<<
 *             values[i].s = int(arg)
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":559
 *             values[i].s = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int             # <<<<<<<<<<<<<<
 *             values[i].i = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_I, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":560
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long
 */
      __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_v_arg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = __Pyx_PyInt_As_jint(__pyx_t_5); if (unlikely((__pyx_t_13 == ((jint)-1)) && PyErr_Occurred())) __PYX_ERR(0, 560, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      (__pyx_v_values[__pyx_v_i]).i = __pyx_t_13;

      /* "_javabridge.pyx":561
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__11, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":559
 *             values[i].s = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int             # <<<<<<<<<<<<<<
 *             values[i].i = int(arg)
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":562
 *             values[i].i = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long             # <<<<<<<<<<<<<<
 *             values[i].j = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_J, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 562, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":563
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float
 */
      __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_v_arg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 563, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyInt_As_jlong(__pyx_t_5); if (unlikely((__pyx_t_14 == ((jlong)-1)) && PyErr_Occurred())) __PYX_ERR(0, 563, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      (__pyx_v_values[__pyx_v_i]).j = __pyx_t_14;

      /* "_javabridge.pyx":564
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__12, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":562
 *             values[i].i = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long             # <<<<<<<<<<<<<<
 *             values[i].j = int(arg)
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":565
 *             values[i].j = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float             # <<<<<<<<<<<<<<
 *             values[i].f = float(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_F, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":566
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double
 */
      __pyx_t_15 = __Pyx_PyObject_AsDouble(__pyx_v_arg); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 566, __pyx_L1_error)
      (__pyx_v_values[__pyx_v_i]).f = __pyx_t_15;

      /* "_javabridge.pyx":567
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__13, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":565
 *             values[i].j = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float             # <<<<<<<<<<<<<<
 *             values[i].f = float(arg)
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":568
 *             values[i].f = float(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double             # <<<<<<<<<<<<<<
 *             values[i].d = float(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_D, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":569
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 */
      __pyx_t_15 = __Pyx_PyObject_AsDouble(__pyx_v_arg); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L1_error)
      (__pyx_v_values[__pyx_v_i]).d = __pyx_t_15;

      /* "_javabridge.pyx":570
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, NULL, &__pyx_slice__14, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "_javabridge.pyx":568
 *             values[i].f = float(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double             # <<<<<<<<<<<<<<
 *             values[i].d = float(arg)
 *             sig = sig[1:]
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":571
 *             values[i].d = float(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object             # <<<<<<<<<<<<<<
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_16 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_L, Py_EQ)); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_16) {
    } else {
      __pyx_t_7 = __pyx_t_16;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_16 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_kp_s__15, Py_EQ)); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __pyx_t_16;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_7) {

      /* "_javabridge.pyx":572
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):             # <<<<<<<<<<<<<<
 *                  jbobject = arg
 *                  values[i].l = jbobject.o
 */
      __pyx_t_7 = __Pyx_TypeCheck(__pyx_v_arg, __pyx_ptype_11_javabridge_JB_Object); 
      __pyx_t_16 = (__pyx_t_7 != 0);
      if (__pyx_t_16) {

        /* "_javabridge.pyx":573
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg             # <<<<<<<<<<<<<<
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):
 */
        if (!(likely(((__pyx_v_arg) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_arg, __pyx_ptype_11_javabridge_JB_Object))))) __PYX_ERR(0, 573, __pyx_L1_error)
        __pyx_t_5 = __pyx_v_arg;
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_jbobject, ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_t_5));
        __pyx_t_5 = 0;

        /* "_javabridge.pyx":574
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg
 *                  values[i].l = jbobject.o             # <<<<<<<<<<<<<<
 *             elif isinstance(arg, JB_Class):
 *                  jbclass = arg
 */
        __pyx_t_17 = __pyx_v_jbobject->o;
        (__pyx_v_values[__pyx_v_i]).l = __pyx_t_17;

        /* "_javabridge.pyx":572
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):             # <<<<<<<<<<<<<<
 *                  jbobject = arg
 *                  values[i].l = jbobject.o
 */
        goto __pyx_L9;
      }

      /* "_javabridge.pyx":575
 *                  jbobject = arg
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):             # <<<<<<<<<<<<<<
 *                  jbclass = arg
 *                  values[i].l = jbclass.c
 */
      __pyx_t_16 = __Pyx_TypeCheck(__pyx_v_arg, __pyx_ptype_11_javabridge_JB_Class); 
      __pyx_t_7 = (__pyx_t_16 != 0);
      if (__pyx_t_7) {

        /* "_javabridge.pyx":576
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):
 *                  jbclass = arg             # <<<<<<<<<<<<<<
 *                  values[i].l = jbclass.c
 *             elif arg is None:
 */
        if (!(likely(((__pyx_v_arg) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_arg, __pyx_ptype_11_javabridge_JB_Class))))) __PYX_ERR(0, 576, __pyx_L1_error)
        __pyx_t_5 = __pyx_v_arg;
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_jbclass, ((struct __pyx_obj_11_javabridge_JB_Class *)__pyx_t_5));
        __pyx_t_5 = 0;

        /* "_javabridge.pyx":577
 *             elif isinstance(arg, JB_Class):
 *                  jbclass = arg
 *                  values[i].l = jbclass.c             # <<<<<<<<<<<<<<
 *             elif arg is None:
 *                  values[i].l = NULL
 */
        __pyx_t_18 = __pyx_v_jbclass->c;
        (__pyx_v_values[__pyx_v_i]).l = __pyx_t_18;

        /* "_javabridge.pyx":575
 *                  jbobject = arg
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):             # <<<<<<<<<<<<<<
 *                  jbclass = arg
 *                  values[i].l = jbclass.c
 */
        goto __pyx_L9;
      }

      /* "_javabridge.pyx":578
 *                  jbclass = arg
 *                  values[i].l = jbclass.c
 *             elif arg is None:             # <<<<<<<<<<<<<<
 *                  values[i].l = NULL
 *             else:
 */
      __pyx_t_7 = (__pyx_v_arg == Py_None);
      __pyx_t_16 = (__pyx_t_7 != 0);
      if (__pyx_t_16) {

        /* "_javabridge.pyx":579
 *                  values[i].l = jbclass.c
 *             elif arg is None:
 *                  values[i].l = NULL             # <<<<<<<<<<<<<<
 *             else:
 *                  free(<void *>values)
 */
        (__pyx_v_values[__pyx_v_i]).l = NULL;

        /* "_javabridge.pyx":578
 *                  jbclass = arg
 *                  values[i].l = jbclass.c
 *             elif arg is None:             # <<<<<<<<<<<<<<
 *                  values[i].l = NULL
 *             else:
 */
        goto __pyx_L9;
      }

      /* "_javabridge.pyx":581
 *                  values[i].l = NULL
 *             else:
 *                  free(<void *>values)             # <<<<<<<<<<<<<<
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':
 */
      /*else*/ {
        free(((void *)__pyx_v_values));

        /* "_javabridge.pyx":582
 *             else:
 *                  free(<void *>values)
 *                  return ValueError("%s is not a Java object"%str(arg))             # <<<<<<<<<<<<<<
 *             if sig[0] == '[':
 *                  if len(sig) == 1:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_arg);
        __Pyx_GIVEREF(__pyx_v_arg);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_arg);
        __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_5, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_s_is_not_a_Java_object, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_r = __pyx_t_5;
        __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;
      }
      __pyx_L9:;

      /* "_javabridge.pyx":583
 *                  free(<void *>values)
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':             # <<<<<<<<<<<<<<
 *                  if len(sig) == 1:
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 */
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_16 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_kp_s__15, Py_EQ)); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_16) {

        /* "_javabridge.pyx":584
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':
 *                  if len(sig) == 1:             # <<<<<<<<<<<<<<
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  non_bracket_ind = 1
 */
        __pyx_t_6 = PyObject_Length(__pyx_v_sig); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 584, __pyx_L1_error)
        __pyx_t_16 = ((__pyx_t_6 == 1) != 0);
        if (__pyx_t_16) {

          /* "_javabridge.pyx":585
 *             if sig[0] == '[':
 *                  if len(sig) == 1:
 *                       raise ValueError("Bad signature: %s"%orig_sig)             # <<<<<<<<<<<<<<
 *                  non_bracket_ind = 1
 *                  try:
 */
          __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_Bad_signature_s, __pyx_v_orig_sig); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_Raise(__pyx_t_5, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __PYX_ERR(0, 585, __pyx_L1_error)

          /* "_javabridge.pyx":584
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':
 *                  if len(sig) == 1:             # <<<<<<<<<<<<<<
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  non_bracket_ind = 1
 */
        }

        /* "_javabridge.pyx":586
 *                  if len(sig) == 1:
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  non_bracket_ind = 1             # <<<<<<<<<<<<<<
 *                  try:
 *                       while sig[non_bracket_ind] == '[':
 */
        __Pyx_INCREF(__pyx_int_1);
        __Pyx_XDECREF_SET(__pyx_v_non_bracket_ind, __pyx_int_1);

        /* "_javabridge.pyx":587
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  non_bracket_ind = 1
 *                  try:             # <<<<<<<<<<<<<<
 *                       while sig[non_bracket_ind] == '[':
 *                            non_bracket_ind += 1
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          /*try:*/ {

            /* "_javabridge.pyx":588
 *                  non_bracket_ind = 1
 *                  try:
 *                       while sig[non_bracket_ind] == '[':             # <<<<<<<<<<<<<<
 *                            non_bracket_ind += 1
 *                  except IndexError:
 */
            while (1) {
              __pyx_t_5 = PyObject_GetItem(__pyx_v_sig, __pyx_v_non_bracket_ind); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 588, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_16 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_kp_s__15, Py_EQ)); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 588, __pyx_L12_error)
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (!__pyx_t_16) break;

              /* "_javabridge.pyx":589
 *                  try:
 *                       while sig[non_bracket_ind] == '[':
 *                            non_bracket_ind += 1             # <<<<<<<<<<<<<<
 *                  except IndexError:
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 */
              __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_non_bracket_ind, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 589, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF_SET(__pyx_v_non_bracket_ind, __pyx_t_5);
              __pyx_t_5 = 0;
            }

            /* "_javabridge.pyx":587
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  non_bracket_ind = 1
 *                  try:             # <<<<<<<<<<<<<<
 *                       while sig[non_bracket_ind] == '[':
 *                            non_bracket_ind += 1
 */
          }
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
          goto __pyx_L19_try_end;
          __pyx_L12_error:;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "_javabridge.pyx":590
 *                       while sig[non_bracket_ind] == '[':
 *                            non_bracket_ind += 1
 *                  except IndexError:             # <<<<<<<<<<<<<<
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  if sig[non_bracket_ind] != 'L':
 */
          __pyx_t_22 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
          if (__pyx_t_22) {
            __Pyx_AddTraceback("_javabridge.fill_values", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_8, &__pyx_t_23) < 0) __PYX_ERR(0, 590, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GOTREF(__pyx_t_23);

            /* "_javabridge.pyx":591
 *                            non_bracket_ind += 1
 *                  except IndexError:
 *                       raise ValueError("Bad signature: %s"%orig_sig)             # <<<<<<<<<<<<<<
 *                  if sig[non_bracket_ind] != 'L':
 *                      # An array of primitive type:
 */
            __pyx_t_24 = __Pyx_PyString_Format(__pyx_kp_s_Bad_signature_s, __pyx_v_orig_sig); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 591, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_24);
            __pyx_t_25 = PyTuple_New(1); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 591, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_25);
            __Pyx_GIVEREF(__pyx_t_24);
            PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_t_24);
            __pyx_t_24 = 0;
            __pyx_t_24 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_25, NULL); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 591, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_24);
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_Raise(__pyx_t_24, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
            __PYX_ERR(0, 591, __pyx_L14_except_error)
          }
          goto __pyx_L14_except_error;
          __pyx_L14_except_error:;

          /* "_javabridge.pyx":587
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  non_bracket_ind = 1
 *                  try:             # <<<<<<<<<<<<<<
 *                       while sig[non_bracket_ind] == '[':
 *                            non_bracket_ind += 1
 */
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          goto __pyx_L1_error;
          __pyx_L19_try_end:;
        }

        /* "_javabridge.pyx":592
 *                  except IndexError:
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  if sig[non_bracket_ind] != 'L':             # <<<<<<<<<<<<<<
 *                      # An array of primitive type:
 *                      sig = sig[(non_bracket_ind+1):]
 */
        __pyx_t_23 = PyObject_GetItem(__pyx_v_sig, __pyx_v_non_bracket_ind); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_23);
        __pyx_t_16 = (__Pyx_PyString_Equals(__pyx_t_23, __pyx_n_s_L, Py_NE)); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
        if (__pyx_t_16) {

          /* "_javabridge.pyx":594
 *                  if sig[non_bracket_ind] != 'L':
 *                      # An array of primitive type:
 *                      sig = sig[(non_bracket_ind+1):]             # <<<<<<<<<<<<<<
 *                      continue
 *             sig = sig[sig.find(';')+1:]
 */
          __pyx_t_23 = __Pyx_PyInt_AddObjC(__pyx_v_non_bracket_ind, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_23);
          __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 0, 0, &__pyx_t_23, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
          __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "_javabridge.pyx":595
 *                      # An array of primitive type:
 *                      sig = sig[(non_bracket_ind+1):]
 *                      continue             # <<<<<<<<<<<<<<
 *             sig = sig[sig.find(';')+1:]
 *         else:
 */
          goto __pyx_L3_continue;

          /* "_javabridge.pyx":592
 *                  except IndexError:
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 *                  if sig[non_bracket_ind] != 'L':             # <<<<<<<<<<<<<<
 *                      # An array of primitive type:
 *                      sig = sig[(non_bracket_ind+1):]
 */
        }

        /* "_javabridge.pyx":583
 *                  free(<void *>values)
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':             # <<<<<<<<<<<<<<
 *                  if len(sig) == 1:
 *                       raise ValueError("Bad signature: %s"%orig_sig)
 */
      }

      /* "_javabridge.pyx":596
 *                      sig = sig[(non_bracket_ind+1):]
 *                      continue
 *             sig = sig[sig.find(';')+1:]             # <<<<<<<<<<<<<<
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_find); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_23 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_23);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_23, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
      __pyx_t_23 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 0, 0, &__pyx_t_8, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_23);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_23);
      __pyx_t_23 = 0;

      /* "_javabridge.pyx":571
 *             values[i].d = float(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object             # <<<<<<<<<<<<<<
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg
 */
      goto __pyx_L6;
    }

    /* "_javabridge.pyx":598
 *             sig = sig[sig.find(';')+1:]
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)             # <<<<<<<<<<<<<<
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_23 = __Pyx_PyString_Format(__pyx_kp_s_Unhandled_signature_s, __pyx_v_orig_sig); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_23);
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_23);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_23);
      __pyx_t_23 = 0;
      __pyx_t_23 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_23);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_23;
      __pyx_t_23 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;
    }
    __pyx_L6:;

    /* "_javabridge.pyx":542
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):             # <<<<<<<<<<<<<<
 *         if len(sig) == 0:
 *             free(<void *>values)
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_javabridge.pyx":599
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 *     if len(sig) > 0:             # <<<<<<<<<<<<<<
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 *                          (len(args), orig_sig))
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_sig); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 599, __pyx_L1_error)
  __pyx_t_16 = ((__pyx_t_1 > 0) != 0);
  if (__pyx_t_16) {

    /* "_javabridge.pyx":600
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%             # <<<<<<<<<<<<<<
 *                          (len(args), orig_sig))
 * 
 */
    __Pyx_XDECREF(__pyx_r);

    /* "_javabridge.pyx":601
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 *                          (len(args), orig_sig))             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_VM:
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 601, __pyx_L1_error)
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_23 = PyTuple_New(2); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_23);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_23, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_orig_sig);
    __Pyx_GIVEREF(__pyx_v_orig_sig);
    PyTuple_SET_ITEM(__pyx_t_23, 1, __pyx_v_orig_sig);
    __pyx_t_3 = 0;

    /* "_javabridge.pyx":600
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%             # <<<<<<<<<<<<<<
 *                          (len(args), orig_sig))
 * 
 */
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Too_few_arguments_d_for_signatur, __pyx_t_23); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
    __pyx_t_23 = PyTuple_New(1); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_23);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_23, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_23, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "_javabridge.pyx":599
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 *     if len(sig) > 0:             # <<<<<<<<<<<<<<
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 *                          (len(args), orig_sig))
 */
  }

  /* "_javabridge.pyx":531
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))
 * 
 * cdef fill_values(orig_sig, args, jvalue **pvalues):             # <<<<<<<<<<<<<<
 *     cdef:
 *         jvalue *values
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_AddTraceback("_javabridge.fill_values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbobject);
  __Pyx_XDECREF((PyObject *)__pyx_v_jbclass);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_non_bracket_ind);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":607
 *     cdef JavaVM *vm
 * 
 *     def set_vm(self, capsule):             # <<<<<<<<<<<<<<
 *         '''Set the pointer to the JavaVM
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_1set_vm(PyObject *__pyx_v_self, PyObject *__pyx_v_capsule); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_set_vm[] = "Set the pointer to the JavaVM\n        \n        This is here to handle the case where Java is the boss and Python\n        is being started from Java, e.g. from \n        org.cellprofiler.javabridge.CPython.\n        \n        :param capsule: an encapsulated pointer to the JavaVM\n        ";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_1set_vm(PyObject *__pyx_v_self, PyObject *__pyx_v_capsule) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_vm (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_set_vm(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self), ((PyObject *)__pyx_v_capsule));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_set_vm(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_capsule) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("set_vm", 0);

  /* "_javabridge.pyx":616
 *         :param capsule: an encapsulated pointer to the JavaVM
 *         '''
 *         if not PyCapsule_CheckExact(capsule):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_vm called with something other than a wrapped environment")
 */
  __pyx_t_1 = ((!(PyCapsule_CheckExact(__pyx_v_capsule) != 0)) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":617
 *         '''
 *         if not PyCapsule_CheckExact(capsule):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_vm called with something other than a wrapped environment")
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 617, __pyx_L1_error)

    /* "_javabridge.pyx":616
 *         :param capsule: an encapsulated pointer to the JavaVM
 *         '''
 *         if not PyCapsule_CheckExact(capsule):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_vm called with something other than a wrapped environment")
 */
  }

  /* "_javabridge.pyx":619
 *             raise ValueError(
 *             "set_vm called with something other than a wrapped environment")
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)             # <<<<<<<<<<<<<<
 *         if not self.vm:
 *             raise ValueError(
 */
  __pyx_v_self->vm = ((JavaVM *)PyCapsule_GetPointer(__pyx_v_capsule, NULL));

  /* "_javabridge.pyx":620
 *             "set_vm called with something other than a wrapped environment")
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.vm:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_vm called with non-environment capsule")
 */
  __pyx_t_1 = ((!(__pyx_v_self->vm != 0)) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":621
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.vm:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_vm called with non-environment capsule")
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 621, __pyx_L1_error)

    /* "_javabridge.pyx":620
 *             "set_vm called with something other than a wrapped environment")
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.vm:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_vm called with non-environment capsule")
 */
  }

  /* "_javabridge.pyx":607
 *     cdef JavaVM *vm
 * 
 *     def set_vm(self, capsule):             # <<<<<<<<<<<<<<
 *         '''Set the pointer to the JavaVM
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_VM.set_vm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":624
 *             "set_vm called with non-environment capsule")
 * 
 *     def is_active(self):             # <<<<<<<<<<<<<<
 *         '''Return True if JVM has been started, but not killed'''
 *         return self.vm != NULL
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_3is_active(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_2is_active[] = "Return True if JVM has been started, but not killed";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_3is_active(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_active (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_2is_active(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_2is_active(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("is_active", 0);

  /* "_javabridge.pyx":626
 *     def is_active(self):
 *         '''Return True if JVM has been started, but not killed'''
 *         return self.vm != NULL             # <<<<<<<<<<<<<<
 * 
 *     def create(self, options):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->vm != NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":624
 *             "set_vm called with non-environment capsule")
 * 
 *     def is_active(self):             # <<<<<<<<<<<<<<
 *         '''Return True if JVM has been started, but not killed'''
 *         return self.vm != NULL
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_VM.is_active", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":628
 *         return self.vm != NULL
 * 
 *     def create(self, options):             # <<<<<<<<<<<<<<
 *         '''Create the Java VM'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_5create(PyObject *__pyx_v_self, PyObject *__pyx_v_options); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_4create[] = "Create the Java VM";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_5create(PyObject *__pyx_v_self, PyObject *__pyx_v_options) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_4create(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self), ((PyObject *)__pyx_v_options));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_4create(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options) {
  JavaVMInitArgs __pyx_v_args;
  JNIEnv *__pyx_v_env;
  struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_jenv = 0;
  PyObject *__pyx_v_optionutf8 = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_option = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  char *__pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("create", 0);
  __Pyx_INCREF(__pyx_v_options);

  /* "_javabridge.pyx":635
 *             JB_Env jenv
 * 
 *         args.version = JNI_VERSION_1_4             # <<<<<<<<<<<<<<
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 */
  __pyx_v_args.version = JNI_VERSION_1_4;

  /* "_javabridge.pyx":636
 * 
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)             # <<<<<<<<<<<<<<
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_options); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 636, __pyx_L1_error)
  __pyx_v_args.nOptions = __pyx_t_1;

  /* "_javabridge.pyx":637
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)             # <<<<<<<<<<<<<<
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 */
  __pyx_v_args.options = ((JavaVMOption *)malloc(((sizeof(JavaVMOption)) * __pyx_v_args.nOptions)));

  /* "_javabridge.pyx":638
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 */
  __pyx_t_2 = ((__pyx_v_args.options == NULL) != 0);
  if (__pyx_t_2) {

    /* "_javabridge.pyx":639
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option) for option in options]
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 639, __pyx_L1_error)

    /* "_javabridge.pyx":638
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 */
  }

  /* "_javabridge.pyx":640
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]             # <<<<<<<<<<<<<<
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 *         for i, option in enumerate(options):
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_v_options)) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_4 = __pyx_v_options; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 640, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 640, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 640, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_5(__pyx_t_4);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 640, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_option, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_option);
    __Pyx_GIVEREF(__pyx_v_option);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_option);
    __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_6, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_options, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":641
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings             # <<<<<<<<<<<<<<
 *         for i, option in enumerate(options):
 *             optionutf8.append(option.encode('utf-8'))
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_optionutf8 = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":642
 *         options = [str(option) for option in options]
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 *         for i, option in enumerate(options):             # <<<<<<<<<<<<<<
 *             optionutf8.append(option.encode('utf-8'))
 *             args.options[i].optionString = optionutf8[-1]
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_3 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_options)) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_4 = __pyx_v_options; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 642, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 642, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 642, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 642, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 642, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_5(__pyx_t_4);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 642, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_option, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "_javabridge.pyx":643
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 *         for i, option in enumerate(options):
 *             optionutf8.append(option.encode('utf-8'))             # <<<<<<<<<<<<<<
 *             args.options[i].optionString = optionutf8[-1]
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_option, __pyx_n_s_encode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_optionutf8, __pyx_t_6); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "_javabridge.pyx":644
 *         for i, option in enumerate(options):
 *             optionutf8.append(option.encode('utf-8'))
 *             args.options[i].optionString = optionutf8[-1]             # <<<<<<<<<<<<<<
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)
 */
    __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_v_optionutf8, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_t_6); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) __PYX_ERR(0, 644, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 644, __pyx_L1_error)
    (__pyx_v_args.options[__pyx_t_10]).optionString = __pyx_t_9;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "_javabridge.pyx":642
 *         options = [str(option) for option in options]
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 *         for i, option in enumerate(options):             # <<<<<<<<<<<<<<
 *             optionutf8.append(option.encode('utf-8'))
 *             args.options[i].optionString = optionutf8[-1]
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_javabridge.pyx":645
 *             optionutf8.append(option.encode('utf-8'))
 *             args.options[i].optionString = optionutf8[-1]
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)             # <<<<<<<<<<<<<<
 *         free(args.options)
 *         if result != 0:
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(CreateJavaVM((&__pyx_v_self->vm), ((void **)(&__pyx_v_env)), (&__pyx_v_args))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":646
 *             args.options[i].optionString = optionutf8[-1]
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 */
  free(__pyx_v_args.options);

  /* "_javabridge.pyx":647
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 647, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "_javabridge.pyx":648
 *         free(args.options)
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)             # <<<<<<<<<<<<<<
 *         jenv = JB_Env()
 *         jenv.env = env
 */
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_create_Java_VM_Return, __pyx_v_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 648, __pyx_L1_error)

    /* "_javabridge.pyx":647
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  }

  /* "_javabridge.pyx":649
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()             # <<<<<<<<<<<<<<
 *         jenv.env = env
 *         set_thread_local("env", jenv)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Env), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_jenv = ((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":650
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()
 *         jenv.env = env             # <<<<<<<<<<<<<<
 *         set_thread_local("env", jenv)
 *         return jenv
 */
  __pyx_v_jenv->env = __pyx_v_env;

  /* "_javabridge.pyx":651
 *         jenv = JB_Env()
 *         jenv.env = env
 *         set_thread_local("env", jenv)             # <<<<<<<<<<<<<<
 *         return jenv
 * 
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_set_thread_local); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_11 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_11 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_env, ((PyObject *)__pyx_v_jenv)};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 651, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_env, ((PyObject *)__pyx_v_jenv)};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 651, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 651, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_n_s_env);
    __Pyx_GIVEREF(__pyx_n_s_env);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_11, __pyx_n_s_env);
    __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_jenv));
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_11, ((PyObject *)__pyx_v_jenv));
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 651, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_javabridge.pyx":652
 *         jenv.env = env
 *         set_thread_local("env", jenv)
 *         return jenv             # <<<<<<<<<<<<<<
 * 
 *     def create_mac(self, options, class_name, path_to_libjvm, path_to_libjli):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
  __pyx_r = ((PyObject *)__pyx_v_jenv);
  goto __pyx_L0;

  /* "_javabridge.pyx":628
 *         return self.vm != NULL
 * 
 *     def create(self, options):             # <<<<<<<<<<<<<<
 *         '''Create the Java VM'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("_javabridge.JB_VM.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jenv);
  __Pyx_XDECREF(__pyx_v_optionutf8);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_option);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":654
 *         return jenv
 * 
 *     def create_mac(self, options, class_name, path_to_libjvm, path_to_libjli):             # <<<<<<<<<<<<<<
 *         '''Create the Java VM on OS/X in a different thread
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_7create_mac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_6create_mac[] = "Create the Java VM on OS/X in a different thread\n        \n        On the Mac, (assuming this works), you need to start a PThread \n        and do so in a very particular manner if you ever want to run UI\n        code in Java and Python. This creates that thread and it then runs\n        a runnable.\n        \n        org.cellprofiler.runnablequeue.RunnableQueue is a class that uses\n        a queue to ferry runnables to this main thread. You can use that\n        and then call RunnableQueue's static methods to run things on the\n        main thread.\n        \n        You should run this on its own thread since it will not return until\n        after the JVM exits.\n        \n        options - the option strings\n        \n        class_name - the name of the Runnable to run on the Java main thread\n        \n        path_to_libjvm - path to libjvm.dylib\n        \n        path_to_libjli - path to libjli.dylib\n        ";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_7create_mac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_options = 0;
  PyObject *__pyx_v_class_name = 0;
  PyObject *__pyx_v_path_to_libjvm = 0;
  PyObject *__pyx_v_path_to_libjli = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_mac (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_options,&__pyx_n_s_class_name,&__pyx_n_s_path_to_libjvm,&__pyx_n_s_path_to_libjli,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_options)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_class_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_mac", 1, 4, 4, 1); __PYX_ERR(0, 654, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_path_to_libjvm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_mac", 1, 4, 4, 2); __PYX_ERR(0, 654, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_path_to_libjli)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_mac", 1, 4, 4, 3); __PYX_ERR(0, 654, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_mac") < 0)) __PYX_ERR(0, 654, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_options = values[0];
    __pyx_v_class_name = values[1];
    __pyx_v_path_to_libjvm = values[2];
    __pyx_v_path_to_libjli = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_mac", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 654, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_VM.create_mac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_6create_mac(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self), __pyx_v_options, __pyx_v_class_name, __pyx_v_path_to_libjvm, __pyx_v_path_to_libjli);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_6create_mac(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options, PyObject *__pyx_v_class_name, PyObject *__pyx_v_path_to_libjvm, PyObject *__pyx_v_path_to_libjli) {
  JavaVMInitArgs __pyx_v_args;
  int __pyx_v_result;
  char *__pyx_v_pclass_name;
  char *__pyx_v_ppath_to_libjvm;
  char *__pyx_v_ppath_to_libjli;
  JavaVM **__pyx_v_pvm;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_option = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  __Pyx_RefNannySetupContext("create_mac", 0);
  __Pyx_INCREF(__pyx_v_options);
  __Pyx_INCREF(__pyx_v_class_name);
  __Pyx_INCREF(__pyx_v_path_to_libjvm);
  __Pyx_INCREF(__pyx_v_path_to_libjli);

  /* "_javabridge.pyx":678
 *         path_to_libjli - path to libjli.dylib
 *         '''
 *         class_name = str(class_name).encode("utf-8")             # <<<<<<<<<<<<<<
 *         path_to_libjvm = str(path_to_libjvm).encode("utf-8")
 *         path_to_libjli = str(path_to_libjli).encode("utf-8")
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_class_name);
  __Pyx_GIVEREF(__pyx_v_class_name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_class_name);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_class_name, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":679
 *         '''
 *         class_name = str(class_name).encode("utf-8")
 *         path_to_libjvm = str(path_to_libjvm).encode("utf-8")             # <<<<<<<<<<<<<<
 *         path_to_libjli = str(path_to_libjli).encode("utf-8")
 *         cdef:
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_path_to_libjvm);
  __Pyx_GIVEREF(__pyx_v_path_to_libjvm);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_path_to_libjvm);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_encode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_path_to_libjvm, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":680
 *         class_name = str(class_name).encode("utf-8")
 *         path_to_libjvm = str(path_to_libjvm).encode("utf-8")
 *         path_to_libjli = str(path_to_libjli).encode("utf-8")             # <<<<<<<<<<<<<<
 *         cdef:
 *             JavaVMInitArgs args
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_path_to_libjli);
  __Pyx_GIVEREF(__pyx_v_path_to_libjli);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_path_to_libjli);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_path_to_libjli, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":686
 *             JB_Env jenv
 *             int result
 *             char *pclass_name = class_name             # <<<<<<<<<<<<<<
 *             char *ppath_to_libjvm = path_to_libjvm
 *             char *ppath_to_libjli = path_to_libjli
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_class_name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 686, __pyx_L1_error)
  __pyx_v_pclass_name = __pyx_t_3;

  /* "_javabridge.pyx":687
 *             int result
 *             char *pclass_name = class_name
 *             char *ppath_to_libjvm = path_to_libjvm             # <<<<<<<<<<<<<<
 *             char *ppath_to_libjli = path_to_libjli
 *             JavaVM **pvm = &self.vm
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_path_to_libjvm); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 687, __pyx_L1_error)
  __pyx_v_ppath_to_libjvm = __pyx_t_3;

  /* "_javabridge.pyx":688
 *             char *pclass_name = class_name
 *             char *ppath_to_libjvm = path_to_libjvm
 *             char *ppath_to_libjli = path_to_libjli             # <<<<<<<<<<<<<<
 *             JavaVM **pvm = &self.vm
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_path_to_libjli); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_v_ppath_to_libjli = __pyx_t_3;

  /* "_javabridge.pyx":689
 *             char *ppath_to_libjvm = path_to_libjvm
 *             char *ppath_to_libjli = path_to_libjli
 *             JavaVM **pvm = &self.vm             # <<<<<<<<<<<<<<
 * 
 *         args.version = JNI_VERSION_1_4
 */
  __pyx_v_pvm = (&__pyx_v_self->vm);

  /* "_javabridge.pyx":691
 *             JavaVM **pvm = &self.vm
 * 
 *         args.version = JNI_VERSION_1_4             # <<<<<<<<<<<<<<
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 */
  __pyx_v_args.version = JNI_VERSION_1_4;

  /* "_javabridge.pyx":692
 * 
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)             # <<<<<<<<<<<<<<
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 */
  __pyx_t_4 = PyObject_Length(__pyx_v_options); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __pyx_v_args.nOptions = __pyx_t_4;

  /* "_javabridge.pyx":693
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)             # <<<<<<<<<<<<<<
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 */
  __pyx_v_args.options = ((JavaVMOption *)malloc(((sizeof(JavaVMOption)) * __pyx_v_args.nOptions)));

  /* "_javabridge.pyx":694
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option).encode("utf-8") for option in options]
 */
  __pyx_t_5 = ((__pyx_v_args.options == NULL) != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":695
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option).encode("utf-8") for option in options]
 *         for i, option in enumerate(options):
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 695, __pyx_L1_error)

    /* "_javabridge.pyx":694
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option).encode("utf-8") for option in options]
 */
  }

  /* "_javabridge.pyx":696
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option).encode("utf-8") for option in options]             # <<<<<<<<<<<<<<
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_v_options)) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_1 = __pyx_v_options; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 696, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_7); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 696, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_7); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 696, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 696, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_option, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_option);
    __Pyx_GIVEREF(__pyx_v_option);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_option);
    __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)(&PyString_Type)), __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_encode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_options, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":697
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option).encode("utf-8") for option in options]
 *         for i, option in enumerate(options):             # <<<<<<<<<<<<<<
 *             args.options[i].optionString = option
 *         with nogil:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_2 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_options)) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_1 = __pyx_v_options; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 697, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_8); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 697, __pyx_L1_error)
        #else
        __pyx_t_8 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 697, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_8); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 697, __pyx_L1_error)
        #else
        __pyx_t_8 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 697, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      }
    } else {
      __pyx_t_8 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_8)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 697, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_XDECREF_SET(__pyx_v_option, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
    __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "_javabridge.pyx":698
 *         options = [str(option).encode("utf-8") for option in options]
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option             # <<<<<<<<<<<<<<
 *         with nogil:
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)
 */
    __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_option); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 698, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 698, __pyx_L1_error)
    (__pyx_v_args.options[__pyx_t_9]).optionString = __pyx_t_3;

    /* "_javabridge.pyx":697
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option).encode("utf-8") for option in options]
 *         for i, option in enumerate(options):             # <<<<<<<<<<<<<<
 *             args.options[i].optionString = option
 *         with nogil:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_javabridge.pyx":699
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)
 *         free(args.options)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      #endif
      /*try:*/ {

        /* "_javabridge.pyx":700
 *             args.options[i].optionString = option
 *         with nogil:
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)             # <<<<<<<<<<<<<<
 *         free(args.options)
 *         if result != 0:
 */
        __pyx_v_result = MacStartVM(__pyx_v_pvm, (&__pyx_v_args), __pyx_v_pclass_name, __pyx_v_ppath_to_libjvm, __pyx_v_ppath_to_libjli);
      }

      /* "_javabridge.pyx":699
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)
 *         free(args.options)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "_javabridge.pyx":701
 *         with nogil:
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)
 *         free(args.options)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 */
  free(__pyx_v_args.options);

  /* "_javabridge.pyx":702
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)
 *         free(args.options)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 * 
 */
  __pyx_t_5 = ((__pyx_v_result != 0) != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":703
 *         free(args.options)
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)             # <<<<<<<<<<<<<<
 * 
 *     def attach(self):
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_create_Java_VM_Return, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 703, __pyx_L1_error)

    /* "_javabridge.pyx":702
 *             result = MacStartVM(pvm, &args, pclass_name, ppath_to_libjvm, ppath_to_libjli)
 *         free(args.options)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 * 
 */
  }

  /* "_javabridge.pyx":654
 *         return jenv
 * 
 *     def create_mac(self, options, class_name, path_to_libjvm, path_to_libjli):             # <<<<<<<<<<<<<<
 *         '''Create the Java VM on OS/X in a different thread
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("_javabridge.JB_VM.create_mac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_option);
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XDECREF(__pyx_v_class_name);
  __Pyx_XDECREF(__pyx_v_path_to_libjvm);
  __Pyx_XDECREF(__pyx_v_path_to_libjli);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":705
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 * 
 *     def attach(self):             # <<<<<<<<<<<<<<
 *         '''Attach this thread to the VM returning an environment'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_9attach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_8attach[] = "Attach this thread to the VM returning an environment";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_9attach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("attach (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_8attach(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_8attach(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self) {
  JNIEnv *__pyx_v_env;
  struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_jenv = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("attach", 0);

  /* "_javabridge.pyx":710
 *             JNIEnv *env
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 */
  __pyx_t_1 = __Pyx_PyInt_From_jint((__pyx_v_self->vm[0])->AttachCurrentThread(__pyx_v_self->vm, ((void **)(&__pyx_v_env)), NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":711
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "_javabridge.pyx":712
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)             # <<<<<<<<<<<<<<
 *         jenv = JB_Env()
 *         jenv.env = env
 */
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_attach_to_current_thre, __pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 712, __pyx_L1_error)

    /* "_javabridge.pyx":711
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  }

  /* "_javabridge.pyx":713
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()             # <<<<<<<<<<<<<<
 *         jenv.env = env
 *         return jenv
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Env), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jenv = ((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":714
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 *         jenv.env = env             # <<<<<<<<<<<<<<
 *         return jenv
 * 
 */
  __pyx_v_jenv->env = __pyx_v_env;

  /* "_javabridge.pyx":715
 *         jenv = JB_Env()
 *         jenv.env = env
 *         return jenv             # <<<<<<<<<<<<<<
 * 
 *     def attach_as_daemon(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
  __pyx_r = ((PyObject *)__pyx_v_jenv);
  goto __pyx_L0;

  /* "_javabridge.pyx":705
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 * 
 *     def attach(self):             # <<<<<<<<<<<<<<
 *         '''Attach this thread to the VM returning an environment'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_javabridge.JB_VM.attach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jenv);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":717
 *         return jenv
 * 
 *     def attach_as_daemon(self):             # <<<<<<<<<<<<<<
 *         '''Attach this thread as a daemon thread'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_11attach_as_daemon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_10attach_as_daemon[] = "Attach this thread as a daemon thread";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_11attach_as_daemon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("attach_as_daemon (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_10attach_as_daemon(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_10attach_as_daemon(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self) {
  JNIEnv *__pyx_v_env;
  struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_jenv = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("attach_as_daemon", 0);

  /* "_javabridge.pyx":722
 *             JNIEnv *env
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 */
  __pyx_t_1 = __Pyx_PyInt_From_jint((__pyx_v_self->vm[0])->AttachCurrentThreadAsDaemon(__pyx_v_self->vm, ((void *)(&__pyx_v_env)), NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":723
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 723, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "_javabridge.pyx":724
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)             # <<<<<<<<<<<<<<
 *         jenv = JB_Env()
 *         jenv.env = env
 */
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_attach_to_current_thre, __pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 724, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 724, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 724, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 724, __pyx_L1_error)

    /* "_javabridge.pyx":723
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  }

  /* "_javabridge.pyx":725
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()             # <<<<<<<<<<<<<<
 *         jenv.env = env
 *         return jenv
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Env), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jenv = ((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":726
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 *         jenv.env = env             # <<<<<<<<<<<<<<
 *         return jenv
 * 
 */
  __pyx_v_jenv->env = __pyx_v_env;

  /* "_javabridge.pyx":727
 *         jenv = JB_Env()
 *         jenv.env = env
 *         return jenv             # <<<<<<<<<<<<<<
 * 
 *     def detach(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
  __pyx_r = ((PyObject *)__pyx_v_jenv);
  goto __pyx_L0;

  /* "_javabridge.pyx":717
 *         return jenv
 * 
 *     def attach_as_daemon(self):             # <<<<<<<<<<<<<<
 *         '''Attach this thread as a daemon thread'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_javabridge.JB_VM.attach_as_daemon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jenv);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":729
 *         return jenv
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         '''Detach this thread from the VM'''
 *         self.vm[0].DetachCurrentThread(self.vm)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_13detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_5JB_VM_12detach[] = "Detach this thread from the VM";
static PyObject *__pyx_pw_11_javabridge_5JB_VM_13detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detach (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_12detach(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_12detach(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detach", 0);

  /* "_javabridge.pyx":731
 *     def detach(self):
 *         '''Detach this thread from the VM'''
 *         self.vm[0].DetachCurrentThread(self.vm)             # <<<<<<<<<<<<<<
 * 
 *     def destroy(self):
 */
  (__pyx_v_self->vm[0])->DetachCurrentThread(__pyx_v_self->vm);

  /* "_javabridge.pyx":729
 *         return jenv
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         '''Detach this thread from the VM'''
 *         self.vm[0].DetachCurrentThread(self.vm)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":733
 *         self.vm[0].DetachCurrentThread(self.vm)
 * 
 *     def destroy(self):             # <<<<<<<<<<<<<<
 *         if self.vm != NULL:
 *             StopVM(self.vm)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_5JB_VM_15destroy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11_javabridge_5JB_VM_15destroy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("destroy (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_5JB_VM_14destroy(((struct __pyx_obj_11_javabridge_JB_VM *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_5JB_VM_14destroy(struct __pyx_obj_11_javabridge_JB_VM *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("destroy", 0);

  /* "_javabridge.pyx":734
 * 
 *     def destroy(self):
 *         if self.vm != NULL:             # <<<<<<<<<<<<<<
 *             StopVM(self.vm)
 *             self.vm = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->vm != NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":735
 *     def destroy(self):
 *         if self.vm != NULL:
 *             StopVM(self.vm)             # <<<<<<<<<<<<<<
 *             self.vm = NULL
 * 
 */
    StopVM(__pyx_v_self->vm);

    /* "_javabridge.pyx":736
 *         if self.vm != NULL:
 *             StopVM(self.vm)
 *             self.vm = NULL             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_Env:
 */
    __pyx_v_self->vm = NULL;

    /* "_javabridge.pyx":734
 * 
 *     def destroy(self):
 *         if self.vm != NULL:             # <<<<<<<<<<<<<<
 *             StopVM(self.vm)
 *             self.vm = NULL
 */
  }

  /* "_javabridge.pyx":733
 *         self.vm[0].DetachCurrentThread(self.vm)
 * 
 *     def destroy(self):             # <<<<<<<<<<<<<<
 *         if self.vm != NULL:
 *             StopVM(self.vm)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":747
 *         JNIEnv *env
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.env = NULL
 * 
 */

/* Python wrapper */
static int __pyx_pw_11_javabridge_6JB_Env_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11_javabridge_6JB_Env_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env___init__(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11_javabridge_6JB_Env___init__(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "_javabridge.pyx":748
 * 
 *     def __init__(self):
 *         self.env = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_v_self->env = NULL;

  /* "_javabridge.pyx":747
 *         JNIEnv *env
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.env = NULL
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":750
 *         self.env = NULL
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11_javabridge_6JB_Env_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_2__repr__(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_2__repr__(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "_javabridge.pyx":751
 * 
 *     def __repr__(self):
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))             # <<<<<<<<<<<<<<
 * 
 *     def set_env(self, capsule):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((size_t)__pyx_v_self->env)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_JB_Env_at_0x_x, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":750
 *         self.env = NULL
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":753
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 * 
 *     def set_env(self, capsule):             # <<<<<<<<<<<<<<
 *         '''Set the JNIEnv to a memory address
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_5set_env(PyObject *__pyx_v_self, PyObject *__pyx_v_capsule); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_4set_env[] = "Set the JNIEnv to a memory address\n        \n        address - address as an integer representation of a string\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_5set_env(PyObject *__pyx_v_self, PyObject *__pyx_v_capsule) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_env (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_4set_env(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_capsule));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_4set_env(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_capsule) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("set_env", 0);

  /* "_javabridge.pyx":758
 *         address - address as an integer representation of a string
 *         '''
 *         if not PyCapsule_CheckExact(capsule):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_env called with something other than a wrapped environment")
 */
  __pyx_t_1 = ((!(PyCapsule_CheckExact(__pyx_v_capsule) != 0)) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":759
 *         '''
 *         if not PyCapsule_CheckExact(capsule):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_env called with something other than a wrapped environment")
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 759, __pyx_L1_error)

    /* "_javabridge.pyx":758
 *         address - address as an integer representation of a string
 *         '''
 *         if not PyCapsule_CheckExact(capsule):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_env called with something other than a wrapped environment")
 */
  }

  /* "_javabridge.pyx":761
 *             raise ValueError(
 *             "set_env called with something other than a wrapped environment")
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)             # <<<<<<<<<<<<<<
 *         if not self.env:
 *             raise ValueError(
 */
  __pyx_v_self->env = ((JNIEnv *)PyCapsule_GetPointer(__pyx_v_capsule, NULL));

  /* "_javabridge.pyx":762
 *             "set_env called with something other than a wrapped environment")
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.env:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_env called with non-environment capsule")
 */
  __pyx_t_1 = ((!(__pyx_v_self->env != 0)) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":763
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.env:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_env called with non-environment capsule")
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 763, __pyx_L1_error)

    /* "_javabridge.pyx":762
 *             "set_env called with something other than a wrapped environment")
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.env:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *             "set_env called with non-environment capsule")
 */
  }

  /* "_javabridge.pyx":753
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 * 
 *     def set_env(self, capsule):             # <<<<<<<<<<<<<<
 *         '''Set the JNIEnv to a memory address
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_env", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":766
 *             "set_env called with non-environment capsule")
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.env = NULL
 * 
 */

/* Python wrapper */
static void __pyx_pw_11_javabridge_6JB_Env_7__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_11_javabridge_6JB_Env_7__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_11_javabridge_6JB_Env_6__dealloc__(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_11_javabridge_6JB_Env_6__dealloc__(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "_javabridge.pyx":767
 * 
 *     def __dealloc__(self):
 *         self.env = NULL             # <<<<<<<<<<<<<<
 * 
 *     def dealloc_jobject(self, JB_Object jbo):
 */
  __pyx_v_self->env = NULL;

  /* "_javabridge.pyx":766
 *             "set_env called with non-environment capsule")
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.env = NULL
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "_javabridge.pyx":769
 *         self.env = NULL
 * 
 *     def dealloc_jobject(self, JB_Object jbo):             # <<<<<<<<<<<<<<
 *         '''Deallocate an object as it goes out of scope
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_9dealloc_jobject(PyObject *__pyx_v_self, PyObject *__pyx_v_jbo); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_8dealloc_jobject[] = "Deallocate an object as it goes out of scope\n        \n        DON'T call this externally.\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_9dealloc_jobject(PyObject *__pyx_v_self, PyObject *__pyx_v_jbo) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dealloc_jobject (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_jbo), __pyx_ptype_11_javabridge_JB_Object, 1, "jbo", 0))) __PYX_ERR(0, 769, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_8dealloc_jobject(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_jbo));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_8dealloc_jobject(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dealloc_jobject", 0);

  /* "_javabridge.pyx":774
 *         DON'T call this externally.
 *         '''
 *         self.env[0].DeleteGlobalRef(self.env, jbo.o)             # <<<<<<<<<<<<<<
 *         jbo.gc_collect = False
 * 
 */
  (__pyx_v_self->env[0])->DeleteGlobalRef(__pyx_v_self->env, __pyx_v_jbo->o);

  /* "_javabridge.pyx":775
 *         '''
 *         self.env[0].DeleteGlobalRef(self.env, jbo.o)
 *         jbo.gc_collect = False             # <<<<<<<<<<<<<<
 * 
 *     def get_version(self):
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_jbo->gc_collect);
  __Pyx_DECREF(__pyx_v_jbo->gc_collect);
  __pyx_v_jbo->gc_collect = Py_False;

  /* "_javabridge.pyx":769
 *         self.env = NULL
 * 
 *     def dealloc_jobject(self, JB_Object jbo):             # <<<<<<<<<<<<<<
 *         '''Deallocate an object as it goes out of scope
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":777
 *         jbo.gc_collect = False
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         '''Return the version number as a major / minor version tuple'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_11get_version(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_10get_version[] = "Return the version number as a major / minor version tuple";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_11get_version(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_version (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_10get_version(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_10get_version(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  int __pyx_v_version;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("get_version", 0);

  /* "_javabridge.pyx":781
 *         cdef:
 *             int version
 *         version = self.env[0].GetVersion(self.env)             # <<<<<<<<<<<<<<
 *         return (int(version / 65536), version % 65536)
 * 
 */
  __pyx_v_version = (__pyx_v_self->env[0])->GetVersion(__pyx_v_self->env);

  /* "_javabridge.pyx":782
 *             int version
 *         version = self.env[0].GetVersion(self.env)
 *         return (int(version / 65536), version % 65536)             # <<<<<<<<<<<<<<
 * 
 *     def find_class(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_div_long(__pyx_v_version, 0x10000)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&PyInt_Type)), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_long(__Pyx_mod_long(__pyx_v_version, 0x10000)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":777
 *         jbo.gc_collect = False
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         '''Return the version number as a major / minor version tuple'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":784
 *         return (int(version / 65536), version % 65536)
 * 
 *     def find_class(self, name):             # <<<<<<<<<<<<<<
 *         '''Find a Java class by name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_13find_class(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_12find_class[] = "Find a Java class by name\n\n        :param name: the class name with \"/\" as the path separator, e.g. \"java/lang/String\"\n        :return: a Java class object suitable for calls such as :py:meth:`.get_method_id`\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_13find_class(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_class (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_12find_class(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_12find_class(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_name) {
  jclass __pyx_v_c;
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_result = 0;
  PyObject *__pyx_v_utf8name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("find_class", 0);

  /* "_javabridge.pyx":793
 *             jclass c
 *             JB_Class result
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         c = self.env[0].FindClass(self.env, utf8name)
 *         if c == NULL:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_utf8name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":794
 *             JB_Class result
 *         utf8name = name.encode('utf-8')
 *         c = self.env[0].FindClass(self.env, utf8name)             # <<<<<<<<<<<<<<
 *         if c == NULL:
 *             print "Failed to get class "+name
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_utf8name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 794, __pyx_L1_error)
  __pyx_v_c = (__pyx_v_self->env[0])->FindClass(__pyx_v_self->env, __pyx_t_3);

  /* "_javabridge.pyx":795
 *         utf8name = name.encode('utf-8')
 *         c = self.env[0].FindClass(self.env, utf8name)
 *         if c == NULL:             # <<<<<<<<<<<<<<
 *             print "Failed to get class "+name
 *             return
 */
  __pyx_t_4 = ((__pyx_v_c == NULL) != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":796
 *         c = self.env[0].FindClass(self.env, utf8name)
 *         if c == NULL:
 *             print "Failed to get class "+name             # <<<<<<<<<<<<<<
 *             return
 *         result = JB_Class()
 */
    __pyx_t_2 = PyNumber_Add(__pyx_kp_s_Failed_to_get_class, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "_javabridge.pyx":797
 *         if c == NULL:
 *             print "Failed to get class "+name
 *             return             # <<<<<<<<<<<<<<
 *         result = JB_Class()
 *         result.c = c
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":795
 *         utf8name = name.encode('utf-8')
 *         c = self.env[0].FindClass(self.env, utf8name)
 *         if c == NULL:             # <<<<<<<<<<<<<<
 *             print "Failed to get class "+name
 *             return
 */
  }

  /* "_javabridge.pyx":798
 *             print "Failed to get class "+name
 *             return
 *         result = JB_Class()             # <<<<<<<<<<<<<<
 *         result.c = c
 *         return result
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Class), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((struct __pyx_obj_11_javabridge_JB_Class *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":799
 *             return
 *         result = JB_Class()
 *         result.c = c             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_v_result->c = __pyx_v_c;

  /* "_javabridge.pyx":800
 *         result = JB_Class()
 *         result.c = c
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_object_class(self, JB_Object o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":784
 *         return (int(version / 65536), version % 65536)
 * 
 *     def find_class(self, name):             # <<<<<<<<<<<<<<
 *         '''Find a Java class by name
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.find_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_utf8name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":802
 *         return result
 * 
 *     def get_object_class(self, JB_Object o):             # <<<<<<<<<<<<<<
 *         '''Return the class for an object
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_15get_object_class(PyObject *__pyx_v_self, PyObject *__pyx_v_o); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_14get_object_class[] = "Return the class for an object\n        \n        :param o: a Java object\n        :return: a Java class object suitable for calls such as :py:meth:`.get_method_id`\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_15get_object_class(PyObject *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_class (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 802, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_14get_object_class(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_o));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_14get_object_class(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o) {
  jclass __pyx_v_c;
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_object_class", 0);

  /* "_javabridge.pyx":811
 *             jclass c
 *             JB_Class result
 *         c = self.env[0].GetObjectClass(self.env, o.o)             # <<<<<<<<<<<<<<
 *         result = JB_Class()
 *         result.c = c
 */
  __pyx_v_c = (__pyx_v_self->env[0])->GetObjectClass(__pyx_v_self->env, __pyx_v_o->o);

  /* "_javabridge.pyx":812
 *             JB_Class result
 *         c = self.env[0].GetObjectClass(self.env, o.o)
 *         result = JB_Class()             # <<<<<<<<<<<<<<
 *         result.c = c
 *         return result
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Class), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((struct __pyx_obj_11_javabridge_JB_Class *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":813
 *         c = self.env[0].GetObjectClass(self.env, o.o)
 *         result = JB_Class()
 *         result.c = c             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_v_result->c = __pyx_v_c;

  /* "_javabridge.pyx":814
 *         result = JB_Class()
 *         result.c = c
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def is_instance_of(self, JB_Object o, JB_Class c):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":802
 *         return result
 * 
 *     def get_object_class(self, JB_Object o):             # <<<<<<<<<<<<<<
 *         '''Return the class for an object
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_object_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":816
 *         return result
 * 
 *     def is_instance_of(self, JB_Object o, JB_Class c):             # <<<<<<<<<<<<<<
 *         '''Return True if object is instance of class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_17is_instance_of(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_16is_instance_of[] = "Return True if object is instance of class\n        \n        :param o: a Java object\n        :param c: a Java class\n        :return: True if o is an instance of c otherwise False\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_17is_instance_of(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_instance_of (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_c,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("is_instance_of", 1, 2, 2, 1); __PYX_ERR(0, 816, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "is_instance_of") < 0)) __PYX_ERR(0, 816, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_instance_of", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 816, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.is_instance_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 816, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 816, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_16is_instance_of(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_c);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_16is_instance_of(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c) {
  jboolean __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("is_instance_of", 0);

  /* "_javabridge.pyx":823
 *         :return: True if o is an instance of c otherwise False
 *         '''
 *         result = self.env[0].IsInstanceOf(self.env, o.o, c.c)             # <<<<<<<<<<<<<<
 *         return result != 0
 * 
 */
  __pyx_v_result = (__pyx_v_self->env[0])->IsInstanceOf(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_c->c);

  /* "_javabridge.pyx":824
 *         '''
 *         result = self.env[0].IsInstanceOf(self.env, o.o, c.c)
 *         return result != 0             # <<<<<<<<<<<<<<
 * 
 *     def exception_occurred(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_result != 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":816
 *         return result
 * 
 *     def is_instance_of(self, JB_Object o, JB_Class c):             # <<<<<<<<<<<<<<
 *         '''Return True if object is instance of class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.is_instance_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":826
 *         return result != 0
 * 
 *     def exception_occurred(self):             # <<<<<<<<<<<<<<
 *         '''Return a throwable if an exception occurred or None'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_19exception_occurred(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_18exception_occurred[] = "Return a throwable if an exception occurred or None";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_19exception_occurred(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_occurred (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_18exception_occurred(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_18exception_occurred(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  jobject __pyx_v_t;
  PyObject *__pyx_v_o = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("exception_occurred", 0);

  /* "_javabridge.pyx":830
 *         cdef:
 *             jobject t
 *         t = self.env[0].ExceptionOccurred(self.env)             # <<<<<<<<<<<<<<
 *         if t == NULL:
 *             return
 */
  __pyx_v_t = (__pyx_v_self->env[0])->ExceptionOccurred(__pyx_v_self->env);

  /* "_javabridge.pyx":831
 *             jobject t
 *         t = self.env[0].ExceptionOccurred(self.env)
 *         if t == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         o, e = make_jb_object(self, t)
 */
  __pyx_t_1 = ((__pyx_v_t == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":832
 *         t = self.env[0].ExceptionOccurred(self.env)
 *         if t == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         o, e = make_jb_object(self, t)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":831
 *             jobject t
 *         t = self.env[0].ExceptionOccurred(self.env)
 *         if t == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         o, e = make_jb_object(self, t)
 */
  }

  /* "_javabridge.pyx":833
 *         if t == NULL:
 *             return
 *         o, e = make_jb_object(self, t)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_2 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 833, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 833, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_o = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":834
 *             return
 *         o, e = make_jb_object(self, t)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return o
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":835
 *         o, e = make_jb_object(self, t)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return o
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 835, __pyx_L1_error)

    /* "_javabridge.pyx":834
 *             return
 *         o, e = make_jb_object(self, t)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return o
 */
  }

  /* "_javabridge.pyx":836
 *         if e is not None:
 *             raise e
 *         return o             # <<<<<<<<<<<<<<
 * 
 *     def exception_describe(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_o);
  __pyx_r = __pyx_v_o;
  goto __pyx_L0;

  /* "_javabridge.pyx":826
 *         return result != 0
 * 
 *     def exception_occurred(self):             # <<<<<<<<<<<<<<
 *         '''Return a throwable if an exception occurred or None'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.JB_Env.exception_occurred", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":838
 *         return o
 * 
 *     def exception_describe(self):             # <<<<<<<<<<<<<<
 *         '''Print a stack trace of the last exception to stderr'''
 *         self.env[0].ExceptionDescribe(self.env)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_21exception_describe(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_20exception_describe[] = "Print a stack trace of the last exception to stderr";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_21exception_describe(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_describe (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_20exception_describe(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_20exception_describe(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_describe", 0);

  /* "_javabridge.pyx":840
 *     def exception_describe(self):
 *         '''Print a stack trace of the last exception to stderr'''
 *         self.env[0].ExceptionDescribe(self.env)             # <<<<<<<<<<<<<<
 * 
 *     def exception_clear(self):
 */
  (__pyx_v_self->env[0])->ExceptionDescribe(__pyx_v_self->env);

  /* "_javabridge.pyx":838
 *         return o
 * 
 *     def exception_describe(self):             # <<<<<<<<<<<<<<
 *         '''Print a stack trace of the last exception to stderr'''
 *         self.env[0].ExceptionDescribe(self.env)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":842
 *         self.env[0].ExceptionDescribe(self.env)
 * 
 *     def exception_clear(self):             # <<<<<<<<<<<<<<
 *         '''Clear the current exception'''
 *         self.env[0].ExceptionClear(self.env)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_23exception_clear(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_22exception_clear[] = "Clear the current exception";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_23exception_clear(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_clear (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_22exception_clear(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_22exception_clear(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_clear", 0);

  /* "_javabridge.pyx":844
 *     def exception_clear(self):
 *         '''Clear the current exception'''
 *         self.env[0].ExceptionClear(self.env)             # <<<<<<<<<<<<<<
 * 
 *     def get_method_id(self, JB_Class c, name, sig):
 */
  (__pyx_v_self->env[0])->ExceptionClear(__pyx_v_self->env);

  /* "_javabridge.pyx":842
 *         self.env[0].ExceptionDescribe(self.env)
 * 
 *     def exception_clear(self):             # <<<<<<<<<<<<<<
 *         '''Clear the current exception'''
 *         self.env[0].ExceptionClear(self.env)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":846
 *         self.env[0].ExceptionClear(self.env)
 * 
 *     def get_method_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Find the method ID for a method on a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_25get_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_24get_method_id[] = "Find the method ID for a method on a class\n\n        :param c: a class retrieved by find_class or get_object_class\n        :param name: the method name\n        :param sig: the calling signature,\n                    e.g. \"(ILjava/lang/String;)D\" is a function that\n                    returns a double and takes an integer, a long and\n                    a string as arguments.\n\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_25get_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sig = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_method_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_name,&__pyx_n_s_sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_method_id", 1, 3, 3, 1); __PYX_ERR(0, 846, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_method_id", 1, 3, 3, 2); __PYX_ERR(0, 846, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_method_id") < 0)) __PYX_ERR(0, 846, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = values[1];
    __pyx_v_sig = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_method_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 846, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 846, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_24get_method_id(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_24get_method_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig) {
  jmethodID __pyx_v_id;
  struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_result = 0;
  PyObject *__pyx_v_utf8name = NULL;
  PyObject *__pyx_v_utf8sig = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  char *__pyx_t_5;
  char *__pyx_t_6;
  __Pyx_RefNannySetupContext("get_method_id", 0);

  /* "_javabridge.pyx":860
 *             jmethodID id
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 *         if c is None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_utf8name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":861
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_encode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_utf8sig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":862
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')
 *         if c is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_t_3 = (((PyObject *)__pyx_v_c) == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":863
 *         utf8sig = sig.encode('utf-8')
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 863, __pyx_L1_error)

    /* "_javabridge.pyx":862
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')
 *         if c is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 */
  }

  /* "_javabridge.pyx":864
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return
 */
  __pyx_t_5 = __Pyx_PyObject_AsString(__pyx_v_utf8name); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) __PYX_ERR(0, 864, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_AsString(__pyx_v_utf8sig); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 864, __pyx_L1_error)
  __pyx_v_id = (__pyx_v_self->env[0])->GetMethodID(__pyx_v_self->env, __pyx_v_c->c, __pyx_t_5, __pyx_t_6);

  /* "_javabridge.pyx":865
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  __pyx_t_4 = ((__pyx_v_id == NULL) != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":866
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result = __JB_MethodID()
 *         result.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":865
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  }

  /* "_javabridge.pyx":867
 *         if id == NULL:
 *             return
 *         result = __JB_MethodID()             # <<<<<<<<<<<<<<
 *         result.id = id
 *         result.sig = sig
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge___JB_MethodID), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((struct __pyx_obj_11_javabridge___JB_MethodID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":868
 *             return
 *         result = __JB_MethodID()
 *         result.id = id             # <<<<<<<<<<<<<<
 *         result.sig = sig
 *         result.is_static = False
 */
  __pyx_v_result->id = __pyx_v_id;

  /* "_javabridge.pyx":869
 *         result = __JB_MethodID()
 *         result.id = id
 *         result.sig = sig             # <<<<<<<<<<<<<<
 *         result.is_static = False
 *         return result
 */
  __Pyx_INCREF(__pyx_v_sig);
  __Pyx_GIVEREF(__pyx_v_sig);
  __Pyx_GOTREF(__pyx_v_result->sig);
  __Pyx_DECREF(__pyx_v_result->sig);
  __pyx_v_result->sig = __pyx_v_sig;

  /* "_javabridge.pyx":870
 *         result.id = id
 *         result.sig = sig
 *         result.is_static = False             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_result->is_static);
  __Pyx_DECREF(__pyx_v_result->is_static);
  __pyx_v_result->is_static = Py_False;

  /* "_javabridge.pyx":871
 *         result.sig = sig
 *         result.is_static = False
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_static_method_id(self, JB_Class c, name, sig):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":846
 *         self.env[0].ExceptionClear(self.env)
 * 
 *     def get_method_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Find the method ID for a method on a class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_utf8name);
  __Pyx_XDECREF(__pyx_v_utf8sig);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":873
 *         return result
 * 
 *     def get_static_method_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Find the method ID for a static method on a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_27get_static_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_26get_static_method_id[] = "Find the method ID for a static method on a class\n\n        :param c: a class retrieved by find_class or get_object_class\n        :param name: the method name\n        :param sig: the calling signature,\n                    e.g. \"(ILjava/lang/String;)D\" is a function that\n                    returns a double and takes an integer, a long and\n                    a string as arguments.\n\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_27get_static_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sig = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_method_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_name,&__pyx_n_s_sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_method_id", 1, 3, 3, 1); __PYX_ERR(0, 873, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_method_id", 1, 3, 3, 2); __PYX_ERR(0, 873, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_method_id") < 0)) __PYX_ERR(0, 873, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = values[1];
    __pyx_v_sig = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_method_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 873, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 873, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_26get_static_method_id(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_26get_static_method_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig) {
  jmethodID __pyx_v_id;
  struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_result = 0;
  PyObject *__pyx_v_utf8name = NULL;
  PyObject *__pyx_v_utf8sig = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("get_static_method_id", 0);

  /* "_javabridge.pyx":887
 *             jmethodID id
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_utf8name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":888
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_encode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_utf8sig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":889
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_utf8name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 889, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_AsString(__pyx_v_utf8sig); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 889, __pyx_L1_error)
  __pyx_v_id = (__pyx_v_self->env[0])->GetStaticMethodID(__pyx_v_self->env, __pyx_v_c->c, __pyx_t_3, __pyx_t_4);

  /* "_javabridge.pyx":890
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  __pyx_t_5 = ((__pyx_v_id == NULL) != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":891
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result = __JB_MethodID()
 *         result.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":890
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  }

  /* "_javabridge.pyx":892
 *         if id == NULL:
 *             return
 *         result = __JB_MethodID()             # <<<<<<<<<<<<<<
 *         result.id = id
 *         result.sig = sig
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge___JB_MethodID), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((struct __pyx_obj_11_javabridge___JB_MethodID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":893
 *             return
 *         result = __JB_MethodID()
 *         result.id = id             # <<<<<<<<<<<<<<
 *         result.sig = sig
 *         result.is_static = True
 */
  __pyx_v_result->id = __pyx_v_id;

  /* "_javabridge.pyx":894
 *         result = __JB_MethodID()
 *         result.id = id
 *         result.sig = sig             # <<<<<<<<<<<<<<
 *         result.is_static = True
 *         return result
 */
  __Pyx_INCREF(__pyx_v_sig);
  __Pyx_GIVEREF(__pyx_v_sig);
  __Pyx_GOTREF(__pyx_v_result->sig);
  __Pyx_DECREF(__pyx_v_result->sig);
  __pyx_v_result->sig = __pyx_v_sig;

  /* "_javabridge.pyx":895
 *         result.id = id
 *         result.sig = sig
 *         result.is_static = True             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  __Pyx_GOTREF(__pyx_v_result->is_static);
  __Pyx_DECREF(__pyx_v_result->is_static);
  __pyx_v_result->is_static = Py_True;

  /* "_javabridge.pyx":896
 *         result.sig = sig
 *         result.is_static = True
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def from_reflected_method(self, JB_Object method, char *sig, is_static):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":873
 *         return result
 * 
 *     def get_static_method_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Find the method ID for a static method on a class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_utf8name);
  __Pyx_XDECREF(__pyx_v_utf8sig);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":898
 *         return result
 * 
 *     def from_reflected_method(self, JB_Object method, char *sig, is_static):             # <<<<<<<<<<<<<<
 *         '''Get a method_id given an instance of java.lang.reflect.Method
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_29from_reflected_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_28from_reflected_method[] = "Get a method_id given an instance of java.lang.reflect.Method\n        \n        :param method: a method, e.g. as retrieved from getDeclaredMethods\n        :param sig: signature of method\n        :param is_static: true if this is a static method\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_29from_reflected_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_method = 0;
  char *__pyx_v_sig;
  PyObject *__pyx_v_is_static = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_reflected_method (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_method,&__pyx_n_s_sig,&__pyx_n_s_is_static,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_method)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("from_reflected_method", 1, 3, 3, 1); __PYX_ERR(0, 898, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_is_static)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("from_reflected_method", 1, 3, 3, 2); __PYX_ERR(0, 898, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "from_reflected_method") < 0)) __PYX_ERR(0, 898, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_method = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_sig = __Pyx_PyObject_AsString(values[1]); if (unlikely((!__pyx_v_sig) && PyErr_Occurred())) __PYX_ERR(0, 898, __pyx_L3_error)
    __pyx_v_is_static = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_reflected_method", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 898, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.from_reflected_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_method), __pyx_ptype_11_javabridge_JB_Object, 1, "method", 0))) __PYX_ERR(0, 898, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_28from_reflected_method(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_method, __pyx_v_sig, __pyx_v_is_static);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_28from_reflected_method(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_method, char *__pyx_v_sig, PyObject *__pyx_v_is_static) {
  jmethodID __pyx_v_id;
  struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("from_reflected_method", 0);

  /* "_javabridge.pyx":908
 *             jmethodID id
 *             __JB_MethodID result
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return
 */
  __pyx_v_id = (__pyx_v_self->env[0])->FromReflectedMethod(__pyx_v_self->env, __pyx_v_method->o);

  /* "_javabridge.pyx":909
 *             __JB_MethodID result
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  __pyx_t_1 = ((__pyx_v_id == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":910
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)
 *         if id == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result = __JB_MethodID()
 *         result.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":909
 *             __JB_MethodID result
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  }

  /* "_javabridge.pyx":911
 *         if id == NULL:
 *             return
 *         result = __JB_MethodID()             # <<<<<<<<<<<<<<
 *         result.id = id
 *         result.sig = sig
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge___JB_MethodID), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((struct __pyx_obj_11_javabridge___JB_MethodID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":912
 *             return
 *         result = __JB_MethodID()
 *         result.id = id             # <<<<<<<<<<<<<<
 *         result.sig = sig
 *         result.is_static = is_static
 */
  __pyx_v_result->id = __pyx_v_id;

  /* "_javabridge.pyx":913
 *         result = __JB_MethodID()
 *         result.id = id
 *         result.sig = sig             # <<<<<<<<<<<<<<
 *         result.is_static = is_static
 *         return result
 */
  __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_sig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->sig);
  __Pyx_DECREF(__pyx_v_result->sig);
  __pyx_v_result->sig = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":914
 *         result.id = id
 *         result.sig = sig
 *         result.is_static = is_static             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __Pyx_INCREF(__pyx_v_is_static);
  __Pyx_GIVEREF(__pyx_v_is_static);
  __Pyx_GOTREF(__pyx_v_result->is_static);
  __Pyx_DECREF(__pyx_v_result->is_static);
  __pyx_v_result->is_static = __pyx_v_is_static;

  /* "_javabridge.pyx":915
 *         result.sig = sig
 *         result.is_static = is_static
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def call_method(self, JB_Object o, __JB_MethodID m, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":898
 *         return result
 * 
 *     def from_reflected_method(self, JB_Object method, char *sig, is_static):             # <<<<<<<<<<<<<<
 *         '''Get a method_id given an instance of java.lang.reflect.Method
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.from_reflected_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":917
 *         return result
 * 
 *     def call_method(self, JB_Object o, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a method on an object with arguments
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_31call_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_30call_method[] = "Call a method on an object with arguments\n\n        :param o: object in question\n        :param m: the method ID from :py:meth:`.get_method_id`\n        :param \\*args: the arguments to the method call. Arguments\n                      should appear in the same order as the\n                      signature. Arguments will be coerced into the\n                      type of the signature.\n\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_31call_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_method (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_m,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_m)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("call_method", 0, 2, 2, 1); __PYX_ERR(0, 917, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_method") < 0)) __PYX_ERR(0, 917, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_m = ((struct __pyx_obj_11_javabridge___JB_MethodID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_method", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 917, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("_javabridge.JB_Env.call_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 917, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_m), __pyx_ptype_11_javabridge___JB_MethodID, 1, "m", 0))) __PYX_ERR(0, 917, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_30call_method(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_m, __pyx_v_args);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_30call_method(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args) {
  jvalue *__pyx_v_values;
  jobject __pyx_v_this;
  JNIEnv *__pyx_v_jnienv;
  jboolean __pyx_v_zresult;
  jbyte __pyx_v_bresult;
  jchar __pyx_v_cresult;
  jshort __pyx_v_sresult;
  jint __pyx_v_iresult;
  jlong __pyx_v_jresult;
  jfloat __pyx_v_fresult;
  jdouble __pyx_v_dresult;
  jobject __pyx_v_oresult;
  jmethodID __pyx_v_m_id;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg_end = NULL;
  PyObject *__pyx_v_arg_sig = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  jobject __pyx_t_1;
  JNIEnv *__pyx_t_2;
  jmethodID __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  __Pyx_RefNannySetupContext("call_method", 0);

  /* "_javabridge.pyx":930
 *         cdef:
 *             jvalue *values
 *             jobject this = o.o             # <<<<<<<<<<<<<<
 *             JNIEnv *jnienv = self.env
 *             jboolean zresult
 */
  __pyx_t_1 = __pyx_v_o->o;
  __pyx_v_this = __pyx_t_1;

  /* "_javabridge.pyx":931
 *             jvalue *values
 *             jobject this = o.o
 *             JNIEnv *jnienv = self.env             # <<<<<<<<<<<<<<
 *             jboolean zresult
 *             jbyte bresult
 */
  __pyx_t_2 = __pyx_v_self->env;
  __pyx_v_jnienv = __pyx_t_2;

  /* "_javabridge.pyx":941
 *             jdouble dresult
 *             jobject oresult
 *             jmethodID m_id = m.id             # <<<<<<<<<<<<<<
 * 
 *         if m is None:
 */
  __pyx_t_3 = __pyx_v_m->id;
  __pyx_v_m_id = __pyx_t_3;

  /* "_javabridge.pyx":943
 *             jmethodID m_id = m.id
 * 
 *         if m is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_m) == Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":944
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use"
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 944, __pyx_L1_error)

    /* "_javabridge.pyx":943
 *             jmethodID m_id = m.id
 * 
 *         if m is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 */
  }

  /* "_javabridge.pyx":945
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:             # <<<<<<<<<<<<<<
 *             raise ValueError("call_method called with a static method. Use"
 *                              " call_static_method instead")
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_m->is_static); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 945, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":946
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use"             # <<<<<<<<<<<<<<
 *                              " call_static_method instead")
 *         sig = m.sig  # m.sig should be unicode already, no need to decode
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 946, __pyx_L1_error)

    /* "_javabridge.pyx":945
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:             # <<<<<<<<<<<<<<
 *             raise ValueError("call_method called with a static method. Use"
 *                              " call_static_method instead")
 */
  }

  /* "_javabridge.pyx":948
 *             raise ValueError("call_method called with a static method. Use"
 *                              " call_static_method instead")
 *         sig = m.sig  # m.sig should be unicode already, no need to decode             # <<<<<<<<<<<<<<
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_6 = __pyx_v_m->sig;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_v_sig = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":949
 *                              " call_static_method instead")
 *         sig = m.sig  # m.sig should be unicode already, no need to decode
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_kp_s__37, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_5) {

    /* "_javabridge.pyx":950
 *         sig = m.sig  # m.sig should be unicode already, no need to decode
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 */
    __pyx_t_6 = __Pyx_PyString_Format(__pyx_kp_s_Bad_function_signature_s, __pyx_v_m->sig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 950, __pyx_L1_error)

    /* "_javabridge.pyx":949
 *                              " call_static_method instead")
 *         sig = m.sig  # m.sig should be unicode already, no need to decode
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  }

  /* "_javabridge.pyx":951
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_find); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_arg_end = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_javabridge.pyx":952
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  __pyx_t_7 = __Pyx_PyInt_EqObjC(__pyx_v_arg_end, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_5) {

    /* "_javabridge.pyx":953
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 */
    __pyx_t_7 = __Pyx_PyString_Format(__pyx_kp_s_Bad_function_signature_s, __pyx_v_m->sig); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_6, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_7, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __PYX_ERR(0, 953, __pyx_L1_error)

    /* "_javabridge.pyx":952
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  }

  /* "_javabridge.pyx":954
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]             # <<<<<<<<<<<<<<
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 */
  __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, &__pyx_v_arg_end, NULL, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_arg_sig = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_javabridge.pyx":955
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)             # <<<<<<<<<<<<<<
 *         if error is not None:
 *             raise error
 */
  __pyx_t_7 = __pyx_f_11_javabridge_fill_values(__pyx_v_arg_sig, __pyx_v_args, (&__pyx_v_values)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_error = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_javabridge.pyx":956
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         sig = sig[arg_end+1:]
 */
  __pyx_t_5 = (__pyx_v_error != Py_None);
  __pyx_t_4 = (__pyx_t_5 != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":957
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 *             raise error             # <<<<<<<<<<<<<<
 *         sig = sig[arg_end+1:]
 *         #
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 957, __pyx_L1_error)

    /* "_javabridge.pyx":956
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         sig = sig[arg_end+1:]
 */
  }

  /* "_javabridge.pyx":958
 *         if error is not None:
 *             raise error
 *         sig = sig[arg_end+1:]             # <<<<<<<<<<<<<<
 *         #
 *         # Dispatch based on return code at end of sig
 */
  __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_arg_end, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 0, 0, &__pyx_t_7, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":962
 *         # Dispatch based on return code at end of sig
 *         #
 *         if sig == 'Z':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 zresult = jnienv[0].CallBooleanMethodA(
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_Z, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 962, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":963
 *         #
 *         if sig == 'Z':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 zresult = jnienv[0].CallBooleanMethodA(
 *                     jnienv, this, m_id, values)
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":964
 *         if sig == 'Z':
 *             with nogil:
 *                 zresult = jnienv[0].CallBooleanMethodA(             # <<<<<<<<<<<<<<
 *                     jnienv, this, m_id, values)
 *             result = zresult != 0
 */
          __pyx_v_zresult = (__pyx_v_jnienv[0])->CallBooleanMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":963
 *         #
 *         if sig == 'Z':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 zresult = jnienv[0].CallBooleanMethodA(
 *                     jnienv, this, m_id, values)
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L11;
          }
          __pyx_L11:;
        }
    }

    /* "_javabridge.pyx":966
 *                 zresult = jnienv[0].CallBooleanMethodA(
 *                     jnienv, this, m_id, values)
 *             result = zresult != 0             # <<<<<<<<<<<<<<
 *         elif sig == 'B':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyBool_FromLong((__pyx_v_zresult != 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":962
 *         # Dispatch based on return code at end of sig
 *         #
 *         if sig == 'Z':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 zresult = jnienv[0].CallBooleanMethodA(
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":967
 *                     jnienv, this, m_id, values)
 *             result = zresult != 0
 *         elif sig == 'B':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_B, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 967, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":968
 *             result = zresult != 0
 *         elif sig == 'B':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 *             result = bresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":969
 *         elif sig == 'B':
 *             with nogil:
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = bresult
 *         elif sig == 'C':
 */
          __pyx_v_bresult = (__pyx_v_jnienv[0])->CallByteMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":968
 *             result = zresult != 0
 *         elif sig == 'B':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 *             result = bresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L14;
          }
          __pyx_L14:;
        }
    }

    /* "_javabridge.pyx":970
 *             with nogil:
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 *             result = bresult             # <<<<<<<<<<<<<<
 *         elif sig == 'C':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jbyte(__pyx_v_bresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":967
 *                     jnienv, this, m_id, values)
 *             result = zresult != 0
 *         elif sig == 'B':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":971
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 *             result = bresult
 *         elif sig == 'C':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_C, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 971, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":972
 *             result = bresult
 *         elif sig == 'C':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 *             result = unichr(cresult)
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":973
 *         elif sig == 'C':
 *             with nogil:
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = unichr(cresult)
 *         elif sig == 'S':
 */
          __pyx_v_cresult = (__pyx_v_jnienv[0])->CallCharMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":972
 *             result = bresult
 *         elif sig == 'C':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 *             result = unichr(cresult)
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L17;
          }
          __pyx_L17:;
        }
    }

    /* "_javabridge.pyx":974
 *             with nogil:
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 *             result = unichr(cresult)             # <<<<<<<<<<<<<<
 *         elif sig == 'S':
 *             with nogil:
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyInt_From_jchar(__pyx_v_cresult); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 974, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":971
 *                 bresult = jnienv[0].CallByteMethodA(jnienv, this, m_id, values)
 *             result = bresult
 *         elif sig == 'C':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":975
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 *             result = unichr(cresult)
 *         elif sig == 'S':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_S, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 975, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":976
 *             result = unichr(cresult)
 *         elif sig == 'S':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 *             result = sresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":977
 *         elif sig == 'S':
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = sresult
 *         elif sig == 'I':
 */
          __pyx_v_sresult = (__pyx_v_jnienv[0])->CallShortMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":976
 *             result = unichr(cresult)
 *         elif sig == 'S':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 *             result = sresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L20;
          }
          __pyx_L20:;
        }
    }

    /* "_javabridge.pyx":978
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 *             result = sresult             # <<<<<<<<<<<<<<
 *         elif sig == 'I':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jshort(__pyx_v_sresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":975
 *                 cresult = jnienv[0].CallCharMethodA(jnienv, this, m_id, values)
 *             result = unichr(cresult)
 *         elif sig == 'S':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":979
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 *             result = sresult
 *         elif sig == 'I':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_I, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 979, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":980
 *             result = sresult
 *         elif sig == 'I':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 *             result = iresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":981
 *         elif sig == 'I':
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = iresult
 *         elif sig == 'J':
 */
          __pyx_v_iresult = (__pyx_v_jnienv[0])->CallIntMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":980
 *             result = sresult
 *         elif sig == 'I':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 *             result = iresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L23;
          }
          __pyx_L23:;
        }
    }

    /* "_javabridge.pyx":982
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 *             result = iresult             # <<<<<<<<<<<<<<
 *         elif sig == 'J':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jint(__pyx_v_iresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":979
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, this, m_id, values)
 *             result = sresult
 *         elif sig == 'I':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":983
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 *             result = iresult
 *         elif sig == 'J':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_J, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 983, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":984
 *             result = iresult
 *         elif sig == 'J':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 *             result = jresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":985
 *         elif sig == 'J':
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = jresult
 *         elif sig == 'F':
 */
          __pyx_v_jresult = (__pyx_v_jnienv[0])->CallLongMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":984
 *             result = iresult
 *         elif sig == 'J':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 *             result = jresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L26;
          }
          __pyx_L26:;
        }
    }

    /* "_javabridge.pyx":986
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 *             result = jresult             # <<<<<<<<<<<<<<
 *         elif sig == 'F':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jlong(__pyx_v_jresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":983
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, this, m_id, values)
 *             result = iresult
 *         elif sig == 'J':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":987
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 *             result = jresult
 *         elif sig == 'F':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_F, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 987, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":988
 *             result = jresult
 *         elif sig == 'F':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 *             result = fresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":989
 *         elif sig == 'F':
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = fresult
 *         elif sig == 'D':
 */
          __pyx_v_fresult = (__pyx_v_jnienv[0])->CallFloatMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":988
 *             result = jresult
 *         elif sig == 'F':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 *             result = fresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L29;
          }
          __pyx_L29:;
        }
    }

    /* "_javabridge.pyx":990
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 *             result = fresult             # <<<<<<<<<<<<<<
 *         elif sig == 'D':
 *             with nogil:
 */
    __pyx_t_6 = PyFloat_FromDouble(__pyx_v_fresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":987
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, this, m_id, values)
 *             result = jresult
 *         elif sig == 'F':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":991
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 *             result = fresult
 *         elif sig == 'D':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_D, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 991, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":992
 *             result = fresult
 *         elif sig == 'D':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 *             result = dresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":993
 *         elif sig == 'D':
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':
 */
          __pyx_v_dresult = (__pyx_v_jnienv[0])->CallDoubleMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":992
 *             result = fresult
 *         elif sig == 'D':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 *             result = dresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L32;
          }
          __pyx_L32:;
        }
    }

    /* "_javabridge.pyx":994
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 *             result = dresult             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:
 */
    __pyx_t_6 = PyFloat_FromDouble(__pyx_v_dresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":991
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, this, m_id, values)
 *             result = fresult
 *         elif sig == 'D':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":995
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_n_s_L, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L33_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_kp_s__15, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = __pyx_t_5;
  __pyx_L33_bool_binop_done:;
  if (__pyx_t_4) {

    /* "_javabridge.pyx":996
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 *             if oresult == NULL:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":997
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             if oresult == NULL:
 *                 result = None
 */
          __pyx_v_oresult = (__pyx_v_jnienv[0])->CallObjectMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":996
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 *             if oresult == NULL:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L37;
          }
          __pyx_L37:;
        }
    }

    /* "_javabridge.pyx":998
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 *             if oresult == NULL:             # <<<<<<<<<<<<<<
 *                 result = None
 *             else:
 */
    __pyx_t_4 = ((__pyx_v_oresult == NULL) != 0);
    if (__pyx_t_4) {

      /* "_javabridge.pyx":999
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 *             if oresult == NULL:
 *                 result = None             # <<<<<<<<<<<<<<
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 */
      __Pyx_INCREF(Py_None);
      __pyx_v_result = Py_None;

      /* "_javabridge.pyx":998
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 *             if oresult == NULL:             # <<<<<<<<<<<<<<
 *                 result = None
 *             else:
 */
      goto __pyx_L38;
    }

    /* "_javabridge.pyx":1001
 *                 result = None
 *             else:
 *                 result, e = make_jb_object(self, oresult)             # <<<<<<<<<<<<<<
 *                 if e is not None:
 *                     raise e
 */
    /*else*/ {
      __pyx_t_6 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_oresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1001, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1001, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_10 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1001, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1001, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1001, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_11 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_11(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L39_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_10 = __pyx_t_11(__pyx_t_8); if (unlikely(!__pyx_t_10)) goto __pyx_L39_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_8), 2) < 0) __PYX_ERR(0, 1001, __pyx_L1_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L40_unpacking_done;
        __pyx_L39_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1001, __pyx_L1_error)
        __pyx_L40_unpacking_done:;
      }
      __pyx_v_result = __pyx_t_7;
      __pyx_t_7 = 0;
      __pyx_v_e = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "_javabridge.pyx":1002
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *         elif sig == 'V':
 */
      __pyx_t_4 = (__pyx_v_e != Py_None);
      __pyx_t_5 = (__pyx_t_4 != 0);
      if (__pyx_t_5) {

        /* "_javabridge.pyx":1003
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:
 *                     raise e             # <<<<<<<<<<<<<<
 *         elif sig == 'V':
 *             with nogil:
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(0, 1003, __pyx_L1_error)

        /* "_javabridge.pyx":1002
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *         elif sig == 'V':
 */
      }
    }
    __pyx_L38:;

    /* "_javabridge.pyx":995
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, this, m_id, values)
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1004
 *                 if e is not None:
 *                     raise e
 *         elif sig == 'V':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 jnienv[0].CallVoidMethodA(jnienv, this, m_id, values)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_V, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1004, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1005
 *                     raise e
 *         elif sig == 'V':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 jnienv[0].CallVoidMethodA(jnienv, this, m_id, values)
 *             result = None
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1006
 *         elif sig == 'V':
 *             with nogil:
 *                 jnienv[0].CallVoidMethodA(jnienv, this, m_id, values)             # <<<<<<<<<<<<<<
 *             result = None
 *         else:
 */
          (__pyx_v_jnienv[0])->CallVoidMethodA(__pyx_v_jnienv, __pyx_v_this, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1005
 *                     raise e
 *         elif sig == 'V':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 jnienv[0].CallVoidMethodA(jnienv, this, m_id, values)
 *             result = None
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L44;
          }
          __pyx_L44:;
        }
    }

    /* "_javabridge.pyx":1007
 *             with nogil:
 *                 jnienv[0].CallVoidMethodA(jnienv, this, m_id, values)
 *             result = None             # <<<<<<<<<<<<<<
 *         else:
 *             free(<void *>values)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_result = Py_None;

    /* "_javabridge.pyx":1004
 *                 if e is not None:
 *                     raise e
 *         elif sig == 'V':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 jnienv[0].CallVoidMethodA(jnienv, this, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1009
 *             result = None
 *         else:
 *             free(<void *>values)             # <<<<<<<<<<<<<<
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 */
  /*else*/ {
    free(((void *)__pyx_v_values));

    /* "_javabridge.pyx":1010
 *         else:
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)             # <<<<<<<<<<<<<<
 *         free(<void *>values)
 *         return result
 */
    __pyx_t_6 = __Pyx_PyString_Format(__pyx_kp_s_Unhandled_return_type_Signature, __pyx_v_m->sig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 1010, __pyx_L1_error)
  }
  __pyx_L8:;

  /* "_javabridge.pyx":1011
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  free(((void *)__pyx_v_values));

  /* "_javabridge.pyx":1012
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def call_static_method(self, JB_Class c, __JB_MethodID m, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":917
 *         return result
 * 
 *     def call_method(self, JB_Object o, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a method on an object with arguments
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("_javabridge.JB_Env.call_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg_end);
  __Pyx_XDECREF(__pyx_v_arg_sig);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1014
 *         return result
 * 
 *     def call_static_method(self, JB_Class c, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a static method on a class with arguments
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_33call_static_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_32call_static_method[] = "Call a static method on a class with arguments\n\n        :param c: class holding the method (e.g. from :py:meth:`.find_class`)\n        :param m: the method ID from :py:meth:`.get_static_method_id`\n        :param args: the arguments to the method call. Arguments\n                      should appear in the same order as the\n                      signature. Arguments will be coerced into the\n                      type of the signature.\n\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_33call_static_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_static_method (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_m,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_m)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("call_static_method", 0, 2, 2, 1); __PYX_ERR(0, 1014, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_static_method") < 0)) __PYX_ERR(0, 1014, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_m = ((struct __pyx_obj_11_javabridge___JB_MethodID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_static_method", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1014, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("_javabridge.JB_Env.call_static_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1014, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_m), __pyx_ptype_11_javabridge___JB_MethodID, 1, "m", 0))) __PYX_ERR(0, 1014, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_32call_static_method(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_m, __pyx_v_args);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_32call_static_method(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args) {
  jvalue *__pyx_v_values;
  JNIEnv *__pyx_v_jnienv;
  jclass __pyx_v_klass;
  jboolean __pyx_v_zresult;
  jbyte __pyx_v_bresult;
  jchar __pyx_v_cresult;
  jshort __pyx_v_sresult;
  jint __pyx_v_iresult;
  jlong __pyx_v_jresult;
  jfloat __pyx_v_fresult;
  jdouble __pyx_v_dresult;
  jobject __pyx_v_oresult;
  jmethodID __pyx_v_m_id;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg_end = NULL;
  PyObject *__pyx_v_arg_sig = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  JNIEnv *__pyx_t_1;
  jclass __pyx_t_2;
  jmethodID __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  __Pyx_RefNannySetupContext("call_static_method", 0);

  /* "_javabridge.pyx":1027
 *         cdef:
 *             jvalue *values
 *             JNIEnv *jnienv = self.env             # <<<<<<<<<<<<<<
 *             jclass klass = c.c
 *             jboolean zresult
 */
  __pyx_t_1 = __pyx_v_self->env;
  __pyx_v_jnienv = __pyx_t_1;

  /* "_javabridge.pyx":1028
 *             jvalue *values
 *             JNIEnv *jnienv = self.env
 *             jclass klass = c.c             # <<<<<<<<<<<<<<
 *             jboolean zresult
 *             jbyte bresult
 */
  __pyx_t_2 = __pyx_v_c->c;
  __pyx_v_klass = __pyx_t_2;

  /* "_javabridge.pyx":1038
 *             jdouble dresult
 *             jobject oresult
 *             jmethodID m_id = m.id             # <<<<<<<<<<<<<<
 * 
 *         if m is None:
 */
  __pyx_t_3 = __pyx_v_m->id;
  __pyx_v_m_id = __pyx_t_3;

  /* "_javabridge.pyx":1040
 *             jmethodID m_id = m.id
 * 
 *         if m is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_m) == Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1041
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__40, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1041, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 1041, __pyx_L1_error)

    /* "_javabridge.pyx":1040
 *             jmethodID m_id = m.id
 * 
 *         if m is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 */
  }

  /* "_javabridge.pyx":1042
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:             # <<<<<<<<<<<<<<
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_m->is_static); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_5) != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":1043
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")             # <<<<<<<<<<<<<<
 *         sig = m.sig
 *         if sig[0] != '(':
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 1043, __pyx_L1_error)

    /* "_javabridge.pyx":1042
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:             # <<<<<<<<<<<<<<
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig
 */
  }

  /* "_javabridge.pyx":1044
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig             # <<<<<<<<<<<<<<
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_6 = __pyx_v_m->sig;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_v_sig = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":1045
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_kp_s__37, Py_NE)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {

    /* "_javabridge.pyx":1046
 *         sig = m.sig
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 */
    __pyx_t_6 = __Pyx_PyString_Format(__pyx_kp_s_Bad_function_signature_s, __pyx_v_m->sig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 1046, __pyx_L1_error)

    /* "_javabridge.pyx":1045
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  }

  /* "_javabridge.pyx":1047
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_find); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_arg_end = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_javabridge.pyx":1048
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  __pyx_t_7 = __Pyx_PyInt_EqObjC(__pyx_v_arg_end, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1048, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_4) {

    /* "_javabridge.pyx":1049
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 */
    __pyx_t_7 = __Pyx_PyString_Format(__pyx_kp_s_Bad_function_signature_s, __pyx_v_m->sig); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_6, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_7, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __PYX_ERR(0, 1049, __pyx_L1_error)

    /* "_javabridge.pyx":1048
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  }

  /* "_javabridge.pyx":1050
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]             # <<<<<<<<<<<<<<
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 */
  __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, &__pyx_v_arg_end, NULL, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_arg_sig = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_javabridge.pyx":1051
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)             # <<<<<<<<<<<<<<
 *         if error is not None:
 *             raise error
 */
  __pyx_t_7 = __pyx_f_11_javabridge_fill_values(__pyx_v_arg_sig, __pyx_v_args, (&__pyx_v_values)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_error = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_javabridge.pyx":1052
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         sig = sig[arg_end+1:]
 */
  __pyx_t_4 = (__pyx_v_error != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1053
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 *             raise error             # <<<<<<<<<<<<<<
 *         sig = sig[arg_end+1:]
 *         #
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 1053, __pyx_L1_error)

    /* "_javabridge.pyx":1052
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         sig = sig[arg_end+1:]
 */
  }

  /* "_javabridge.pyx":1054
 *         if error is not None:
 *             raise error
 *         sig = sig[arg_end+1:]             # <<<<<<<<<<<<<<
 *         #
 *         # Dispatch based on return code at end of sig
 */
  __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_arg_end, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 0, 0, &__pyx_t_7, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_sig, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":1058
 *         # Dispatch based on return code at end of sig
 *         #
 *         if sig == 'Z':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 zresult = jnienv[0].CallStaticBooleanMethodA(
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_Z, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1058, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1059
 *         #
 *         if sig == 'Z':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 zresult = jnienv[0].CallStaticBooleanMethodA(
 *                     jnienv, klass, m_id, values)
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1060
 *         if sig == 'Z':
 *             with nogil:
 *                 zresult = jnienv[0].CallStaticBooleanMethodA(             # <<<<<<<<<<<<<<
 *                     jnienv, klass, m_id, values)
 *             result = zresult != 0
 */
          __pyx_v_zresult = (__pyx_v_jnienv[0])->CallStaticBooleanMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1059
 *         #
 *         if sig == 'Z':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 zresult = jnienv[0].CallStaticBooleanMethodA(
 *                     jnienv, klass, m_id, values)
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L11;
          }
          __pyx_L11:;
        }
    }

    /* "_javabridge.pyx":1062
 *                 zresult = jnienv[0].CallStaticBooleanMethodA(
 *                     jnienv, klass, m_id, values)
 *             result = zresult != 0             # <<<<<<<<<<<<<<
 *         elif sig == 'B':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyBool_FromLong((__pyx_v_zresult != 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1058
 *         # Dispatch based on return code at end of sig
 *         #
 *         if sig == 'Z':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 zresult = jnienv[0].CallStaticBooleanMethodA(
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1063
 *                     jnienv, klass, m_id, values)
 *             result = zresult != 0
 *         elif sig == 'B':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 bresult = jnienv[0].CallStaticByteMethodA(
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_B, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1063, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1064
 *             result = zresult != 0
 *         elif sig == 'B':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 bresult = jnienv[0].CallStaticByteMethodA(
 *                     jnienv, klass, m_id, values)
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1065
 *         elif sig == 'B':
 *             with nogil:
 *                 bresult = jnienv[0].CallStaticByteMethodA(             # <<<<<<<<<<<<<<
 *                     jnienv, klass, m_id, values)
 *             result = bresult
 */
          __pyx_v_bresult = (__pyx_v_jnienv[0])->CallStaticByteMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1064
 *             result = zresult != 0
 *         elif sig == 'B':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 bresult = jnienv[0].CallStaticByteMethodA(
 *                     jnienv, klass, m_id, values)
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L14;
          }
          __pyx_L14:;
        }
    }

    /* "_javabridge.pyx":1067
 *                 bresult = jnienv[0].CallStaticByteMethodA(
 *                     jnienv, klass, m_id, values)
 *             result = bresult             # <<<<<<<<<<<<<<
 *         elif sig == 'C':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jbyte(__pyx_v_bresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1067, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1063
 *                     jnienv, klass, m_id, values)
 *             result = zresult != 0
 *         elif sig == 'B':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 bresult = jnienv[0].CallStaticByteMethodA(
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1068
 *                     jnienv, klass, m_id, values)
 *             result = bresult
 *         elif sig == 'C':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cresult = jnienv[0].CallStaticCharMethodA(
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_C, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1068, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1069
 *             result = bresult
 *         elif sig == 'C':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cresult = jnienv[0].CallStaticCharMethodA(
 *                     jnienv, klass, m_id, values)
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1070
 *         elif sig == 'C':
 *             with nogil:
 *                 cresult = jnienv[0].CallStaticCharMethodA(             # <<<<<<<<<<<<<<
 *                     jnienv, klass, m_id, values)
 *             result = unichr(cresult)
 */
          __pyx_v_cresult = (__pyx_v_jnienv[0])->CallStaticCharMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1069
 *             result = bresult
 *         elif sig == 'C':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cresult = jnienv[0].CallStaticCharMethodA(
 *                     jnienv, klass, m_id, values)
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L17;
          }
          __pyx_L17:;
        }
    }

    /* "_javabridge.pyx":1072
 *                 cresult = jnienv[0].CallStaticCharMethodA(
 *                     jnienv, klass, m_id, values)
 *             result = unichr(cresult)             # <<<<<<<<<<<<<<
 *         elif sig == 'S':
 *             with nogil:
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1072, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyInt_From_jchar(__pyx_v_cresult); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1072, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1072, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1072, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1072, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1072, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1068
 *                     jnienv, klass, m_id, values)
 *             result = bresult
 *         elif sig == 'C':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cresult = jnienv[0].CallStaticCharMethodA(
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1073
 *                     jnienv, klass, m_id, values)
 *             result = unichr(cresult)
 *         elif sig == 'S':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_S, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1073, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1074
 *             result = unichr(cresult)
 *         elif sig == 'S':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 *             result = sresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1075
 *         elif sig == 'S':
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *             result = sresult
 *         elif sig == 'I':
 */
          __pyx_v_sresult = (__pyx_v_jnienv[0])->CallShortMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1074
 *             result = unichr(cresult)
 *         elif sig == 'S':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 *             result = sresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L20;
          }
          __pyx_L20:;
        }
    }

    /* "_javabridge.pyx":1076
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 *             result = sresult             # <<<<<<<<<<<<<<
 *         elif sig == 'I':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jshort(__pyx_v_sresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1076, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1073
 *                     jnienv, klass, m_id, values)
 *             result = unichr(cresult)
 *         elif sig == 'S':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1077
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 *             result = sresult
 *         elif sig == 'I':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_I, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1077, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1078
 *             result = sresult
 *         elif sig == 'I':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 *             result = iresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1079
 *         elif sig == 'I':
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *             result = iresult
 *         elif sig == 'J':
 */
          __pyx_v_iresult = (__pyx_v_jnienv[0])->CallIntMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1078
 *             result = sresult
 *         elif sig == 'I':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 *             result = iresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L23;
          }
          __pyx_L23:;
        }
    }

    /* "_javabridge.pyx":1080
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 *             result = iresult             # <<<<<<<<<<<<<<
 *         elif sig == 'J':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jint(__pyx_v_iresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1077
 *                 sresult = jnienv[0].CallShortMethodA(jnienv, klass, m_id, values)
 *             result = sresult
 *         elif sig == 'I':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1081
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 *             result = iresult
 *         elif sig == 'J':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_J, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1081, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1082
 *             result = iresult
 *         elif sig == 'J':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 *             result = jresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1083
 *         elif sig == 'J':
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *             result = jresult
 *         elif sig == 'F':
 */
          __pyx_v_jresult = (__pyx_v_jnienv[0])->CallLongMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1082
 *             result = iresult
 *         elif sig == 'J':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 *             result = jresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L26;
          }
          __pyx_L26:;
        }
    }

    /* "_javabridge.pyx":1084
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 *             result = jresult             # <<<<<<<<<<<<<<
 *         elif sig == 'F':
 *             with nogil:
 */
    __pyx_t_6 = __Pyx_PyInt_From_jlong(__pyx_v_jresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1081
 *                 iresult = jnienv[0].CallIntMethodA(jnienv, klass, m_id, values)
 *             result = iresult
 *         elif sig == 'J':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1085
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 *             result = jresult
 *         elif sig == 'F':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_F, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1085, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1086
 *             result = jresult
 *         elif sig == 'F':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 *             result = fresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1087
 *         elif sig == 'F':
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *             result = fresult
 *         elif sig == 'D':
 */
          __pyx_v_fresult = (__pyx_v_jnienv[0])->CallFloatMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1086
 *             result = jresult
 *         elif sig == 'F':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 *             result = fresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L29;
          }
          __pyx_L29:;
        }
    }

    /* "_javabridge.pyx":1088
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 *             result = fresult             # <<<<<<<<<<<<<<
 *         elif sig == 'D':
 *             with nogil:
 */
    __pyx_t_6 = PyFloat_FromDouble(__pyx_v_fresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1085
 *                 jresult = jnienv[0].CallLongMethodA(jnienv, klass, m_id, values)
 *             result = jresult
 *         elif sig == 'F':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1089
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 *             result = fresult
 *         elif sig == 'D':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_D, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1089, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1090
 *             result = fresult
 *         elif sig == 'D':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 *             result = dresult
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1091
 *         elif sig == 'D':
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':
 */
          __pyx_v_dresult = (__pyx_v_jnienv[0])->CallDoubleMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1090
 *             result = fresult
 *         elif sig == 'D':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 *             result = dresult
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L32;
          }
          __pyx_L32:;
        }
    }

    /* "_javabridge.pyx":1092
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 *             result = dresult             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:
 */
    __pyx_t_6 = PyFloat_FromDouble(__pyx_v_dresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "_javabridge.pyx":1089
 *                 fresult = jnienv[0].CallFloatMethodA(jnienv, klass, m_id, values)
 *             result = fresult
 *         elif sig == 'D':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1093
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 */
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_n_s_L, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!__pyx_t_4) {
  } else {
    __pyx_t_5 = __pyx_t_4;
    goto __pyx_L33_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_kp_s__15, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = __pyx_t_4;
  __pyx_L33_bool_binop_done:;
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1094
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 *             if oresult == NULL:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        #endif
        /*try:*/ {

          /* "_javabridge.pyx":1095
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *             if oresult == NULL:
 *                 result = None
 */
          __pyx_v_oresult = (__pyx_v_jnienv[0])->CallObjectMethodA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
        }

        /* "_javabridge.pyx":1094
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 *             if oresult == NULL:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L37;
          }
          __pyx_L37:;
        }
    }

    /* "_javabridge.pyx":1096
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 *             if oresult == NULL:             # <<<<<<<<<<<<<<
 *                 result = None
 *             else:
 */
    __pyx_t_5 = ((__pyx_v_oresult == NULL) != 0);
    if (__pyx_t_5) {

      /* "_javabridge.pyx":1097
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 *             if oresult == NULL:
 *                 result = None             # <<<<<<<<<<<<<<
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 */
      __Pyx_INCREF(Py_None);
      __pyx_v_result = Py_None;

      /* "_javabridge.pyx":1096
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 *             if oresult == NULL:             # <<<<<<<<<<<<<<
 *                 result = None
 *             else:
 */
      goto __pyx_L38;
    }

    /* "_javabridge.pyx":1099
 *                 result = None
 *             else:
 *                 result, e = make_jb_object(self, oresult)             # <<<<<<<<<<<<<<
 *                 if e is not None:
 *                     raise e
 */
    /*else*/ {
      __pyx_t_6 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_oresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1099, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1099, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_10 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1099, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1099, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1099, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_11 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_11(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L39_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_10 = __pyx_t_11(__pyx_t_8); if (unlikely(!__pyx_t_10)) goto __pyx_L39_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_8), 2) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L40_unpacking_done;
        __pyx_L39_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1099, __pyx_L1_error)
        __pyx_L40_unpacking_done:;
      }
      __pyx_v_result = __pyx_t_7;
      __pyx_t_7 = 0;
      __pyx_v_e = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "_javabridge.pyx":1100
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *         elif sig == 'V':
 */
      __pyx_t_5 = (__pyx_v_e != Py_None);
      __pyx_t_4 = (__pyx_t_5 != 0);
      if (__pyx_t_4) {

        /* "_javabridge.pyx":1101
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:
 *                     raise e             # <<<<<<<<<<<<<<
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(0, 1101, __pyx_L1_error)

        /* "_javabridge.pyx":1100
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *         elif sig == 'V':
 */
      }
    }
    __pyx_L38:;

    /* "_javabridge.pyx":1093
 *                 dresult = jnienv[0].CallDoubleMethodA(jnienv, klass, m_id, values)
 *             result = dresult
 *         elif sig[0] == 'L' or sig[0] == '[':             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 oresult = jnienv[0].CallObjectMethodA(jnienv, klass, m_id, values)
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1102
 *                 if e is not None:
 *                     raise e
 *         elif sig == 'V':             # <<<<<<<<<<<<<<
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 *             result = None
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_sig, __pyx_n_s_V, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1102, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "_javabridge.pyx":1103
 *                     raise e
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *             result = None
 *         else:
 */
    (__pyx_v_self->env[0])->CallVoidMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values);

    /* "_javabridge.pyx":1104
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 *             result = None             # <<<<<<<<<<<<<<
 *         else:
 *             free(<void *>values)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_result = Py_None;

    /* "_javabridge.pyx":1102
 *                 if e is not None:
 *                     raise e
 *         elif sig == 'V':             # <<<<<<<<<<<<<<
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 *             result = None
 */
    goto __pyx_L8;
  }

  /* "_javabridge.pyx":1106
 *             result = None
 *         else:
 *             free(<void *>values)             # <<<<<<<<<<<<<<
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 */
  /*else*/ {
    free(((void *)__pyx_v_values));

    /* "_javabridge.pyx":1107
 *         else:
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)             # <<<<<<<<<<<<<<
 *         free(<void *>values)
 *         return result
 */
    __pyx_t_6 = __Pyx_PyString_Format(__pyx_kp_s_Unhandled_return_type_Signature, __pyx_v_m->sig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 1107, __pyx_L1_error)
  }
  __pyx_L8:;

  /* "_javabridge.pyx":1108
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  free(((void *)__pyx_v_values));

  /* "_javabridge.pyx":1109
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_field_id(self, JB_Class c, name, sig):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1014
 *         return result
 * 
 *     def call_static_method(self, JB_Class c, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a static method on a class with arguments
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("_javabridge.JB_Env.call_static_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg_end);
  __Pyx_XDECREF(__pyx_v_arg_sig);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1111
 *         return result
 * 
 *     def get_field_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Get a field ID for a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_35get_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_34get_field_id[] = "Get a field ID for a class\n        \n        :param c: class (from :py:meth:`.find_class` or similar)\n        :param name: name of field\n        :param sig: signature of field (e.g. Ljava/lang/String;)\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_35get_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sig = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_field_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_name,&__pyx_n_s_sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_field_id", 1, 3, 3, 1); __PYX_ERR(0, 1111, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_field_id", 1, 3, 3, 2); __PYX_ERR(0, 1111, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_field_id") < 0)) __PYX_ERR(0, 1111, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = values[1];
    __pyx_v_sig = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_field_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1111, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1111, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_34get_field_id(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_34get_field_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig) {
  jfieldID __pyx_v_id;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_jbid = 0;
  PyObject *__pyx_v_utf8name = NULL;
  PyObject *__pyx_v_utf8sig = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("get_field_id", 0);

  /* "_javabridge.pyx":1122
 *             __JB_FieldID jbid
 * 
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_utf8name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":1123
 * 
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_encode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_utf8sig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":1125
 *         utf8sig = sig.encode('utf-8')
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, utf8name, utf8sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return None
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_utf8name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1125, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_AsString(__pyx_v_utf8sig); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 1125, __pyx_L1_error)
  __pyx_v_id = (__pyx_v_self->env[0])->GetFieldID(__pyx_v_self->env, __pyx_v_c->c, __pyx_t_3, __pyx_t_4);

  /* "_javabridge.pyx":1126
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         jbid = __JB_FieldID()
 */
  __pyx_t_5 = ((__pyx_v_id == NULL) != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1127
 *         id = self.env[0].GetFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "_javabridge.pyx":1126
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         jbid = __JB_FieldID()
 */
  }

  /* "_javabridge.pyx":1128
 *         if id == NULL:
 *             return None
 *         jbid = __JB_FieldID()             # <<<<<<<<<<<<<<
 *         jbid.id = id
 *         jbid.sig = sig
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge___JB_FieldID), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jbid = ((struct __pyx_obj_11_javabridge___JB_FieldID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":1129
 *             return None
 *         jbid = __JB_FieldID()
 *         jbid.id = id             # <<<<<<<<<<<<<<
 *         jbid.sig = sig
 *         jbid.is_static = False
 */
  __pyx_v_jbid->id = __pyx_v_id;

  /* "_javabridge.pyx":1130
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 *         jbid.sig = sig             # <<<<<<<<<<<<<<
 *         jbid.is_static = False
 *         return jbid
 */
  __Pyx_INCREF(__pyx_v_sig);
  __Pyx_GIVEREF(__pyx_v_sig);
  __Pyx_GOTREF(__pyx_v_jbid->sig);
  __Pyx_DECREF(__pyx_v_jbid->sig);
  __pyx_v_jbid->sig = __pyx_v_sig;

  /* "_javabridge.pyx":1131
 *         jbid.id = id
 *         jbid.sig = sig
 *         jbid.is_static = False             # <<<<<<<<<<<<<<
 *         return jbid
 * 
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_jbid->is_static);
  __Pyx_DECREF(__pyx_v_jbid->is_static);
  __pyx_v_jbid->is_static = Py_False;

  /* "_javabridge.pyx":1132
 *         jbid.sig = sig
 *         jbid.is_static = False
 *         return jbid             # <<<<<<<<<<<<<<
 * 
 *     def get_object_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbid));
  __pyx_r = ((PyObject *)__pyx_v_jbid);
  goto __pyx_L0;

  /* "_javabridge.pyx":1111
 *         return result
 * 
 *     def get_field_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Get a field ID for a class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbid);
  __Pyx_XDECREF(__pyx_v_utf8name);
  __Pyx_XDECREF(__pyx_v_utf8sig);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1134
 *         return jbid
 * 
 *     def get_object_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an object field
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_37get_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_36get_object_field[] = "Return an object field\n\n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the Java object or None if the field's value is null\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_37get_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_object_field", 1, 2, 2, 1); __PYX_ERR(0, 1134, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_object_field") < 0)) __PYX_ERR(0, 1134, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_object_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1134, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1134, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1134, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_36get_object_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_36get_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  jobject __pyx_v_subo;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("get_object_field", 0);

  /* "_javabridge.pyx":1144
 *         cdef:
 *             jobject subo
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 *         if subo == NULL:
 *             return
 */
  __pyx_v_subo = (__pyx_v_self->env[0])->GetObjectField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id);

  /* "_javabridge.pyx":1145
 *             jobject subo
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)
 *         if subo == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, subo)
 */
  __pyx_t_1 = ((__pyx_v_subo == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1146
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)
 *         if subo == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":1145
 *             jobject subo
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)
 *         if subo == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, subo)
 */
  }

  /* "_javabridge.pyx":1147
 *         if subo == NULL:
 *             return
 *         result, e = make_jb_object(self, subo)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_2 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_subo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1147, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1147, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1147, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1148
 *             return
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1149
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1149, __pyx_L1_error)

    /* "_javabridge.pyx":1148
 *             return
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1150
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_boolean_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1134
 *         return jbid
 * 
 *     def get_object_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an object field
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1152
 *         return result
 * 
 *     def get_boolean_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a boolean field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_39get_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_38get_boolean_field[] = "Return a boolean field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype: bool\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_39get_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_boolean_field", 1, 2, 2, 1); __PYX_ERR(0, 1152, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_boolean_field") < 0)) __PYX_ERR(0, 1152, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_boolean_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1152, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1152, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1152, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_38get_boolean_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_38get_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_boolean_field", 0);

  /* "_javabridge.pyx":1161
 *         :rtype: bool
 *         '''
 *         return self.env[0].GetBooleanField(self.env, o.o, field.id) != 0             # <<<<<<<<<<<<<<
 * 
 *     def get_byte_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(((__pyx_v_self->env[0])->GetBooleanField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id) != 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1152
 *         return result
 * 
 *     def get_boolean_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a boolean field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1163
 *         return self.env[0].GetBooleanField(self.env, o.o, field.id) != 0
 * 
 *     def get_byte_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a byte field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_41get_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_40get_byte_field[] = "Return a byte field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype: int\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_41get_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_byte_field", 1, 2, 2, 1); __PYX_ERR(0, 1163, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_byte_field") < 0)) __PYX_ERR(0, 1163, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_byte_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1163, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1163, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1163, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_40get_byte_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_40get_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_byte_field", 0);

  /* "_javabridge.pyx":1172
 *         :rtype: int
 *         '''
 *         return self.env[0].GetByteField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_char_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jbyte((__pyx_v_self->env[0])->GetByteField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1163
 *         return self.env[0].GetBooleanField(self.env, o.o, field.id) != 0
 * 
 *     def get_byte_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a byte field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1174
 *         return self.env[0].GetByteField(self.env, o.o, field.id)
 * 
 *     def get_char_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a char field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_43get_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_42get_char_field[] = "Return a char field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the char value stored in the class's field\n        :rtype: unichr\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_43get_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_char_field", 1, 2, 2, 1); __PYX_ERR(0, 1174, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_char_field") < 0)) __PYX_ERR(0, 1174, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_char_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1174, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1174, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1174, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_42get_char_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_42get_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get_char_field", 0);

  /* "_javabridge.pyx":1183
 *         :rtype: unichr
 *         '''
 *         return unichr(self.env[0].GetCharField(self.env, o.o, field.id))             # <<<<<<<<<<<<<<
 * 
 *     def get_short_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_jchar((__pyx_v_self->env[0])->GetCharField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1183, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1174
 *         return self.env[0].GetByteField(self.env, o.o, field.id)
 * 
 *     def get_char_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a char field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1185
 *         return unichr(self.env[0].GetCharField(self.env, o.o, field.id))
 * 
 *     def get_short_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a short field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_45get_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_44get_short_field[] = "Return a short field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype:  int\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_45get_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_short_field", 1, 2, 2, 1); __PYX_ERR(0, 1185, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_short_field") < 0)) __PYX_ERR(0, 1185, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_short_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1185, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1185, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_44get_short_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_44get_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_short_field", 0);

  /* "_javabridge.pyx":1194
 *         :rtype:  int
 *         '''
 *         return self.env[0].GetShortField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_int_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jshort((__pyx_v_self->env[0])->GetShortField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1185
 *         return unichr(self.env[0].GetCharField(self.env, o.o, field.id))
 * 
 *     def get_short_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a short field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1196
 *         return self.env[0].GetShortField(self.env, o.o, field.id)
 * 
 *     def get_int_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an int field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_47get_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_46get_int_field[] = "Return an int field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype:  int\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_47get_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_int_field", 1, 2, 2, 1); __PYX_ERR(0, 1196, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_int_field") < 0)) __PYX_ERR(0, 1196, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_int_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1196, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1196, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1196, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_46get_int_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_46get_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_int_field", 0);

  /* "_javabridge.pyx":1205
 *         :rtype:  int
 *         '''
 *         return self.env[0].GetIntField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_long_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jint((__pyx_v_self->env[0])->GetIntField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1196
 *         return self.env[0].GetShortField(self.env, o.o, field.id)
 * 
 *     def get_int_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an int field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1207
 *         return self.env[0].GetIntField(self.env, o.o, field.id)
 * 
 *     def get_long_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a long field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_49get_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_48get_long_field[] = "Return a long field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype:  long\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_49get_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_long_field", 1, 2, 2, 1); __PYX_ERR(0, 1207, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_long_field") < 0)) __PYX_ERR(0, 1207, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_long_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1207, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_48get_long_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_48get_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_long_field", 0);

  /* "_javabridge.pyx":1216
 *         :rtype:  long
 *         '''
 *         return self.env[0].GetLongField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_float_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jlong((__pyx_v_self->env[0])->GetLongField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1207
 *         return self.env[0].GetIntField(self.env, o.o, field.id)
 * 
 *     def get_long_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a long field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1218
 *         return self.env[0].GetLongField(self.env, o.o, field.id)
 * 
 *     def get_float_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a float field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_51get_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_50get_float_field[] = "Return a float field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype:  float\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_51get_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_float_field", 1, 2, 2, 1); __PYX_ERR(0, 1218, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_float_field") < 0)) __PYX_ERR(0, 1218, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_float_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1218, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1218, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1218, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_50get_float_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_50get_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_float_field", 0);

  /* "_javabridge.pyx":1227
 *         :rtype:  float
 *         '''
 *         return self.env[0].GetFloatField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_double_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetFloatField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1218
 *         return self.env[0].GetLongField(self.env, o.o, field.id)
 * 
 *     def get_float_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a float field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1229
 *         return self.env[0].GetFloatField(self.env, o.o, field.id)
 * 
 *     def get_double_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a double field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_53get_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_52get_double_field[] = "Return a double field's value\n        \n        :param o: the Java object to be accessed\n        :param field: the field to be fetched (from :py:meth:`.get_field_id`)\n        \n        :return: the field's value\n        :rtype:  float\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_53get_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_double_field", 1, 2, 2, 1); __PYX_ERR(0, 1229, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_double_field") < 0)) __PYX_ERR(0, 1229, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_double_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1229, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1229, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1229, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_52get_double_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_52get_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_double_field", 0);

  /* "_javabridge.pyx":1238
 *         :rtype:  float
 *         '''
 *         return self.env[0].GetDoubleField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def set_object_field(self, JB_Object o, __JB_FieldID field, JB_Object value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetDoubleField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1229
 *         return self.env[0].GetFloatField(self.env, o.o, field.id)
 * 
 *     def get_double_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a double field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1240
 *         return self.env[0].GetDoubleField(self.env, o.o, field.id)
 * 
 *     def set_object_field(self, JB_Object o, __JB_FieldID field, JB_Object value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's object fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_55set_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_54set_object_field[] = "Set one of a Java object's object fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the Java object that will become the field's new value\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_55set_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_field", 1, 3, 3, 1); __PYX_ERR(0, 1240, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_field", 1, 3, 3, 2); __PYX_ERR(0, 1240, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_object_field") < 0)) __PYX_ERR(0, 1240, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = ((struct __pyx_obj_11_javabridge_JB_Object *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_object_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1240, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1240, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1240, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_value), __pyx_ptype_11_javabridge_JB_Object, 1, "value", 0))) __PYX_ERR(0, 1240, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_54set_object_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_54set_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_value) {
  jobject __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  void *__pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_object_field", 0);

  /* "_javabridge.pyx":1248
 *         '''
 *         cdef:
 *             jobject jvalue = NULL if value is None else value.o             # <<<<<<<<<<<<<<
 *         self.env[0].SetObjectField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_value) == Py_None);
  if ((__pyx_t_2 != 0)) {
    __pyx_t_1 = NULL;
  } else {
    __pyx_t_1 = __pyx_v_value->o;
  }
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1249
 *         cdef:
 *             jobject jvalue = NULL if value is None else value.o
 *         self.env[0].SetObjectField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_boolean_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetObjectField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1240
 *         return self.env[0].GetDoubleField(self.env, o.o, field.id)
 * 
 *     def set_object_field(self, JB_Object o, __JB_FieldID field, JB_Object value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's object fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1251
 *         self.env[0].SetObjectField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_boolean_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's boolean fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_57set_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_56set_boolean_field[] = "Set one of a Java object's boolean fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the truth value (True or False)\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_57set_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_boolean_field", 1, 3, 3, 1); __PYX_ERR(0, 1251, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_boolean_field", 1, 3, 3, 2); __PYX_ERR(0, 1251, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_boolean_field") < 0)) __PYX_ERR(0, 1251, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_boolean_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1251, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1251, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1251, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_56set_boolean_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_56set_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jboolean __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  jboolean __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_boolean_field", 0);

  /* "_javabridge.pyx":1259
 *         '''
 *         cdef:
 *             jboolean jvalue = 1 if value else 0             # <<<<<<<<<<<<<<
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1259, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1260
 *         cdef:
 *             jboolean jvalue = 1 if value else 0
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_byte_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetBooleanField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1251
 *         self.env[0].SetObjectField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_boolean_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's boolean fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1262
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_byte_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's byte fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_59set_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_58set_byte_field[] = "Set one of a Java object's byte fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the field's new int value \n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_59set_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_byte_field", 1, 3, 3, 1); __PYX_ERR(0, 1262, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_byte_field", 1, 3, 3, 2); __PYX_ERR(0, 1262, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_byte_field") < 0)) __PYX_ERR(0, 1262, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_byte_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1262, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1262, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1262, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_58set_byte_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_58set_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jbyte __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jbyte __pyx_t_2;
  __Pyx_RefNannySetupContext("set_byte_field", 0);

  /* "_javabridge.pyx":1270
 *         '''
 *         cdef:
 *             jbyte jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jbyte(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jbyte)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1271
 *         cdef:
 *             jbyte jvalue = int(value)
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_char_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetByteField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1262
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_byte_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's byte fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1273
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_char_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's char fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_61set_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_60set_char_field[] = "Set one of a Java object's char fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: should be convertible to unicode and at least 1 char long\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_61set_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_char_field", 1, 3, 3, 1); __PYX_ERR(0, 1273, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_char_field", 1, 3, 3, 2); __PYX_ERR(0, 1273, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_char_field") < 0)) __PYX_ERR(0, 1273, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_char_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1273, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1273, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1273, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_60set_char_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_60set_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jchar __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  __Pyx_RefNannySetupContext("set_char_field", 0);

  /* "_javabridge.pyx":1281
 *         '''
 *         cdef:
 *             jchar jvalue = ord(value[0])             # <<<<<<<<<<<<<<
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Ord(__pyx_t_1); if (unlikely(__pyx_t_2 == (long)(Py_UCS4)-1)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1282
 *         cdef:
 *             jchar jvalue = ord(value[0])
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_short_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetCharField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1273
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_char_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's char fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1284
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_short_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's short fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_63set_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_62set_short_field[] = "Set one of a Java object's short fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_63set_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_short_field", 1, 3, 3, 1); __PYX_ERR(0, 1284, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_short_field", 1, 3, 3, 2); __PYX_ERR(0, 1284, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_short_field") < 0)) __PYX_ERR(0, 1284, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_short_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1284, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1284, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1284, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_62set_short_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_62set_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jshort __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jshort __pyx_t_2;
  __Pyx_RefNannySetupContext("set_short_field", 0);

  /* "_javabridge.pyx":1292
 *         '''
 *         cdef:
 *             jshort jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jshort(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jshort)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1293
 *         cdef:
 *             jshort jvalue = int(value)
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_int_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetShortField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1284
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_short_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's short fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1295
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_int_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's byte fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_65set_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_64set_int_field[] = "Set one of a Java object's byte fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_65set_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_int_field", 1, 3, 3, 1); __PYX_ERR(0, 1295, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_int_field", 1, 3, 3, 2); __PYX_ERR(0, 1295, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_int_field") < 0)) __PYX_ERR(0, 1295, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_int_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1295, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1295, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1295, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_64set_int_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_64set_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jint __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jint __pyx_t_2;
  __Pyx_RefNannySetupContext("set_int_field", 0);

  /* "_javabridge.pyx":1303
 *         '''
 *         cdef:
 *             jint jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jint(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jint)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1304
 *         cdef:
 *             jint jvalue = int(value)
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_long_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetIntField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1295
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_int_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's byte fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1306
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_long_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's long fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_67set_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_66set_long_field[] = "Set one of a Java object's long fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_67set_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_long_field", 1, 3, 3, 1); __PYX_ERR(0, 1306, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_long_field", 1, 3, 3, 2); __PYX_ERR(0, 1306, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_long_field") < 0)) __PYX_ERR(0, 1306, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_long_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1306, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1306, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1306, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_66set_long_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_66set_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jlong __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jlong __pyx_t_2;
  __Pyx_RefNannySetupContext("set_long_field", 0);

  /* "_javabridge.pyx":1314
 *         '''
 *         cdef:
 *             jlong jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jlong(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jlong)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1315
 *         cdef:
 *             jlong jvalue = int(value)
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_float_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetLongField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1306
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_long_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's long fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1317
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_float_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's byte fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_69set_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_68set_float_field[] = "Set one of a Java object's byte fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the value to set, should be castable using float()\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_69set_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_float_field", 1, 3, 3, 1); __PYX_ERR(0, 1317, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_float_field", 1, 3, 3, 2); __PYX_ERR(0, 1317, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_float_field") < 0)) __PYX_ERR(0, 1317, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_float_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1317, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1317, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1317, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_68set_float_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_68set_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jfloat __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  __Pyx_RefNannySetupContext("set_float_field", 0);

  /* "_javabridge.pyx":1325
 *         '''
 *         cdef:
 *             jfloat jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1325, __pyx_L1_error)
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1326
 *         cdef:
 *             jfloat jvalue = float(value)
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_double_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetFloatField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1317
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_float_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's byte fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1328
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_double_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's float fields
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_71set_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_70set_double_field[] = "Set one of a Java object's float fields\n        \n        :param o: the Java object in question\n        :param field: a field id retrieved from :py:meth:`.get_field_id`\n        :param value: the value to set, should be castable using float()\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_71set_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_double_field", 1, 3, 3, 1); __PYX_ERR(0, 1328, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_double_field", 1, 3, 3, 2); __PYX_ERR(0, 1328, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_double_field") < 0)) __PYX_ERR(0, 1328, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_double_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1328, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1328, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1328, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_70set_double_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_70set_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jdouble __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  __Pyx_RefNannySetupContext("set_double_field", 0);

  /* "_javabridge.pyx":1336
 *         '''
 *         cdef:
 *             jdouble jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1336, __pyx_L1_error)
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1337
 *         cdef:
 *             jdouble jvalue = float(value)
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_field_id(self, JB_Class c, name, sig):
 */
  (__pyx_v_self->env[0])->SetDoubleField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1328
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_double_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set one of a Java object's float fields
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1339
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)
 * 
 *     def get_static_field_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Look up a static field ID on a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_73get_static_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_72get_static_field_id[] = "Look up a static field ID on a class\n\n        :param c: the object's class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param name: the field's name\n        :param sig: the signature of the field (e.g. \"java/lang/String\")\n        \n        :return: a field ID that can be used in calls to get and get static fields\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_73get_static_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sig = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_field_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_name,&__pyx_n_s_sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_field_id", 1, 3, 3, 1); __PYX_ERR(0, 1339, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_field_id", 1, 3, 3, 2); __PYX_ERR(0, 1339, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_field_id") < 0)) __PYX_ERR(0, 1339, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = values[1];
    __pyx_v_sig = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_field_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1339, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1339, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_72get_static_field_id(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_72get_static_field_id(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, PyObject *__pyx_v_name, PyObject *__pyx_v_sig) {
  jfieldID __pyx_v_id;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_jbid = 0;
  PyObject *__pyx_v_utf8name = NULL;
  PyObject *__pyx_v_utf8sig = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("get_static_field_id", 0);

  /* "_javabridge.pyx":1352
 *             __JB_FieldID jbid
 * 
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_utf8name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":1353
 * 
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_encode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__46, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_utf8sig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":1354
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return None
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_utf8name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1354, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_AsString(__pyx_v_utf8sig); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 1354, __pyx_L1_error)
  __pyx_v_id = (__pyx_v_self->env[0])->GetStaticFieldID(__pyx_v_self->env, __pyx_v_c->c, __pyx_t_3, __pyx_t_4);

  /* "_javabridge.pyx":1355
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         jbid = __JB_FieldID()
 */
  __pyx_t_5 = ((__pyx_v_id == NULL) != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1356
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "_javabridge.pyx":1355
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         jbid = __JB_FieldID()
 */
  }

  /* "_javabridge.pyx":1357
 *         if id == NULL:
 *             return None
 *         jbid = __JB_FieldID()             # <<<<<<<<<<<<<<
 *         jbid.id = id
 *         jbid.sig = sig
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge___JB_FieldID), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jbid = ((struct __pyx_obj_11_javabridge___JB_FieldID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":1358
 *             return None
 *         jbid = __JB_FieldID()
 *         jbid.id = id             # <<<<<<<<<<<<<<
 *         jbid.sig = sig
 *         jbid.is_static = False
 */
  __pyx_v_jbid->id = __pyx_v_id;

  /* "_javabridge.pyx":1359
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 *         jbid.sig = sig             # <<<<<<<<<<<<<<
 *         jbid.is_static = False
 *         return jbid
 */
  __Pyx_INCREF(__pyx_v_sig);
  __Pyx_GIVEREF(__pyx_v_sig);
  __Pyx_GOTREF(__pyx_v_jbid->sig);
  __Pyx_DECREF(__pyx_v_jbid->sig);
  __pyx_v_jbid->sig = __pyx_v_sig;

  /* "_javabridge.pyx":1360
 *         jbid.id = id
 *         jbid.sig = sig
 *         jbid.is_static = False             # <<<<<<<<<<<<<<
 *         return jbid
 * 
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_jbid->is_static);
  __Pyx_DECREF(__pyx_v_jbid->is_static);
  __pyx_v_jbid->is_static = Py_False;

  /* "_javabridge.pyx":1361
 *         jbid.sig = sig
 *         jbid.is_static = False
 *         return jbid             # <<<<<<<<<<<<<<
 * 
 *     def get_static_object_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbid));
  __pyx_r = ((PyObject *)__pyx_v_jbid);
  goto __pyx_L0;

  /* "_javabridge.pyx":1339
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)
 * 
 *     def get_static_field_id(self, JB_Class c, name, sig):             # <<<<<<<<<<<<<<
 *         '''Look up a static field ID on a class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbid);
  __Pyx_XDECREF(__pyx_v_utf8name);
  __Pyx_XDECREF(__pyx_v_utf8sig);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1363
 *         return jbid
 * 
 *     def get_static_object_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an object field on a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_75get_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_74get_static_object_field[] = "Return an object field on a class\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the object stored in the class's static field\n        :rtype: JB_Object\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_75get_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_object_field", 1, 2, 2, 1); __PYX_ERR(0, 1363, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_object_field") < 0)) __PYX_ERR(0, 1363, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_object_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1363, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1363, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1363, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_74get_static_object_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_74get_static_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  jobject __pyx_v_o;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("get_static_object_field", 0);

  /* "_javabridge.pyx":1374
 *         cdef:
 *             jobject o
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             return
 */
  __pyx_v_o = (__pyx_v_self->env[0])->GetStaticObjectField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id);

  /* "_javabridge.pyx":1375
 *             jobject o
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, o)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1376
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)
 *         if o == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":1375
 *             jobject o
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, o)
 */
  }

  /* "_javabridge.pyx":1377
 *         if o == NULL:
 *             return
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_2 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1377, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1377, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1377, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1378
 *             return
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1379
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1379, __pyx_L1_error)

    /* "_javabridge.pyx":1378
 *             return
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1380
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_static_boolean_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1363
 *         return jbid
 * 
 *     def get_static_object_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an object field on a class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1382
 *         return result
 * 
 *     def get_static_boolean_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a boolean static field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_77get_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_76get_static_boolean_field[] = "Return a boolean static field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the boolean value stored in the class's static field\n        :rtype: bool\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_77get_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_boolean_field", 1, 2, 2, 1); __PYX_ERR(0, 1382, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_boolean_field") < 0)) __PYX_ERR(0, 1382, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_boolean_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1382, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1382, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1382, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_76get_static_boolean_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_76get_static_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_boolean_field", 0);

  /* "_javabridge.pyx":1391
 *         :rtype: bool
 *         '''
 *         return self.env[0].GetStaticBooleanField(self.env, c.c, field.id) != 0             # <<<<<<<<<<<<<<
 * 
 *     def get_static_char_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(((__pyx_v_self->env[0])->GetStaticBooleanField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id) != 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1382
 *         return result
 * 
 *     def get_static_boolean_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a boolean static field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1393
 *         return self.env[0].GetStaticBooleanField(self.env, c.c, field.id) != 0
 * 
 *     def get_static_char_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a char static field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_79get_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_78get_static_char_field[] = "Return a char static field's value\n        \n        :param c: the class (e.g. as returieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the char value stored in the class's static field\n        :rtype: unichr\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_79get_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_char_field", 1, 2, 2, 1); __PYX_ERR(0, 1393, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_char_field") < 0)) __PYX_ERR(0, 1393, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_char_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1393, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1393, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1393, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_78get_static_char_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_78get_static_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get_static_char_field", 0);

  /* "_javabridge.pyx":1402
 *         :rtype: unichr
 *         '''
 *         return unichr(self.env[0].GetStaticCharField(self.env, c.c, field.id))             # <<<<<<<<<<<<<<
 * 
 *     def get_static_byte_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_jchar((__pyx_v_self->env[0])->GetStaticCharField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1402, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1402, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1402, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1393
 *         return self.env[0].GetStaticBooleanField(self.env, c.c, field.id) != 0
 * 
 *     def get_static_char_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a char static field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1404
 *         return unichr(self.env[0].GetStaticCharField(self.env, c.c, field.id))
 * 
 *     def get_static_byte_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a byte static field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_81get_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_80get_static_byte_field[] = "Return a byte static field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the byte value stored in the class's static field\n        :rtype: int\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_81get_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_byte_field", 1, 2, 2, 1); __PYX_ERR(0, 1404, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_byte_field") < 0)) __PYX_ERR(0, 1404, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_byte_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1404, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1404, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1404, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_80get_static_byte_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_80get_static_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_byte_field", 0);

  /* "_javabridge.pyx":1413
 *         :rtype: int
 *         '''
 *         return self.env[0].GetStaticByteField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_short_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jbyte((__pyx_v_self->env[0])->GetStaticByteField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1404
 *         return unichr(self.env[0].GetStaticCharField(self.env, c.c, field.id))
 * 
 *     def get_static_byte_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a byte static field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1415
 *         return self.env[0].GetStaticByteField(self.env, c.c, field.id)
 * 
 *     def get_static_short_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a short static field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_83get_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_82get_static_short_field[] = "Return a short static field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the short stored in the class's static field\n        :rtype: JB_Object\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_83get_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_short_field", 1, 2, 2, 1); __PYX_ERR(0, 1415, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_short_field") < 0)) __PYX_ERR(0, 1415, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_short_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1415, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1415, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1415, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_82get_static_short_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_82get_static_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_short_field", 0);

  /* "_javabridge.pyx":1424
 *         :rtype: JB_Object
 *         '''
 *         return self.env[0].GetStaticShortField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_int_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jshort((__pyx_v_self->env[0])->GetStaticShortField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1415
 *         return self.env[0].GetStaticByteField(self.env, c.c, field.id)
 * 
 *     def get_static_short_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a short static field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1426
 *         return self.env[0].GetStaticShortField(self.env, c.c, field.id)
 * 
 *     def get_static_int_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an int field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_85get_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_84get_static_int_field[] = "Return an int field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the integer value stored in the class's static field\n        :rtype: int\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_85get_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_int_field", 1, 2, 2, 1); __PYX_ERR(0, 1426, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_int_field") < 0)) __PYX_ERR(0, 1426, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_int_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1426, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1426, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1426, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_84get_static_int_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_84get_static_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_int_field", 0);

  /* "_javabridge.pyx":1435
 *         :rtype: int
 *         '''
 *         return self.env[0].GetStaticIntField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_long_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jint((__pyx_v_self->env[0])->GetStaticIntField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1426
 *         return self.env[0].GetStaticShortField(self.env, c.c, field.id)
 * 
 *     def get_static_int_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an int field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1437
 *         return self.env[0].GetStaticIntField(self.env, c.c, field.id)
 * 
 *     def get_static_long_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a long field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_87get_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_86get_static_long_field[] = "Return a long field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the long value stored in the class's static field\n        :rtype: long\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_87get_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_long_field", 1, 2, 2, 1); __PYX_ERR(0, 1437, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_long_field") < 0)) __PYX_ERR(0, 1437, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_long_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1437, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1437, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1437, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_86get_static_long_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_86get_static_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_long_field", 0);

  /* "_javabridge.pyx":1446
 *         :rtype: long
 *         '''
 *         return self.env[0].GetStaticLongField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_float_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jlong((__pyx_v_self->env[0])->GetStaticLongField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1437
 *         return self.env[0].GetStaticIntField(self.env, c.c, field.id)
 * 
 *     def get_static_long_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a long field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1448
 *         return self.env[0].GetStaticLongField(self.env, c.c, field.id)
 * 
 *     def get_static_float_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a float field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_89get_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_88get_static_float_field[] = "Return a float field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the float value stored in the class's static field\n        :rtype: float\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_89get_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_float_field", 1, 2, 2, 1); __PYX_ERR(0, 1448, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_float_field") < 0)) __PYX_ERR(0, 1448, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_float_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1448, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1448, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1448, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_88get_static_float_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_88get_static_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_float_field", 0);

  /* "_javabridge.pyx":1457
 *         :rtype: float
 *         '''
 *         return self.env[0].GetStaticFloatField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_double_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetStaticFloatField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1448
 *         return self.env[0].GetStaticLongField(self.env, c.c, field.id)
 * 
 *     def get_static_float_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a float field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1459
 *         return self.env[0].GetStaticFloatField(self.env, c.c, field.id)
 * 
 *     def get_static_double_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a double field's value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_91get_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_90get_static_double_field[] = "Return a double field's value\n        \n        :param c: the class (e.g. as retrieved from :py:meth:`.find_class`)\n        :param field: a field ID retrieved from :py:meth:`.get_static_field_id`\n        \n        :return: the double value stored in the class's static field\n        :rtype: float\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_91get_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_double_field", 1, 2, 2, 1); __PYX_ERR(0, 1459, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_double_field") < 0)) __PYX_ERR(0, 1459, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_double_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1459, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1459, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1459, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_90get_static_double_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_90get_static_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_static_double_field", 0);

  /* "_javabridge.pyx":1468
 *         :rtype: float
 *         '''
 *         return self.env[0].GetStaticDoubleField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_object_field(self, JB_Class c, __JB_FieldID field, JB_Object o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetStaticDoubleField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1459
 *         return self.env[0].GetStaticFloatField(self.env, c.c, field.id)
 * 
 *     def get_static_double_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a double field's value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1470
 *         return self.env[0].GetStaticDoubleField(self.env, c.c, field.id)
 * 
 *     def set_static_object_field(self, JB_Class c, __JB_FieldID field, JB_Object o):             # <<<<<<<<<<<<<<
 *         '''Set a static object field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_93set_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_92set_static_object_field[] = "Set a static object field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param o: the object that will become the field's new value\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_93set_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_o,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_object_field", 1, 3, 3, 1); __PYX_ERR(0, 1470, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_object_field", 1, 3, 3, 2); __PYX_ERR(0, 1470, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_object_field") < 0)) __PYX_ERR(0, 1470, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_o = ((struct __pyx_obj_11_javabridge_JB_Object *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_object_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1470, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1470, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1470, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_11_javabridge_JB_Object, 1, "o", 0))) __PYX_ERR(0, 1470, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_92set_static_object_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_o);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_92set_static_object_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_o) {
  jobject __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  void *__pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_object_field", 0);

  /* "_javabridge.pyx":1478
 *         '''
 *         cdef:
 *             jobject jvalue = NULL if o is None else o.o             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticObjectField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_o) == Py_None);
  if ((__pyx_t_2 != 0)) {
    __pyx_t_1 = NULL;
  } else {
    __pyx_t_1 = __pyx_v_o->o;
  }
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1479
 *         cdef:
 *             jobject jvalue = NULL if o is None else o.o
 *         self.env[0].SetStaticObjectField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_boolean_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticObjectField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1470
 *         return self.env[0].GetStaticDoubleField(self.env, c.c, field.id)
 * 
 *     def set_static_object_field(self, JB_Class c, __JB_FieldID field, JB_Object o):             # <<<<<<<<<<<<<<
 *         '''Set a static object field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1481
 *         self.env[0].SetStaticObjectField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_boolean_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static boolean field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_95set_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_94set_static_boolean_field[] = "Set a static boolean field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be cast to bool and assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_95set_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_boolean_field", 1, 3, 3, 1); __PYX_ERR(0, 1481, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_boolean_field", 1, 3, 3, 2); __PYX_ERR(0, 1481, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_boolean_field") < 0)) __PYX_ERR(0, 1481, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_boolean_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1481, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1481, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1481, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_94set_static_boolean_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_94set_static_boolean_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jboolean __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  jboolean __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_boolean_field", 0);

  /* "_javabridge.pyx":1489
 *         '''
 *         cdef:
 *             jboolean jvalue = 1 if value else 0             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1489, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1490
 *         cdef:
 *             jboolean jvalue = 1 if value else 0
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticBooleanField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1481
 *         self.env[0].SetStaticObjectField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_boolean_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static boolean field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1492
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static char field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_97set_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_96set_static_char_field[] = "Set a static char field in a class\n\n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be cast to a short and assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_97set_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, 1); __PYX_ERR(0, 1492, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, 2); __PYX_ERR(0, 1492, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_char_field") < 0)) __PYX_ERR(0, 1492, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1492, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1492, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1492, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_96set_static_char_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_96set_static_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jchar __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_char_field", 0);

  /* "_javabridge.pyx":1500
 *         '''
 *         cdef:
 *             jchar jvalue = ord(value[0])             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Ord(__pyx_t_1); if (unlikely(__pyx_t_2 == (long)(Py_UCS4)-1)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1501
 *         cdef:
 *             jchar jvalue = ord(value[0])
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_byte_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticCharField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1492
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static char field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1503
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_byte_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static byte field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_99set_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_98set_static_byte_field[] = "Set a static byte field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_99set_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_byte_field", 1, 3, 3, 1); __PYX_ERR(0, 1503, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_byte_field", 1, 3, 3, 2); __PYX_ERR(0, 1503, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_byte_field") < 0)) __PYX_ERR(0, 1503, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_byte_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1503, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1503, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1503, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_98set_static_byte_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_98set_static_byte_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jbyte __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jbyte __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_byte_field", 0);

  /* "_javabridge.pyx":1511
 *         '''
 *         cdef:
 *             jbyte jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jbyte(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jbyte)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1511, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1512
 *         cdef:
 *             jbyte jvalue = int(value)
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticByteField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1503
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_byte_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static byte field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1514
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static char field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_101set_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_100set_static_char_field[] = "Set a static char field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_101set_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, 1); __PYX_ERR(0, 1514, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, 2); __PYX_ERR(0, 1514, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_char_field") < 0)) __PYX_ERR(0, 1514, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1514, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1514, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1514, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_100set_static_char_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_100set_static_char_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jchar __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_char_field", 0);

  /* "_javabridge.pyx":1522
 *         '''
 *         cdef:
 *             jchar jvalue = ord(value[0])             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Ord(__pyx_t_1); if (unlikely(__pyx_t_2 == (long)(Py_UCS4)-1)) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1523
 *         cdef:
 *             jchar jvalue = ord(value[0])
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_short_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticCharField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1514
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static char field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1525
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_short_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static short field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_103set_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_102set_static_short_field[] = "Set a static short field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_103set_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_short_field", 1, 3, 3, 1); __PYX_ERR(0, 1525, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_short_field", 1, 3, 3, 2); __PYX_ERR(0, 1525, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_short_field") < 0)) __PYX_ERR(0, 1525, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_short_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1525, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1525, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1525, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_102set_static_short_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_102set_static_short_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jshort __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jshort __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_short_field", 0);

  /* "_javabridge.pyx":1533
 *         '''
 *         cdef:
 *             jshort jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jshort(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jshort)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1534
 *         cdef:
 *             jshort jvalue = int(value)
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_int_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticShortField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1525
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_short_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static short field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1536
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_int_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static int field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_105set_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_104set_static_int_field[] = "Set a static int field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_105set_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_int_field", 1, 3, 3, 1); __PYX_ERR(0, 1536, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_int_field", 1, 3, 3, 2); __PYX_ERR(0, 1536, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_int_field") < 0)) __PYX_ERR(0, 1536, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_int_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1536, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1536, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1536, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_104set_static_int_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_104set_static_int_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jint __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jint __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_int_field", 0);

  /* "_javabridge.pyx":1544
 *         '''
 *         cdef:
 *             jint jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jint(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jint)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1544, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1545
 *         cdef:
 *             jint jvalue = int(value)
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_long_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticIntField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1536
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_int_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static int field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1547
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_long_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static long field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_107set_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_106set_static_long_field[] = "Set a static long field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_107set_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_long_field", 1, 3, 3, 1); __PYX_ERR(0, 1547, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_long_field", 1, 3, 3, 2); __PYX_ERR(0, 1547, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_long_field") < 0)) __PYX_ERR(0, 1547, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_long_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1547, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1547, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1547, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_106set_static_long_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_106set_static_long_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jlong __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jlong __pyx_t_2;
  __Pyx_RefNannySetupContext("set_static_long_field", 0);

  /* "_javabridge.pyx":1555
 *         '''
 *         cdef:
 *             jlong jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_jlong(__pyx_t_1); if (unlikely((__pyx_t_2 == ((jlong)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_jvalue = __pyx_t_2;

  /* "_javabridge.pyx":1556
 *         cdef:
 *             jlong jvalue = int(value)
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_float_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticLongField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1547
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_long_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static long field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1558
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_float_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static float field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_109set_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_108set_static_float_field[] = "Set a static float field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_109set_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_float_field", 1, 3, 3, 1); __PYX_ERR(0, 1558, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_float_field", 1, 3, 3, 2); __PYX_ERR(0, 1558, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_float_field") < 0)) __PYX_ERR(0, 1558, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_float_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1558, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1558, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1558, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_108set_static_float_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_108set_static_float_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jfloat __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  __Pyx_RefNannySetupContext("set_static_float_field", 0);

  /* "_javabridge.pyx":1566
 *         '''
 *         cdef:
 *             jfloat jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1566, __pyx_L1_error)
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1567
 *         cdef:
 *             jfloat jvalue = float(value)
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_double_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticFloatField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1558
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_float_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static float field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1569
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_double_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static double field in a class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_111set_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_110set_static_double_field[] = "Set a static double field in a class\n        \n        :param c: the class in question, e.g. as retrieved from :py:meth:`.find_class`\n        :param field: a field id retrieved from :py:meth:'.get_static_field_id`\n        :param value: a value that will be assigned to the field\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_111set_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_field,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_double_field", 1, 3, 3, 1); __PYX_ERR(0, 1569, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_double_field", 1, 3, 3, 2); __PYX_ERR(0, 1569, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_double_field") < 0)) __PYX_ERR(0, 1569, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_double_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1569, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1569, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_11_javabridge___JB_FieldID, 1, "field", 0))) __PYX_ERR(0, 1569, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_110set_static_double_field(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_110set_static_double_field(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jdouble __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  __Pyx_RefNannySetupContext("set_static_double_field", 0);

  /* "_javabridge.pyx":1577
 *         '''
 *         cdef:
 *             jdouble jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1577, __pyx_L1_error)
  __pyx_v_jvalue = __pyx_t_1;

  /* "_javabridge.pyx":1578
 *         cdef:
 *             jdouble jvalue = float(value)
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def new_object(self, JB_Class c, __JB_MethodID m, *args):
 */
  (__pyx_v_self->env[0])->SetStaticDoubleField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  /* "_javabridge.pyx":1569
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_double_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static double field in a class
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1580
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)
 * 
 *     def new_object(self, JB_Class c, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a class constructor with arguments
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_113new_object(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_112new_object[] = "Call a class constructor with arguments\n\n        :param c: class in question\n        :param m: the method ID. You can get this by calling\n                  get_method_id with a name of \"<init>\" and a return\n                  type of V\n        :param args: the arguments to the method call. Arguments\n                      should appear in the same order as the\n                      signature. Arguments will be coerced into the\n                      type of the signature.\n\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_113new_object(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_object (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_c,&__pyx_n_s_m,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_m)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("new_object", 0, 2, 2, 1); __PYX_ERR(0, 1580, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "new_object") < 0)) __PYX_ERR(0, 1580, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_11_javabridge_JB_Class *)values[0]);
    __pyx_v_m = ((struct __pyx_obj_11_javabridge___JB_MethodID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("new_object", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1580, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("_javabridge.JB_Env.new_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_11_javabridge_JB_Class, 1, "c", 0))) __PYX_ERR(0, 1580, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_m), __pyx_ptype_11_javabridge___JB_MethodID, 1, "m", 0))) __PYX_ERR(0, 1580, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_112new_object(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_m, __pyx_v_args);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_112new_object(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args) {
  jvalue *__pyx_v_values;
  jobject __pyx_v_oresult;
  jclass __pyx_v_klass;
  jmethodID __pyx_v_m_id;
  JNIEnv *__pyx_v_jnienv;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg_end = NULL;
  PyObject *__pyx_v_arg_sig = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  jclass __pyx_t_1;
  jmethodID __pyx_t_2;
  JNIEnv *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  __Pyx_RefNannySetupContext("new_object", 0);

  /* "_javabridge.pyx":1596
 *             jvalue *values
 *             jobject oresult
 *             jclass klass = c.c             # <<<<<<<<<<<<<<
 *             jmethodID m_id = m.id
 *             JNIEnv *jnienv = self.env
 */
  __pyx_t_1 = __pyx_v_c->c;
  __pyx_v_klass = __pyx_t_1;

  /* "_javabridge.pyx":1597
 *             jobject oresult
 *             jclass klass = c.c
 *             jmethodID m_id = m.id             # <<<<<<<<<<<<<<
 *             JNIEnv *jnienv = self.env
 * 
 */
  __pyx_t_2 = __pyx_v_m->id;
  __pyx_v_m_id = __pyx_t_2;

  /* "_javabridge.pyx":1598
 *             jclass klass = c.c
 *             jmethodID m_id = m.id
 *             JNIEnv *jnienv = self.env             # <<<<<<<<<<<<<<
 * 
 *         sig = m.sig
 */
  __pyx_t_3 = __pyx_v_self->env;
  __pyx_v_jnienv = __pyx_t_3;

  /* "_javabridge.pyx":1600
 *             JNIEnv *jnienv = self.env
 * 
 *         sig = m.sig             # <<<<<<<<<<<<<<
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_4 = __pyx_v_m->sig;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_sig = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1601
 * 
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_sig, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_4, __pyx_kp_s__37, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1602
 *         sig = m.sig
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 */
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Bad_function_signature_s, __pyx_v_m->sig); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1602, __pyx_L1_error)

    /* "_javabridge.pyx":1601
 * 
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  }

  /* "_javabridge.pyx":1603
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_find); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_arg_end = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":1604
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  __pyx_t_6 = __Pyx_PyInt_EqObjC(__pyx_v_arg_end, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1605
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 */
    __pyx_t_6 = __Pyx_PyString_Format(__pyx_kp_s_Bad_function_signature_s, __pyx_v_m->sig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 1605, __pyx_L1_error)

    /* "_javabridge.pyx":1604
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  }

  /* "_javabridge.pyx":1606
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]             # <<<<<<<<<<<<<<
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 */
  __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_v_sig, 1, 0, NULL, &__pyx_v_arg_end, NULL, 1, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_arg_sig = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":1607
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)             # <<<<<<<<<<<<<<
 *         if error is not None:
 *             raise error
 */
  __pyx_t_6 = __pyx_f_11_javabridge_fill_values(__pyx_v_arg_sig, __pyx_v_args, (&__pyx_v_values)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_error = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":1608
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         with nogil:
 */
  __pyx_t_5 = (__pyx_v_error != Py_None);
  __pyx_t_7 = (__pyx_t_5 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1609
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 *             raise error             # <<<<<<<<<<<<<<
 *         with nogil:
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 1609, __pyx_L1_error)

    /* "_javabridge.pyx":1608
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         with nogil:
 */
  }

  /* "_javabridge.pyx":1610
 *         if error is not None:
 *             raise error
 *         with nogil:             # <<<<<<<<<<<<<<
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)
 *         free(values)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      #endif
      /*try:*/ {

        /* "_javabridge.pyx":1611
 *             raise error
 *         with nogil:
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)             # <<<<<<<<<<<<<<
 *         free(values)
 *         if oresult == NULL:
 */
        __pyx_v_oresult = (__pyx_v_jnienv[0])->NewObjectA(__pyx_v_jnienv, __pyx_v_klass, __pyx_v_m_id, __pyx_v_values);
      }

      /* "_javabridge.pyx":1610
 *         if error is not None:
 *             raise error
 *         with nogil:             # <<<<<<<<<<<<<<
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)
 *         free(values)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "_javabridge.pyx":1612
 *         with nogil:
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)
 *         free(values)             # <<<<<<<<<<<<<<
 *         if oresult == NULL:
 *             return
 */
  free(__pyx_v_values);

  /* "_javabridge.pyx":1613
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)
 *         free(values)
 *         if oresult == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, oresult)
 */
  __pyx_t_7 = ((__pyx_v_oresult == NULL) != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1614
 *         free(values)
 *         if oresult == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_javabridge.pyx":1613
 *             oresult = jnienv[0].NewObjectA(jnienv, klass, m_id, values)
 *         free(values)
 *         if oresult == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, oresult)
 */
  }

  /* "_javabridge.pyx":1615
 *         if oresult == NULL:
 *             return
 *         result, e = make_jb_object(self, oresult)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_6 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_oresult); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
    PyObject* sequence = __pyx_t_6;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1615, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_8);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    #endif
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_9 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
    index = 0; __pyx_t_4 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_4)) goto __pyx_L10_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L10_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 1615, __pyx_L1_error)
    __pyx_t_10 = NULL;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L11_unpacking_done;
    __pyx_L10_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_10 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1615, __pyx_L1_error)
    __pyx_L11_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_e = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "_javabridge.pyx":1616
 *             return
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_7 = (__pyx_v_e != Py_None);
  __pyx_t_5 = (__pyx_t_7 != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1617
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1617, __pyx_L1_error)

    /* "_javabridge.pyx":1616
 *             return
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1618
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def new_string(self, u):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1580
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)
 * 
 *     def new_object(self, JB_Class c, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a class constructor with arguments
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("_javabridge.JB_Env.new_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg_end);
  __Pyx_XDECREF(__pyx_v_arg_sig);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1620
 *         return result
 * 
 *     def new_string(self, u):             # <<<<<<<<<<<<<<
 *         '''Turn a unicode string into a Java string object
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_115new_string(PyObject *__pyx_v_self, PyObject *__pyx_v_u); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_114new_string[] = "Turn a unicode string into a Java string object\n        \n        :param u: a unicode string (ideally) or a string that can be\n                  encoded in utf-16 like this: u.encode(\"utf-16\")\n                  \n        :return: a Java string object\n        :rtype: JB_Object\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_115new_string(PyObject *__pyx_v_self, PyObject *__pyx_v_u) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_string (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_114new_string(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_u));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_114new_string(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_u) {
  char *__pyx_v_s;
  jsize __pyx_v_nchars;
  jobject __pyx_v_o;
  PyObject *__pyx_v_u16 = NULL;
  PyObject *__pyx_v_jbo = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("new_string", 0);

  /* "_javabridge.pyx":1633
 *             jsize nchars
 *             jobject o
 *         u16 = u.encode("utf-16")             # <<<<<<<<<<<<<<
 *         nchars = len(u16) / 2 - 1
 *         s = u16
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_u, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_u16 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":1634
 *             jobject o
 *         u16 = u.encode("utf-16")
 *         nchars = len(u16) / 2 - 1             # <<<<<<<<<<<<<<
 *         s = u16
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_u16); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1634, __pyx_L1_error)
  __pyx_v_nchars = (__Pyx_div_Py_ssize_t(__pyx_t_3, 2) - 1);

  /* "_javabridge.pyx":1635
 *         u16 = u.encode("utf-16")
 *         nchars = len(u16) / 2 - 1
 *         s = u16             # <<<<<<<<<<<<<<
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)
 *         if o == NULL:
 */
  __pyx_t_4 = __Pyx_PyObject_AsString(__pyx_v_u16); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 1635, __pyx_L1_error)
  __pyx_v_s = __pyx_t_4;

  /* "_javabridge.pyx":1636
 *         nchars = len(u16) / 2 - 1
 *         s = u16
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewString(__pyx_v_self->env, (((jchar *)__pyx_v_s) + 1), __pyx_v_nchars);

  /* "_javabridge.pyx":1637
 *         s = u16
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 */
  __pyx_t_5 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_5) {

    /* "_javabridge.pyx":1638
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")             # <<<<<<<<<<<<<<
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1638, __pyx_L1_error)

    /* "_javabridge.pyx":1637
 *         s = u16
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 */
  }

  /* "_javabridge.pyx":1639
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *              raise e
 */
  __pyx_t_2 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1639, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_6);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 1639, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1639, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_jbo = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_e = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "_javabridge.pyx":1640
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *              raise e
 *         return jbo
 */
  __pyx_t_5 = (__pyx_v_e != Py_None);
  __pyx_t_9 = (__pyx_t_5 != 0);
  if (__pyx_t_9) {

    /* "_javabridge.pyx":1641
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 *              raise e             # <<<<<<<<<<<<<<
 *         return jbo
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1641, __pyx_L1_error)

    /* "_javabridge.pyx":1640
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *              raise e
 *         return jbo
 */
  }

  /* "_javabridge.pyx":1642
 *         if e is not None:
 *              raise e
 *         return jbo             # <<<<<<<<<<<<<<
 * 
 *     def new_string_utf(self, s):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_jbo);
  __pyx_r = __pyx_v_jbo;
  goto __pyx_L0;

  /* "_javabridge.pyx":1620
 *         return result
 * 
 *     def new_string(self, u):             # <<<<<<<<<<<<<<
 *         '''Turn a unicode string into a Java string object
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("_javabridge.JB_Env.new_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_u16);
  __Pyx_XDECREF(__pyx_v_jbo);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1644
 *         return jbo
 * 
 *     def new_string_utf(self, s):             # <<<<<<<<<<<<<<
 *         '''Turn a Python string into a Java string object
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_117new_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_v_s); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_116new_string_utf[] = "Turn a Python string into a Java string object\n        \n        :param s: a Python string or unicode object\n        :return: a Java string object\n        :rtype: JB_Object\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_117new_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_string_utf (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_116new_string_utf(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_s));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_116new_string_utf(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_s) {
  jobject __pyx_v_o;
  PyObject *__pyx_v_jbo = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("new_string_utf", 0);

  /* "_javabridge.pyx":1653
 *         cdef:
 *             jobject o
 *         o = self.env[0].NewStringUTF(self.env, s.encode('utf-8'))             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1653, __pyx_L1_error)
  __pyx_v_o = (__pyx_v_self->env[0])->NewStringUTF(__pyx_v_self->env, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_javabridge.pyx":1654
 *             jobject o
 *         o = self.env[0].NewStringUTF(self.env, s.encode('utf-8'))
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 */
  __pyx_t_4 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_4) {

    /* "_javabridge.pyx":1655
 *         o = self.env[0].NewStringUTF(self.env, s.encode('utf-8'))
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")             # <<<<<<<<<<<<<<
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1655, __pyx_L1_error)

    /* "_javabridge.pyx":1654
 *             jobject o
 *         o = self.env[0].NewStringUTF(self.env, s.encode('utf-8'))
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 */
  }

  /* "_javabridge.pyx":1656
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *              raise e
 */
  __pyx_t_2 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1656, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 1656, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1656, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_jbo = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_e = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "_javabridge.pyx":1657
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *              raise e
 *         return jbo
 */
  __pyx_t_4 = (__pyx_v_e != Py_None);
  __pyx_t_8 = (__pyx_t_4 != 0);
  if (__pyx_t_8) {

    /* "_javabridge.pyx":1658
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 *              raise e             # <<<<<<<<<<<<<<
 *         return jbo
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1658, __pyx_L1_error)

    /* "_javabridge.pyx":1657
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *              raise e
 *         return jbo
 */
  }

  /* "_javabridge.pyx":1659
 *         if e is not None:
 *              raise e
 *         return jbo             # <<<<<<<<<<<<<<
 * 
 *     def get_string(self, JB_Object s):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_jbo);
  __pyx_r = __pyx_v_jbo;
  goto __pyx_L0;

  /* "_javabridge.pyx":1644
 *         return jbo
 * 
 *     def new_string_utf(self, s):             # <<<<<<<<<<<<<<
 *         '''Turn a Python string into a Java string object
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_javabridge.JB_Env.new_string_utf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_jbo);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1661
 *         return jbo
 * 
 *     def get_string(self, JB_Object s):             # <<<<<<<<<<<<<<
 *         '''Turn a Java string object into a Python unicode string
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_119get_string(PyObject *__pyx_v_self, PyObject *__pyx_v_s); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_118get_string[] = "Turn a Java string object into a Python unicode string\n        \n        :param s: a Java object\n        :return: the unicode string representation of the object\n        :rtype: unicode\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_119get_string(PyObject *__pyx_v_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_string (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_ptype_11_javabridge_JB_Object, 1, "s", 0))) __PYX_ERR(0, 1661, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_118get_string(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_s));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_118get_string(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_s) {
  jsize __pyx_v_nchars;
  jchar const *__pyx_v_chars;
  int __pyx_v_byteorder;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_string", 0);

  /* "_javabridge.pyx":1669
 *         '''
 *         cdef:
 *             jsize nchars = self.env[0].GetStringLength(self.env, s.o)             # <<<<<<<<<<<<<<
 *             const jchar *chars
 *             int byteorder = 0
 */
  __pyx_v_nchars = (__pyx_v_self->env[0])->GetStringLength(__pyx_v_self->env, __pyx_v_s->o);

  /* "_javabridge.pyx":1671
 *             jsize nchars = self.env[0].GetStringLength(self.env, s.o)
 *             const jchar *chars
 *             int byteorder = 0             # <<<<<<<<<<<<<<
 *         if <int>s.o == 0:
 *             return None
 */
  __pyx_v_byteorder = 0;

  /* "_javabridge.pyx":1672
 *             const jchar *chars
 *             int byteorder = 0
 *         if <int>s.o == 0:             # <<<<<<<<<<<<<<
 *             return None
 *         chars = self.env[0].GetStringChars(self.env, s.o, NULL)
 */
  __pyx_t_1 = ((((int)__pyx_v_s->o) == 0) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1673
 *             int byteorder = 0
 *         if <int>s.o == 0:
 *             return None             # <<<<<<<<<<<<<<
 *         chars = self.env[0].GetStringChars(self.env, s.o, NULL)
 *         result = PyUnicode_DecodeUTF16(
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "_javabridge.pyx":1672
 *             const jchar *chars
 *             int byteorder = 0
 *         if <int>s.o == 0:             # <<<<<<<<<<<<<<
 *             return None
 *         chars = self.env[0].GetStringChars(self.env, s.o, NULL)
 */
  }

  /* "_javabridge.pyx":1674
 *         if <int>s.o == 0:
 *             return None
 *         chars = self.env[0].GetStringChars(self.env, s.o, NULL)             # <<<<<<<<<<<<<<
 *         result = PyUnicode_DecodeUTF16(
 *             <const char *>chars, nchars*2, "ignore", &byteorder)
 */
  __pyx_v_chars = (__pyx_v_self->env[0])->GetStringChars(__pyx_v_self->env, __pyx_v_s->o, NULL);

  /* "_javabridge.pyx":1675
 *             return None
 *         chars = self.env[0].GetStringChars(self.env, s.o, NULL)
 *         result = PyUnicode_DecodeUTF16(             # <<<<<<<<<<<<<<
 *             <const char *>chars, nchars*2, "ignore", &byteorder)
 *         self.env[0].ReleaseStringChars(self.env, s.o, chars)
 */
  __pyx_t_2 = PyUnicode_DecodeUTF16(((char const *)__pyx_v_chars), (__pyx_v_nchars * 2), ((char *)"ignore"), (&__pyx_v_byteorder)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":1677
 *         result = PyUnicode_DecodeUTF16(
 *             <const char *>chars, nchars*2, "ignore", &byteorder)
 *         self.env[0].ReleaseStringChars(self.env, s.o, chars)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->ReleaseStringChars(__pyx_v_self->env, __pyx_v_s->o, __pyx_v_chars);

  /* "_javabridge.pyx":1678
 *             <const char *>chars, nchars*2, "ignore", &byteorder)
 *         self.env[0].ReleaseStringChars(self.env, s.o, chars)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_string_utf(self, JB_Object s):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1661
 *         return jbo
 * 
 *     def get_string(self, JB_Object s):             # <<<<<<<<<<<<<<
 *         '''Turn a Java string object into a Python unicode string
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1680
 *         return result
 * 
 *     def get_string_utf(self, JB_Object s):             # <<<<<<<<<<<<<<
 *         '''Turn a Java string object into a Python string
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_121get_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_v_s); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_120get_string_utf[] = "Turn a Java string object into a Python string\n\n        :param s: a Java object\n        :return: a string (Python 3) or unicode (Python 2) representation of s\n        :rtype: str\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_121get_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_string_utf (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_ptype_11_javabridge_JB_Object, 1, "s", 0))) __PYX_ERR(0, 1680, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_120get_string_utf(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_s));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_120get_string_utf(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_s) {
  char const *__pyx_v_chars;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_string_utf", 0);

  /* "_javabridge.pyx":1689
 *         cdef:
 *            const char *chars
 *         if <int> s.o == 0:             # <<<<<<<<<<<<<<
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 */
  __pyx_t_1 = ((((int)__pyx_v_s->o) == 0) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1690
 *            const char *chars
 *         if <int> s.o == 0:
 *            return None             # <<<<<<<<<<<<<<
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 *         result = chars.decode('utf-8')
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "_javabridge.pyx":1689
 *         cdef:
 *            const char *chars
 *         if <int> s.o == 0:             # <<<<<<<<<<<<<<
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 */
  }

  /* "_javabridge.pyx":1691
 *         if <int> s.o == 0:
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)             # <<<<<<<<<<<<<<
 *         result = chars.decode('utf-8')
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)
 */
  __pyx_v_chars = (__pyx_v_self->env[0])->GetStringUTFChars(__pyx_v_self->env, __pyx_v_s->o, NULL);

  /* "_javabridge.pyx":1692
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 *         result = chars.decode('utf-8')             # <<<<<<<<<<<<<<
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)
 *         return result
 */
  __pyx_t_2 = __Pyx_decode_c_string(__pyx_v_chars, 0, strlen(__pyx_v_chars), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":1693
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 *         result = chars.decode('utf-8')
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->ReleaseStringUTFChars(__pyx_v_self->env, __pyx_v_s->o, __pyx_v_chars);

  /* "_javabridge.pyx":1694
 *         result = chars.decode('utf-8')
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_array_length(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1680
 *         return result
 * 
 *     def get_string_utf(self, JB_Object s):             # <<<<<<<<<<<<<<
 *         '''Turn a Java string object into a Python string
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_string_utf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1696
 *         return result
 * 
 *     def get_array_length(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the length of an array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_123get_array_length(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_122get_array_length[] = "Return the length of an array\n        \n        :param array: a Java array\n        :return: the number of elements in the array\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_123get_array_length(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_array_length (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1696, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_122get_array_length(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_122get_array_length(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_array_length", 0);

  /* "_javabridge.pyx":1702
 *         :return: the number of elements in the array
 *         '''
 *         return self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *     def get_boolean_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_jint((__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1696
 *         return result
 * 
 *     def get_array_length(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the length of an array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_array_length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1704
 *         return self.env[0].GetArrayLength(self.env, array.o)
 * 
 *     def get_boolean_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java boolean array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_125get_boolean_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_124get_boolean_array_elements[] = "Return the contents of a Java boolean array as a numpy array\n        \n        :param array: a Java boolean array\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_125get_boolean_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_boolean_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1704, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_124get_boolean_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_124get_boolean_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("get_boolean_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1712
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1714
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_uint8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1714, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1714, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1715
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)
 *         return result.astype(np.bool8)
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1716
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)             # <<<<<<<<<<<<<<
 *         return result.astype(np.bool8)
 * 
 */
  (__pyx_v_self->env[0])->GetBooleanArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jboolean *)__pyx_v_data));

  /* "_javabridge.pyx":1717
 *         data = result.data
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)
 *         return result.astype(np.bool8)             # <<<<<<<<<<<<<<
 * 
 *     def get_byte_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_astype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_bool8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1717, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1717, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1717, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_11, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1704
 *         return self.env[0].GetArrayLength(self.env, array.o)
 * 
 *     def get_boolean_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java boolean array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_boolean_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1719
 *         return result.astype(np.bool8)
 * 
 *     def get_byte_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java byte array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_127get_byte_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_126get_byte_array_elements[] = "Return the contents of a Java byte array as a numpy array\n\n        array - a Java \"byte []\" array\n        returns a 1-d numpy array of np.uint8s\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_127get_byte_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_byte_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1719, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_126get_byte_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_126get_byte_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  __Pyx_RefNannySetupContext("get_byte_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1728
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1730
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_uint8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1730, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1730, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1731
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1732
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetByteArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jbyte *)__pyx_v_data));

  /* "_javabridge.pyx":1733
 *         data = result.data
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_short_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":1719
 *         return result.astype(np.bool8)
 * 
 *     def get_byte_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java byte array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_byte_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1735
 *         return result
 * 
 *     def get_short_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java short array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_129get_short_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_128get_short_array_elements[] = "Return the contents of a Java short array as a numpy array\n        \n        array - a Java \"short []\" array\n        returns a 1-d numpy array of np.int16s\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_129get_short_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_short_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1735, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_128get_short_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_128get_short_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  __Pyx_RefNannySetupContext("get_short_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1744
 *             np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int16)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1746
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int16)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_int16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1746, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1746, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1747
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int16)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1748
 *         result = np.zeros(shape=(alen,),dtype=np.int16)
 *         data = result.data
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetShortArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jshort *)__pyx_v_data));

  /* "_javabridge.pyx":1749
 *         data = result.data
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_int_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":1735
 *         return result
 * 
 *     def get_short_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java short array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_short_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1751
 *         return result
 * 
 *     def get_int_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java byte array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_131get_int_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_130get_int_array_elements[] = "Return the contents of a Java byte array as a numpy array\n        \n        array - a Java \"int []\" array\n        returns a 1-d numpy array of np.int32s\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_131get_int_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_int_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1751, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_130get_int_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_130get_int_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  __Pyx_RefNannySetupContext("get_int_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1760
 *             np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int32)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1762
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int32)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_int32); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1762, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1762, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1763
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int32)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1764
 *         result = np.zeros(shape=(alen,),dtype=np.int32)
 *         data = result.data
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetIntArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jint *)__pyx_v_data));

  /* "_javabridge.pyx":1765
 *         data = result.data
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_long_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":1751
 *         return result
 * 
 *     def get_int_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java byte array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_int_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1767
 *         return result
 * 
 *     def get_long_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java long array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_133get_long_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_132get_long_array_elements[] = "Return the contents of a Java long array as a numpy array\n        \n        array - a Java \"long []\" array\n        returns a 1-d numpy array of np.int64s\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_133get_long_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_long_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1767, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_132get_long_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_132get_long_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  __Pyx_RefNannySetupContext("get_long_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1776
 *             np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int64)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1778
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int64)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_int64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1778, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1778, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1779
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int64)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1780
 *         result = np.zeros(shape=(alen,),dtype=np.int64)
 *         data = result.data
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetLongArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jlong *)__pyx_v_data));

  /* "_javabridge.pyx":1781
 *         data = result.data
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_float_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":1767
 *         return result
 * 
 *     def get_long_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java long array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_long_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1783
 *         return result
 * 
 *     def get_float_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java float array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_135get_float_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_134get_float_array_elements[] = "Return the contents of a Java float array as a numpy array\n        \n        array - a Java \"float []\" array\n        returns a 1-d numpy array of np.int32s\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_135get_float_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_float_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1783, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_134get_float_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_134get_float_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  __Pyx_RefNannySetupContext("get_float_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1792
 *             np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float32)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1794
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float32)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float32); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1794, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1794, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1795
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float32)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1796
 *         result = np.zeros(shape=(alen,),dtype=np.float32)
 *         data = result.data
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetFloatArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jfloat *)__pyx_v_data));

  /* "_javabridge.pyx":1797
 *         data = result.data
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_double_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":1783
 *         return result
 * 
 *     def get_float_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java float array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_float_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1799
 *         return result
 * 
 *     def get_double_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java double array as a numpy array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_137get_double_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_136get_double_array_elements[] = "Return the contents of a Java double array as a numpy array\n        \n        array - a Java \"int []\" array\n        returns a 1-d numpy array of np.int32s\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_137get_double_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_double_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1799, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_136get_double_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_136get_double_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  __Pyx_RefNannySetupContext("get_double_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "_javabridge.pyx":1808
 *             np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float64)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1810
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float64)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1810, __pyx_L1_error)
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1810, __pyx_L1_error)
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":1811
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float64)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "_javabridge.pyx":1812
 *         result = np.zeros(shape=(alen,),dtype=np.float64)
 *         data = result.data
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetDoubleArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jdouble *)__pyx_v_data));

  /* "_javabridge.pyx":1813
 *         data = result.data
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_object_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "_javabridge.pyx":1799
 *         return result
 * 
 *     def get_double_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java double array as a numpy array
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.get_double_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1815
 *         return result
 * 
 *     def get_object_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java object array as a list of wrapped objects'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_139get_object_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_138get_object_array_elements[] = "Return the contents of a Java object array as a list of wrapped objects";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_139get_object_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_11_javabridge_JB_Object, 1, "array", 0))) __PYX_ERR(0, 1815, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_138get_object_array_elements(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_138get_object_array_elements(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_nobjects;
  int __pyx_v_i;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_sub = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jsize __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("get_object_array_elements", 0);

  /* "_javabridge.pyx":1819
 *         cdef:
 *             jobject o
 *             jsize nobjects = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 *             int i
 *         result = []
 */
  __pyx_v_nobjects = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "_javabridge.pyx":1821
 *             jsize nobjects = self.env[0].GetArrayLength(self.env, array.o)
 *             int i
 *         result = []             # <<<<<<<<<<<<<<
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":1822
 *             int i
 *         result = []
 *         for i in range(nobjects):             # <<<<<<<<<<<<<<
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:
 */
  __pyx_t_2 = __pyx_v_nobjects;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "_javabridge.pyx":1823
 *         result = []
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)             # <<<<<<<<<<<<<<
 *             if o == NULL:
 *                 result.append(None)
 */
    __pyx_v_o = (__pyx_v_self->env[0])->GetObjectArrayElement(__pyx_v_self->env, __pyx_v_array->o, __pyx_v_i);

    /* "_javabridge.pyx":1824
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:             # <<<<<<<<<<<<<<
 *                 result.append(None)
 *             else:
 */
    __pyx_t_4 = ((__pyx_v_o == NULL) != 0);
    if (__pyx_t_4) {

      /* "_javabridge.pyx":1825
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:
 *                 result.append(None)             # <<<<<<<<<<<<<<
 *             else:
 *                 sub, e = make_jb_object(self, o)
 */
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_result, Py_None); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 1825, __pyx_L1_error)

      /* "_javabridge.pyx":1824
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:             # <<<<<<<<<<<<<<
 *                 result.append(None)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "_javabridge.pyx":1827
 *                 result.append(None)
 *             else:
 *                 sub, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *                 if e is not None:
 *                     raise e
 */
    /*else*/ {
      __pyx_t_1 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1827, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) __PYX_ERR(0, 1827, __pyx_L1_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_unpacking_done;
        __pyx_L6_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1827, __pyx_L1_error)
        __pyx_L7_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_sub, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "_javabridge.pyx":1828
 *             else:
 *                 sub, e = make_jb_object(self, o)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *                 result.append(sub)
 */
      __pyx_t_4 = (__pyx_v_e != Py_None);
      __pyx_t_10 = (__pyx_t_4 != 0);
      if (__pyx_t_10) {

        /* "_javabridge.pyx":1829
 *                 sub, e = make_jb_object(self, o)
 *                 if e is not None:
 *                     raise e             # <<<<<<<<<<<<<<
 *                 result.append(sub)
 *         return result
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(0, 1829, __pyx_L1_error)

        /* "_javabridge.pyx":1828
 *             else:
 *                 sub, e = make_jb_object(self, o)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *                 result.append(sub)
 */
      }

      /* "_javabridge.pyx":1830
 *                 if e is not None:
 *                     raise e
 *                 result.append(sub)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_result, __pyx_v_sub); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 1830, __pyx_L1_error)
    }
    __pyx_L5:;
  }

  /* "_javabridge.pyx":1831
 *                     raise e
 *                 result.append(sub)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_boolean_array(self, array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1815
 *         return result
 * 
 *     def get_object_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java object array as a list of wrapped objects'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("_javabridge.JB_Env.get_object_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_sub);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1833
 *         return result
 * 
 *     def make_boolean_array(self, array):             # <<<<<<<<<<<<<<
 *         '''Create a java boolean [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_141make_boolean_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_140make_boolean_array[] = "Create a java boolean [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_141make_boolean_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_boolean_array (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_140make_boolean_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_array));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_140make_boolean_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_array) {
  PyArrayObject *__pyx_v_barray = 0;
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jboolean *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_barray;
  __Pyx_Buffer __pyx_pybuffer_barray;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("make_boolean_array", 0);
  __pyx_pybuffer_barray.pybuffer.buf = NULL;
  __pyx_pybuffer_barray.refcount = 0;
  __pyx_pybuffernd_barray.data = NULL;
  __pyx_pybuffernd_barray.rcbuffer = &__pyx_pybuffer_barray;

  /* "_javabridge.pyx":1836
 *         '''Create a java boolean [] array from the contents of a numpy array'''
 *         cdef:
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] barray = array.astype(np.bool8).astype(np.uint8)             # <<<<<<<<<<<<<<
 *             jobject o
 *             jsize alen = barray.shape[0]
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_array, __pyx_n_s_astype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_bool8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1836, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_astype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_uint8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1836, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_barray.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_barray = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_barray.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1836, __pyx_L1_error)
    } else {__pyx_pybuffernd_barray.diminfo[0].strides = __pyx_pybuffernd_barray.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_barray.diminfo[0].shape = __pyx_pybuffernd_barray.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_barray = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "_javabridge.pyx":1838
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] barray = array.astype(np.bool8).astype(np.uint8)
 *             jobject o
 *             jsize alen = barray.shape[0]             # <<<<<<<<<<<<<<
 *             jboolean *data = <jboolean *>(barray.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_barray->dimensions[0]);

  /* "_javabridge.pyx":1839
 *             jobject o
 *             jsize alen = barray.shape[0]
 *             jboolean *data = <jboolean *>(barray.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 */
  __pyx_v_data = ((jboolean *)__pyx_v_barray->data);

  /* "_javabridge.pyx":1841
 *             jboolean *data = <jboolean *>(barray.data)
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewBooleanArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1842
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_8 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_8) {

    /* "_javabridge.pyx":1843
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_1 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_byte_array_of, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1843, __pyx_L1_error)

    /* "_javabridge.pyx":1842
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1844
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetBooleanArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1845
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1845, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_9(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_5 = __pyx_t_9(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_6), 2) < 0) __PYX_ERR(0, 1845, __pyx_L1_error)
    __pyx_t_9 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1845, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_e = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "_javabridge.pyx":1846
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_8 = (__pyx_v_e != Py_None);
  __pyx_t_10 = (__pyx_t_8 != 0);
  if (__pyx_t_10) {

    /* "_javabridge.pyx":1847
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1847, __pyx_L1_error)

    /* "_javabridge.pyx":1846
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1848
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_byte_array(self, np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1833
 *         return result
 * 
 *     def make_boolean_array(self, array):             # <<<<<<<<<<<<<<
 *         '''Create a java boolean [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_barray.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_boolean_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_barray.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_barray);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1850
 *         return result
 * 
 *     def make_byte_array(self, np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java byte [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_143make_byte_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_142make_byte_array[] = "Create a java byte [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_143make_byte_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_byte_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) __PYX_ERR(0, 1850, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_142make_byte_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_142make_byte_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jbyte *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_byte_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1850, __pyx_L1_error)
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "_javabridge.pyx":1854
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jbyte *data = <jbyte *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "_javabridge.pyx":1855
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jbyte *data = <jbyte *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)
 */
  __pyx_v_data = ((jbyte *)__pyx_v_array->data);

  /* "_javabridge.pyx":1857
 *             jbyte *data = <jbyte *>(array.data)
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewByteArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1858
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1859
 *         o = self.env[0].NewByteArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_byte_array_of, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1859, __pyx_L1_error)

    /* "_javabridge.pyx":1858
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1860
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetByteArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1861
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1861, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1861, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1861, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1862
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1863
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1863, __pyx_L1_error)

    /* "_javabridge.pyx":1862
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1864
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_short_array(self, np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1850
 *         return result
 * 
 *     def make_byte_array(self, np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java byte [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_byte_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1866
 *         return result
 * 
 *     def make_short_array(self, np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java short [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_145make_short_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_144make_short_array[] = "Create a java short [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_145make_short_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_short_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) __PYX_ERR(0, 1866, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_144make_short_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_144make_short_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jshort *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_short_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1866, __pyx_L1_error)
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "_javabridge.pyx":1870
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jshort *data = <jshort *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "_javabridge.pyx":1871
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jshort *data = <jshort *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)
 */
  __pyx_v_data = ((jshort *)__pyx_v_array->data);

  /* "_javabridge.pyx":1873
 *             jshort *data = <jshort *>(array.data)
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewShortArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1874
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1875
 *         o = self.env[0].NewShortArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_short_array_o, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1875, __pyx_L1_error)

    /* "_javabridge.pyx":1874
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1876
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetShortArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1877
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1877, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1877, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1877, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1878
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1879
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1879, __pyx_L1_error)

    /* "_javabridge.pyx":1878
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1880
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_int_array(self, np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1866
 *         return result
 * 
 *     def make_short_array(self, np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java short [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_short_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1882
 *         return result
 * 
 *     def make_int_array(self, np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java int [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_147make_int_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_146make_int_array[] = "Create a java int [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_147make_int_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_int_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) __PYX_ERR(0, 1882, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_146make_int_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_146make_int_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jint *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_int_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1882, __pyx_L1_error)
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "_javabridge.pyx":1886
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jint *data = <jint *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "_javabridge.pyx":1887
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jint *data = <jint *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)
 */
  __pyx_v_data = ((jint *)__pyx_v_array->data);

  /* "_javabridge.pyx":1889
 *             jint *data = <jint *>(array.data)
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewIntArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1890
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1891
 *         o = self.env[0].NewIntArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_int_array_of, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1891, __pyx_L1_error)

    /* "_javabridge.pyx":1890
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1892
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetIntArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1893
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1893, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1893, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1893, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1894
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1895
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1895, __pyx_L1_error)

    /* "_javabridge.pyx":1894
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1896
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_long_array(self, np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1882
 *         return result
 * 
 *     def make_int_array(self, np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java int [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_int_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1898
 *         return result
 * 
 *     def make_long_array(self, np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java long [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_149make_long_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_148make_long_array[] = "Create a java long [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_149make_long_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_long_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) __PYX_ERR(0, 1898, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_148make_long_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_148make_long_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jlong *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_long_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1898, __pyx_L1_error)
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "_javabridge.pyx":1902
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jlong *data = <jlong *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "_javabridge.pyx":1903
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jlong *data = <jlong *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)
 */
  __pyx_v_data = ((jlong *)__pyx_v_array->data);

  /* "_javabridge.pyx":1905
 *             jlong *data = <jlong *>(array.data)
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewLongArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1906
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1907
 *         o = self.env[0].NewLongArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_long_array_of, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1907, __pyx_L1_error)

    /* "_javabridge.pyx":1906
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1908
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetLongArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1909
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1909, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1909, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1909, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1910
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1911
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1911, __pyx_L1_error)

    /* "_javabridge.pyx":1910
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1912
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_float_array(self, np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1898
 *         return result
 * 
 *     def make_long_array(self, np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java long [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_long_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1914
 *         return result
 * 
 *     def make_float_array(self, np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java float [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_151make_float_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_150make_float_array[] = "Create a java float [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_151make_float_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_float_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) __PYX_ERR(0, 1914, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_150make_float_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_150make_float_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jfloat *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_float_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1914, __pyx_L1_error)
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "_javabridge.pyx":1918
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jfloat *data = <jfloat *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "_javabridge.pyx":1919
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jfloat *data = <jfloat *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)
 */
  __pyx_v_data = ((jfloat *)__pyx_v_array->data);

  /* "_javabridge.pyx":1921
 *             jfloat *data = <jfloat *>(array.data)
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewFloatArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1922
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1923
 *         o = self.env[0].NewFloatArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_float_array_o, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1923, __pyx_L1_error)

    /* "_javabridge.pyx":1922
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1924
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetFloatArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1925
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1925, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1925, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1925, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1926
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1927
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1927, __pyx_L1_error)

    /* "_javabridge.pyx":1926
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1928
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_double_array(self, np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1914
 *         return result
 * 
 *     def make_float_array(self, np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java float [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_float_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1930
 *         return result
 * 
 *     def make_double_array(self, np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java double [] array from the contents of a numpy array'''
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_153make_double_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_152make_double_array[] = "Create a java double [] array from the contents of a numpy array";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_153make_double_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_double_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) __PYX_ERR(0, 1930, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_152make_double_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_152make_double_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jdouble *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_double_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1930, __pyx_L1_error)
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "_javabridge.pyx":1934
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jdouble *data = <jdouble *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "_javabridge.pyx":1935
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jdouble *data = <jdouble *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 */
  __pyx_v_data = ((jdouble *)__pyx_v_array->data);

  /* "_javabridge.pyx":1937
 *             jdouble *data = <jdouble *>(array.data)
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewDoubleArray(__pyx_v_self->env, __pyx_v_alen);

  /* "_javabridge.pyx":1938
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1939
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_From_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_double_array, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1939, __pyx_L1_error)

    /* "_javabridge.pyx":1938
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 */
  }

  /* "_javabridge.pyx":1940
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetDoubleArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "_javabridge.pyx":1941
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1941, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1941, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1941, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1942
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1943
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1943, __pyx_L1_error)

    /* "_javabridge.pyx":1942
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1944
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_object_array(self, int len, JB_Class klass):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1930
 *         return result
 * 
 *     def make_double_array(self, np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java double [] array from the contents of a numpy array'''
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("_javabridge.JB_Env.make_double_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1946
 *         return result
 * 
 *     def make_object_array(self, int len, JB_Class klass):             # <<<<<<<<<<<<<<
 *         '''Create a java object [] array filled with all nulls
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_155make_object_array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_154make_object_array[] = "Create a java object [] array filled with all nulls\n        \n        len - # of elements in array\n        klass - class of objects that will be stored\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_155make_object_array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_len;
  struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_klass = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_object_array (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_len,&__pyx_n_s_klass,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_len)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_klass)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("make_object_array", 1, 2, 2, 1); __PYX_ERR(0, 1946, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "make_object_array") < 0)) __PYX_ERR(0, 1946, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_len = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_len == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1946, __pyx_L3_error)
    __pyx_v_klass = ((struct __pyx_obj_11_javabridge_JB_Class *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_object_array", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1946, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.make_object_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_klass), __pyx_ptype_11_javabridge_JB_Class, 1, "klass", 0))) __PYX_ERR(0, 1946, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_154make_object_array(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_len, __pyx_v_klass);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_154make_object_array(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, int __pyx_v_len, struct __pyx_obj_11_javabridge_JB_Class *__pyx_v_klass) {
  jobject __pyx_v_o;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("make_object_array", 0);

  /* "_javabridge.pyx":1954
 *         cdef:
 *             jobject o
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewObjectArray(__pyx_v_self->env, __pyx_v_len, __pyx_v_klass->c, NULL);

  /* "_javabridge.pyx":1955
 *             jobject o
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)
 */
  __pyx_t_1 = ((__pyx_v_o == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1956
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate object array of size %d" % len)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_len); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_allocate_object_array, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1956, __pyx_L1_error)

    /* "_javabridge.pyx":1955
 *             jobject o
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)
 */
  }

  /* "_javabridge.pyx":1957
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1957, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1957, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1957, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_javabridge.pyx":1958
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "_javabridge.pyx":1959
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    __PYX_ERR(0, 1959, __pyx_L1_error)

    /* "_javabridge.pyx":1958
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  }

  /* "_javabridge.pyx":1960
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def set_object_array_element(self, JB_Object jbo, int index, JB_Object v):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "_javabridge.pyx":1946
 *         return result
 * 
 *     def make_object_array(self, int len, JB_Class klass):             # <<<<<<<<<<<<<<
 *         '''Create a java object [] array filled with all nulls
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("_javabridge.JB_Env.make_object_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1962
 *         return result
 * 
 *     def set_object_array_element(self, JB_Object jbo, int index, JB_Object v):             # <<<<<<<<<<<<<<
 *         '''Set an element within an object array
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_157set_object_array_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_156set_object_array_element[] = "Set an element within an object array\n        \n        jbo - the object array\n        index - the zero-based index of the element to set\n        v - the value to be inserted\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_157set_object_array_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo = 0;
  int __pyx_v_index;
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_v = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_object_array_element (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_jbo,&__pyx_n_s_index,&__pyx_n_s_v,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_jbo)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_array_element", 1, 3, 3, 1); __PYX_ERR(0, 1962, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_v)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_array_element", 1, 3, 3, 2); __PYX_ERR(0, 1962, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_object_array_element") < 0)) __PYX_ERR(0, 1962, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_jbo = ((struct __pyx_obj_11_javabridge_JB_Object *)values[0]);
    __pyx_v_index = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1962, __pyx_L3_error)
    __pyx_v_v = ((struct __pyx_obj_11_javabridge_JB_Object *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_object_array_element", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1962, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("_javabridge.JB_Env.set_object_array_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_jbo), __pyx_ptype_11_javabridge_JB_Object, 1, "jbo", 0))) __PYX_ERR(0, 1962, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_v), __pyx_ptype_11_javabridge_JB_Object, 1, "v", 0))) __PYX_ERR(0, 1962, __pyx_L1_error)
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_156set_object_array_element(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_jbo, __pyx_v_index, __pyx_v_v);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_156set_object_array_element(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo, int __pyx_v_index, struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_v) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_object_array_element", 0);

  /* "_javabridge.pyx":1969
 *         v - the value to be inserted
 *         '''
 *         if v is None:             # <<<<<<<<<<<<<<
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, NULL)
 *         else:
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_v) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "_javabridge.pyx":1970
 *         '''
 *         if v is None:
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, NULL)             # <<<<<<<<<<<<<<
 *         else:
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, v.o)
 */
    (__pyx_v_self->env[0])->SetObjectArrayElement(__pyx_v_self->env, __pyx_v_jbo->o, __pyx_v_index, NULL);

    /* "_javabridge.pyx":1969
 *         v - the value to be inserted
 *         '''
 *         if v is None:             # <<<<<<<<<<<<<<
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, NULL)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "_javabridge.pyx":1972
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, NULL)
 *         else:
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, v.o)             # <<<<<<<<<<<<<<
 * 
 *     def make_jb_object(self, pCapsule):
 */
  /*else*/ {
    (__pyx_v_self->env[0])->SetObjectArrayElement(__pyx_v_self->env, __pyx_v_jbo->o, __pyx_v_index, __pyx_v_v->o);
  }
  __pyx_L3:;

  /* "_javabridge.pyx":1962
 *         return result
 * 
 *     def set_object_array_element(self, JB_Object jbo, int index, JB_Object v):             # <<<<<<<<<<<<<<
 *         '''Set an element within an object array
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1974
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, v.o)
 * 
 *     def make_jb_object(self, pCapsule):             # <<<<<<<<<<<<<<
 *         '''Wrap a java object in a javabridge object
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11_javabridge_6JB_Env_159make_jb_object(PyObject *__pyx_v_self, PyObject *__pyx_v_pCapsule); /*proto*/
static char __pyx_doc_11_javabridge_6JB_Env_158make_jb_object[] = "Wrap a java object in a javabridge object\n        \n        address - integer representation of the memory address, as a string\n        ";
static PyObject *__pyx_pw_11_javabridge_6JB_Env_159make_jb_object(PyObject *__pyx_v_self, PyObject *__pyx_v_pCapsule) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_jb_object (wrapper)", 0);
  __pyx_r = __pyx_pf_11_javabridge_6JB_Env_158make_jb_object(((struct __pyx_obj_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_pCapsule));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11_javabridge_6JB_Env_158make_jb_object(CYTHON_UNUSED struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_pCapsule) {
  jobject __pyx_v_jobj;
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("make_jb_object", 0);

  /* "_javabridge.pyx":1982
 *             jobject jobj
 *             JB_Object jbo
 *         if not PyCapsule_CheckExact(pCapsule):             # <<<<<<<<<<<<<<
 *             raise ValueError("Argument must be a jobject in a capsule")
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 */
  __pyx_t_1 = ((!(PyCapsule_CheckExact(__pyx_v_pCapsule) != 0)) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1983
 *             JB_Object jbo
 *         if not PyCapsule_CheckExact(pCapsule):
 *             raise ValueError("Argument must be a jobject in a capsule")             # <<<<<<<<<<<<<<
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 *         if not jobj:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1983, __pyx_L1_error)

    /* "_javabridge.pyx":1982
 *             jobject jobj
 *             JB_Object jbo
 *         if not PyCapsule_CheckExact(pCapsule):             # <<<<<<<<<<<<<<
 *             raise ValueError("Argument must be a jobject in a capsule")
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 */
  }

  /* "_javabridge.pyx":1984
 *         if not PyCapsule_CheckExact(pCapsule):
 *             raise ValueError("Argument must be a jobject in a capsule")
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)             # <<<<<<<<<<<<<<
 *         if not jobj:
 *             raise ValueError("Capsule did not contain a jobject")
 */
  __pyx_v_jobj = ((jobject)PyCapsule_GetPointer(__pyx_v_pCapsule, NULL));

  /* "_javabridge.pyx":1985
 *             raise ValueError("Argument must be a jobject in a capsule")
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 *         if not jobj:             # <<<<<<<<<<<<<<
 *             raise ValueError("Capsule did not contain a jobject")
 *         jbo = JB_Object()
 */
  __pyx_t_1 = ((!(__pyx_v_jobj != 0)) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":1986
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 *         if not jobj:
 *             raise ValueError("Capsule did not contain a jobject")             # <<<<<<<<<<<<<<
 *         jbo = JB_Object()
 *         jbo.o = jobj
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1986, __pyx_L1_error)

    /* "_javabridge.pyx":1985
 *             raise ValueError("Argument must be a jobject in a capsule")
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 *         if not jobj:             # <<<<<<<<<<<<<<
 *             raise ValueError("Capsule did not contain a jobject")
 *         jbo = JB_Object()
 */
  }

  /* "_javabridge.pyx":1987
 *         if not jobj:
 *             raise ValueError("Capsule did not contain a jobject")
 *         jbo = JB_Object()             # <<<<<<<<<<<<<<
 *         jbo.o = jobj
 *         jbo.gc_collect = False
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Object), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_jbo = ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "_javabridge.pyx":1988
 *             raise ValueError("Capsule did not contain a jobject")
 *         jbo = JB_Object()
 *         jbo.o = jobj             # <<<<<<<<<<<<<<
 *         jbo.gc_collect = False
 *         return jbo
 */
  __pyx_v_jbo->o = __pyx_v_jobj;

  /* "_javabridge.pyx":1989
 *         jbo = JB_Object()
 *         jbo.o = jobj
 *         jbo.gc_collect = False             # <<<<<<<<<<<<<<
 *         return jbo
 * 
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_jbo->gc_collect);
  __Pyx_DECREF(__pyx_v_jbo->gc_collect);
  __pyx_v_jbo->gc_collect = Py_False;

  /* "_javabridge.pyx":1990
 *         jbo.o = jobj
 *         jbo.gc_collect = False
 *         return jbo             # <<<<<<<<<<<<<<
 * 
 * cdef make_jb_object(JB_Env env, jobject o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbo));
  __pyx_r = ((PyObject *)__pyx_v_jbo);
  goto __pyx_L0;

  /* "_javabridge.pyx":1974
 *             self.env[0].SetObjectArrayElement(self.env, jbo.o, index, v.o)
 * 
 *     def make_jb_object(self, pCapsule):             # <<<<<<<<<<<<<<
 *         '''Wrap a java object in a javabridge object
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_javabridge.JB_Env.make_jb_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_javabridge.pyx":1992
 *         return jbo
 * 
 * cdef make_jb_object(JB_Env env, jobject o):             # <<<<<<<<<<<<<<
 *     '''Wrap a Java object in a JB_Object with appropriate reference handling
 * 
 */

static PyObject *__pyx_f_11_javabridge_make_jb_object(struct __pyx_obj_11_javabridge_JB_Env *__pyx_v_env, jobject __pyx_v_o) {
  jobject __pyx_v_oref;
  struct __pyx_obj_11_javabridge_JB_Object *__pyx_v_jbo = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("make_jb_object", 0);

  /* "_javabridge.pyx":2003
 *         JB_Object jbo
 * 
 *     oref = env.env[0].NewGlobalRef(env.env, o)             # <<<<<<<<<<<<<<
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))
 */
  __pyx_v_oref = (__pyx_v_env->env[0])->NewGlobalRef(__pyx_v_env->env, __pyx_v_o);

  /* "_javabridge.pyx":2004
 * 
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:             # <<<<<<<<<<<<<<
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)
 */
  __pyx_t_1 = ((__pyx_v_oref == NULL) != 0);
  if (__pyx_t_1) {

    /* "_javabridge.pyx":2005
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))             # <<<<<<<<<<<<<<
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_3, 0, Py_None);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "_javabridge.pyx":2004
 * 
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:             # <<<<<<<<<<<<<<
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)
 */
  }

  /* "_javabridge.pyx":2006
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)             # <<<<<<<<<<<<<<
 *     jbo = JB_Object()
 *     jbo.o = oref
 */
  (__pyx_v_env->env[0])->DeleteLocalRef(__pyx_v_env->env, __pyx_v_o);

  /* "_javabridge.pyx":2007
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()             # <<<<<<<<<<<<<<
 *     jbo.o = oref
 *     jbo.gc_collect = True
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11_javabridge_JB_Object), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_jbo = ((struct __pyx_obj_11_javabridge_JB_Object *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_javabridge.pyx":2008
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()
 *     jbo.o = oref             # <<<<<<<<<<<<<<
 *     jbo.gc_collect = True
 *     return (jbo, None)
 */
  __pyx_v_jbo->o = __pyx_v_oref;

  /* "_javabridge.pyx":2009
 *     jbo = JB_Object()
 *     jbo.o = oref
 *     jbo.gc_collect = True             # <<<<<<<<<<<<<<
 *     return (jbo, None)
 */
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  __Pyx_GOTREF(__pyx_v_jbo->gc_collect);
  __Pyx_DECREF(__pyx_v_jbo->gc_collect);
  __pyx_v_jbo->gc_collect = Py_True;

  /* "_javabridge.pyx":2010
 *     jbo.o = oref
 *     jbo.gc_collect = True
 *     return (jbo, None)             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbo));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_jbo));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_jbo));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_3, 1, Py_None);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "_javabridge.pyx":1992
 *         return jbo
 * 
 * cdef make_jb_object(JB_Env env, jobject o):             # <<<<<<<<<<<<<<
 *     '''Wrap a Java object in a JB_Object with appropriate reference handling
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_javabridge.make_jb_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":197
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_copy_shape;
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_v_hasfields;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":203
 *             # of flags
 * 
 *             if info == NULL: return             # <<<<<<<<<<<<<<
 * 
 *             cdef int copy_shape, i, ndim
 */
  __pyx_t_1 = ((__pyx_v_info == NULL) != 0);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":206
 * 
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":207
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":209
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":211
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":212
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 copy_shape = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 copy_shape = 0
 */
    __pyx_v_copy_shape = 1;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":211
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
    goto __pyx_L4;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":214
 *                 copy_shape = 1
 *             else:
 *                 copy_shape = 0             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
  /*else*/ {
    __pyx_v_copy_shape = 0;
  }
  __pyx_L4:;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":216
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":217
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_C_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":216
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":218
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 218, __pyx_L1_error)

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":216
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L9_bool_binop_done;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":221
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_F_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L9_bool_binop_done:;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":222
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 222, __pyx_L1_error)

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":224
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if copy_shape:
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":225
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if copy_shape:
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":226
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  __pyx_t_1 = (__pyx_v_copy_shape != 0);
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":229
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)malloc((((sizeof(Py_ssize_t)) * ((size_t)__pyx_v_ndim)) * 2)));

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":230
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":231
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_4 = __pyx_v_ndim;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":232
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":233
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":226
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
    goto __pyx_L11;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":235
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
  /*else*/ {
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":236
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L11:;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":237
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":238
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":239
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!(PyArray_ISWRITEABLE(__pyx_v_self) != 0));

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":242
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = self.descr
 *             cdef int offset
 */
  __pyx_v_f = NULL;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":243
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = self.descr             # <<<<<<<<<<<<<<
 *             cdef int offset
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->descr);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_descr = ((PyArray_Descr *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":246
 *             cdef int offset
 * 
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields and not copy_shape:
 */
  __pyx_v_hasfields = PyDataType_HASFIELDS(__pyx_v_descr);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":248
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
  __pyx_t_2 = ((!(__pyx_v_hasfields != 0)) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_2 = ((!(__pyx_v_copy_shape != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":250
 *             if not hasfields and not copy_shape:
 *                 # do not call releasebuffer
 *                 info.obj = None             # <<<<<<<<<<<<<<
 *             else:
 *                 # need to call releasebuffer
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = Py_None;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":248
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
    goto __pyx_L14;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":253
 *             else:
 *                 # need to call releasebuffer
 *                 info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields:
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = ((PyObject *)__pyx_v_self);
  }
  __pyx_L14:;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":255
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  __pyx_t_1 = ((!(__pyx_v_hasfields != 0)) != 0);
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":256
 * 
 *             if not hasfields:
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 */
    __pyx_t_4 = __pyx_v_descr->type_num;
    __pyx_v_t = __pyx_t_4;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":257
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '>') != 0);
    if (!__pyx_t_2) {
      goto __pyx_L20_next_or;
    } else {
    }
    __pyx_t_2 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_L20_next_or:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":258
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '<') != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_2 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L19_bool_binop_done:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":257
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    if (__pyx_t_1) {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":259
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(1, 259, __pyx_L1_error)

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":257
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":260
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    switch (__pyx_v_t) {
      case NPY_BYTE:
      __pyx_v_f = ((char *)"b");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":261
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
      case NPY_UBYTE:
      __pyx_v_f = ((char *)"B");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":262
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
      case NPY_SHORT:
      __pyx_v_f = ((char *)"h");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":263
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
      case NPY_USHORT:
      __pyx_v_f = ((char *)"H");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":264
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
      case NPY_INT:
      __pyx_v_f = ((char *)"i");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":265
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
      case NPY_UINT:
      __pyx_v_f = ((char *)"I");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":266
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
      case NPY_LONG:
      __pyx_v_f = ((char *)"l");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":267
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
      case NPY_ULONG:
      __pyx_v_f = ((char *)"L");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":268
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
      case NPY_LONGLONG:
      __pyx_v_f = ((char *)"q");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":269
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
      case NPY_ULONGLONG:
      __pyx_v_f = ((char *)"Q");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":270
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
      case NPY_FLOAT:
      __pyx_v_f = ((char *)"f");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":271
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
      case NPY_DOUBLE:
      __pyx_v_f = ((char *)"d");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":272
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
      case NPY_LONGDOUBLE:
      __pyx_v_f = ((char *)"g");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":273
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
      case NPY_CFLOAT:
      __pyx_v_f = ((char *)"Zf");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
      case NPY_CDOUBLE:
      __pyx_v_f = ((char *)"Zd");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":275
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
      case NPY_CLONGDOUBLE:
      __pyx_v_f = ((char *)"Zg");
      break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":276
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      case NPY_OBJECT:
      __pyx_v_f = ((char *)"O");
      break;
      default:

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":278
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(1, 278, __pyx_L1_error)
      break;
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":279
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":280
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":255
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":282
 *                 return
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 */
  /*else*/ {
    __pyx_v_info->format = ((char *)malloc(0xFF));

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":283
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":284
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":285
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,             # <<<<<<<<<<<<<<
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 */
    __pyx_t_7 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 0xFF), (&__pyx_v_offset)); if (unlikely(__pyx_t_7 == NULL)) __PYX_ERR(1, 285, __pyx_L1_error)
    __pyx_v_f = __pyx_t_7;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":288
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = c'\0' # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = '\x00';
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":197
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info != NULL && __pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = NULL;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":290
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":291
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = (PyArray_HASFIELDS(__pyx_v_self) != 0);
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":292
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)
 */
    free(__pyx_v_info->format);

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":291
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":293
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":294
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    free(__pyx_v_info->strides);

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":293
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":290
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":770
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":771
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":770
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":773
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":774
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":773
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":776
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":777
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":776
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":779
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":780
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":779
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":782
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":783
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":782
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":785
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  long __pyx_t_8;
  char *__pyx_t_9;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":790
 * 
 *     cdef dtype child
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":791
 *     cdef dtype child
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":794
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(__pyx_v_descr->names == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(1, 794, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_descr->names; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 794, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_childname, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":795
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    if (unlikely(__pyx_v_descr->fields == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 795, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(1, 795, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_fields, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":796
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 */
    if (likely(__pyx_v_fields != Py_None)) {
      PyObject* sequence = __pyx_v_fields;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(1, 796, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(1, 796, __pyx_L1_error)
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(1, 796, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_child, ((PyArray_Descr *)__pyx_t_3));
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_new_offset, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":798
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 798, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = ((((__pyx_v_end - __pyx_v_f) - ((int)__pyx_t_5)) < 15) != 0);
    if (__pyx_t_6) {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":799
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 799, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(1, 799, __pyx_L1_error)

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":798
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '>') != 0);
    if (!__pyx_t_7) {
      goto __pyx_L8_next_or;
    } else {
    }
    __pyx_t_7 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L8_next_or:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":802
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '<') != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L7_bool_binop_done:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    if (__pyx_t_6) {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(1, 803, __pyx_L1_error)

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":813
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_v_new_offset, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 813, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 813, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_6) break;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":814
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 0x78;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":815
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":816
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_8 = 0;
      (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + 1);
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":818
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_8 = 0;
    (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + __pyx_v_child->elsize);

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":820
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_6 = ((!(PyDataType_HASFIELDS(__pyx_v_child) != 0)) != 0);
    if (__pyx_t_6) {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":821
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_child->type_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 821, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":822
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_6 = (((__pyx_v_end - __pyx_v_f) < 5) != 0);
      if (__pyx_t_6) {

        /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 823, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(1, 823, __pyx_L1_error)

        /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":822
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":826
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_BYTE); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 826, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 826, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 826, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":827
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UBYTE); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 827, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 827, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":828
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_SHORT); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 828, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 828, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x68;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":829
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_USHORT); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 829, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 829, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 829, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":830
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_INT); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 830, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 830, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 830, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x69;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":831
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UINT); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 831, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 831, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":832
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONG); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 832, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 832, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 832, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x6C;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":833
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONG); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 833, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 833, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":834
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGLONG); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 834, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 834, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 834, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x71;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":835
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONGLONG); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 835, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 835, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":836
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_FLOAT); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 836, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 836, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x66;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":837
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_DOUBLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 837, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 837, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x64;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":838
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 838, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 838, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x67;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":839
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CFLOAT); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 839, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 839, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 839, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x66;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":840
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CDOUBLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 840, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 840, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x64;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":841
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 841, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 841, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x67;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":842
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_OBJECT); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 842, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(1, 842, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L15;
      }

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":844
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
      /*else*/ {
        __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(1, 844, __pyx_L1_error)
      }
      __pyx_L15:;

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":845
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":820
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
      goto __pyx_L13;
    }

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":849
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
    /*else*/ {
      __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_9 == NULL)) __PYX_ERR(1, 849, __pyx_L1_error)
      __pyx_v_f = __pyx_t_9;
    }
    __pyx_L13:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":794
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":850
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":785
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_baseptr;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":968
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
  __pyx_t_1 = (__pyx_v_base == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":969
 *      cdef PyObject* baseptr
 *      if base is None:
 *          baseptr = NULL             # <<<<<<<<<<<<<<
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 */
    __pyx_v_baseptr = NULL;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":968
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
    goto __pyx_L3;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":971
 *          baseptr = NULL
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!             # <<<<<<<<<<<<<<
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 */
  /*else*/ {
    Py_INCREF(__pyx_v_base);

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":972
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base             # <<<<<<<<<<<<<<
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr
 */
    __pyx_v_baseptr = ((PyObject *)__pyx_v_base);
  }
  __pyx_L3:;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":973
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)             # <<<<<<<<<<<<<<
 *      arr.base = baseptr
 * 
 */
  Py_XDECREF(__pyx_v_arr->base);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":974
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_v_arr->base = __pyx_v_baseptr;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":976
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":977
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_arr->base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":978
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>arr.base
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":977
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":980
 *         return None
 *     else:
 *         return <object>arr.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_arr->base));
    __pyx_r = ((PyObject *)__pyx_v_arr->base);
    goto __pyx_L0;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":976
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":985
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":986
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":987
 * cdef inline int import_array() except -1:
 *     try:
 *         _import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(1, 987, __pyx_L3_error)

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":986
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":988
 *     try:
 *         _import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 988, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":989
 *         _import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 989, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 989, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":986
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L10_try_end:;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":985
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":991
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":992
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":993
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(1, 993, __pyx_L3_error)

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":992
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":994
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 994, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":995
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 995, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 995, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":992
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L10_try_end:;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":991
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":997
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":998
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":999
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(1, 999, __pyx_L3_error)

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":998
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":1000
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 1000, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":1001
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1001, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 1001, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":998
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L10_try_end:;
  }

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":997
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_11_javabridge_JB_Object(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11_javabridge_JB_Object *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11_javabridge_JB_Object *)o);
  p->gc_collect = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11_javabridge_9JB_Object_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11_javabridge_JB_Object(PyObject *o) {
  struct __pyx_obj_11_javabridge_JB_Object *p = (struct __pyx_obj_11_javabridge_JB_Object *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_11_javabridge_9JB_Object_5__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->gc_collect);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11_javabridge_JB_Object(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11_javabridge_JB_Object *p = (struct __pyx_obj_11_javabridge_JB_Object *)o;
  if (p->gc_collect) {
    e = (*v)(p->gc_collect, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11_javabridge_JB_Object(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11_javabridge_JB_Object *p = (struct __pyx_obj_11_javabridge_JB_Object *)o;
  tmp = ((PyObject*)p->gc_collect);
  p->gc_collect = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11_javabridge_JB_Object[] = {
  {"addr", (PyCFunction)__pyx_pw_11_javabridge_9JB_Object_7addr, METH_NOARGS, __pyx_doc_11_javabridge_9JB_Object_6addr},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11_javabridge_JB_Object = {
  PyVarObject_HEAD_INIT(0, 0)
  "_javabridge.JB_Object", /*tp_name*/
  sizeof(struct __pyx_obj_11_javabridge_JB_Object), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11_javabridge_JB_Object, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11_javabridge_9JB_Object_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Represents a Java object.", /*tp_doc*/
  __pyx_tp_traverse_11_javabridge_JB_Object, /*tp_traverse*/
  __pyx_tp_clear_11_javabridge_JB_Object, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11_javabridge_JB_Object, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11_javabridge_JB_Object, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_11_javabridge_JB_Class(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  if (unlikely(__pyx_pw_11_javabridge_8JB_Class_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11_javabridge_JB_Class(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_11_javabridge_JB_Class[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11_javabridge_JB_Class = {
  PyVarObject_HEAD_INIT(0, 0)
  "_javabridge.JB_Class", /*tp_name*/
  sizeof(struct __pyx_obj_11_javabridge_JB_Class), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11_javabridge_JB_Class, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11_javabridge_8JB_Class_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "A Java class", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11_javabridge_JB_Class, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11_javabridge_JB_Class, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_11_javabridge___JB_MethodID(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11_javabridge___JB_MethodID *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11_javabridge___JB_MethodID *)o);
  p->sig = Py_None; Py_INCREF(Py_None);
  p->is_static = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11_javabridge_13__JB_MethodID_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11_javabridge___JB_MethodID(PyObject *o) {
  struct __pyx_obj_11_javabridge___JB_MethodID *p = (struct __pyx_obj_11_javabridge___JB_MethodID *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->sig);
  Py_CLEAR(p->is_static);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11_javabridge___JB_MethodID(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11_javabridge___JB_MethodID *p = (struct __pyx_obj_11_javabridge___JB_MethodID *)o;
  if (p->sig) {
    e = (*v)(p->sig, a); if (e) return e;
  }
  if (p->is_static) {
    e = (*v)(p->is_static, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11_javabridge___JB_MethodID(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11_javabridge___JB_MethodID *p = (struct __pyx_obj_11_javabridge___JB_MethodID *)o;
  tmp = ((PyObject*)p->sig);
  p->sig = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->is_static);
  p->is_static = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11_javabridge___JB_MethodID[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11_javabridge___JB_MethodID = {
  PyVarObject_HEAD_INIT(0, 0)
  "_javabridge.__JB_MethodID", /*tp_name*/
  sizeof(struct __pyx_obj_11_javabridge___JB_MethodID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11_javabridge___JB_MethodID, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11_javabridge_13__JB_MethodID_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "A method ID as returned by get_method_id", /*tp_doc*/
  __pyx_tp_traverse_11_javabridge___JB_MethodID, /*tp_traverse*/
  __pyx_tp_clear_11_javabridge___JB_MethodID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11_javabridge___JB_MethodID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11_javabridge___JB_MethodID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_11_javabridge___JB_FieldID(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11_javabridge___JB_FieldID *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11_javabridge___JB_FieldID *)o);
  p->sig = Py_None; Py_INCREF(Py_None);
  p->is_static = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11_javabridge_12__JB_FieldID_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11_javabridge___JB_FieldID(PyObject *o) {
  struct __pyx_obj_11_javabridge___JB_FieldID *p = (struct __pyx_obj_11_javabridge___JB_FieldID *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->sig);
  Py_CLEAR(p->is_static);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11_javabridge___JB_FieldID(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11_javabridge___JB_FieldID *p = (struct __pyx_obj_11_javabridge___JB_FieldID *)o;
  if (p->sig) {
    e = (*v)(p->sig, a); if (e) return e;
  }
  if (p->is_static) {
    e = (*v)(p->is_static, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11_javabridge___JB_FieldID(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11_javabridge___JB_FieldID *p = (struct __pyx_obj_11_javabridge___JB_FieldID *)o;
  tmp = ((PyObject*)p->sig);
  p->sig = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->is_static);
  p->is_static = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11_javabridge___JB_FieldID[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11_javabridge___JB_FieldID = {
  PyVarObject_HEAD_INIT(0, 0)
  "_javabridge.__JB_FieldID", /*tp_name*/
  sizeof(struct __pyx_obj_11_javabridge___JB_FieldID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11_javabridge___JB_FieldID, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11_javabridge_12__JB_FieldID_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "A field ID as returned by get_field_id", /*tp_doc*/
  __pyx_tp_traverse_11_javabridge___JB_FieldID, /*tp_traverse*/
  __pyx_tp_clear_11_javabridge___JB_FieldID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11_javabridge___JB_FieldID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11_javabridge___JB_FieldID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_11_javabridge_JB_VM(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_11_javabridge_JB_VM(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_11_javabridge_JB_VM[] = {
  {"set_vm", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_1set_vm, METH_O, __pyx_doc_11_javabridge_5JB_VM_set_vm},
  {"is_active", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_3is_active, METH_NOARGS, __pyx_doc_11_javabridge_5JB_VM_2is_active},
  {"create", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_5create, METH_O, __pyx_doc_11_javabridge_5JB_VM_4create},
  {"create_mac", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_7create_mac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_5JB_VM_6create_mac},
  {"attach", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_9attach, METH_NOARGS, __pyx_doc_11_javabridge_5JB_VM_8attach},
  {"attach_as_daemon", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_11attach_as_daemon, METH_NOARGS, __pyx_doc_11_javabridge_5JB_VM_10attach_as_daemon},
  {"detach", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_13detach, METH_NOARGS, __pyx_doc_11_javabridge_5JB_VM_12detach},
  {"destroy", (PyCFunction)__pyx_pw_11_javabridge_5JB_VM_15destroy, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11_javabridge_JB_VM = {
  PyVarObject_HEAD_INIT(0, 0)
  "_javabridge.JB_VM", /*tp_name*/
  sizeof(struct __pyx_obj_11_javabridge_JB_VM), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11_javabridge_JB_VM, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "Represents the Java virtual machine", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11_javabridge_JB_VM, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11_javabridge_JB_VM, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_11_javabridge_JB_Env(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_11_javabridge_JB_Env(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_11_javabridge_6JB_Env_7__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_11_javabridge_JB_Env[] = {
  {"set_env", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_5set_env, METH_O, __pyx_doc_11_javabridge_6JB_Env_4set_env},
  {"dealloc_jobject", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_9dealloc_jobject, METH_O, __pyx_doc_11_javabridge_6JB_Env_8dealloc_jobject},
  {"get_version", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_11get_version, METH_NOARGS, __pyx_doc_11_javabridge_6JB_Env_10get_version},
  {"find_class", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_13find_class, METH_O, __pyx_doc_11_javabridge_6JB_Env_12find_class},
  {"get_object_class", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_15get_object_class, METH_O, __pyx_doc_11_javabridge_6JB_Env_14get_object_class},
  {"is_instance_of", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_17is_instance_of, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_16is_instance_of},
  {"exception_occurred", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_19exception_occurred, METH_NOARGS, __pyx_doc_11_javabridge_6JB_Env_18exception_occurred},
  {"exception_describe", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_21exception_describe, METH_NOARGS, __pyx_doc_11_javabridge_6JB_Env_20exception_describe},
  {"exception_clear", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_23exception_clear, METH_NOARGS, __pyx_doc_11_javabridge_6JB_Env_22exception_clear},
  {"get_method_id", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_25get_method_id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_24get_method_id},
  {"get_static_method_id", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_27get_static_method_id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_26get_static_method_id},
  {"from_reflected_method", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_29from_reflected_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_28from_reflected_method},
  {"call_method", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_31call_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_30call_method},
  {"call_static_method", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_33call_static_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_32call_static_method},
  {"get_field_id", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_35get_field_id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_34get_field_id},
  {"get_object_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_37get_object_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_36get_object_field},
  {"get_boolean_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_39get_boolean_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_38get_boolean_field},
  {"get_byte_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_41get_byte_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_40get_byte_field},
  {"get_char_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_43get_char_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_42get_char_field},
  {"get_short_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_45get_short_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_44get_short_field},
  {"get_int_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_47get_int_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_46get_int_field},
  {"get_long_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_49get_long_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_48get_long_field},
  {"get_float_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_51get_float_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_50get_float_field},
  {"get_double_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_53get_double_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_52get_double_field},
  {"set_object_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_55set_object_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_54set_object_field},
  {"set_boolean_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_57set_boolean_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_56set_boolean_field},
  {"set_byte_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_59set_byte_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_58set_byte_field},
  {"set_char_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_61set_char_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_60set_char_field},
  {"set_short_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_63set_short_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_62set_short_field},
  {"set_int_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_65set_int_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_64set_int_field},
  {"set_long_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_67set_long_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_66set_long_field},
  {"set_float_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_69set_float_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_68set_float_field},
  {"set_double_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_71set_double_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_70set_double_field},
  {"get_static_field_id", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_73get_static_field_id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_72get_static_field_id},
  {"get_static_object_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_75get_static_object_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_74get_static_object_field},
  {"get_static_boolean_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_77get_static_boolean_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_76get_static_boolean_field},
  {"get_static_char_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_79get_static_char_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_78get_static_char_field},
  {"get_static_byte_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_81get_static_byte_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_80get_static_byte_field},
  {"get_static_short_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_83get_static_short_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_82get_static_short_field},
  {"get_static_int_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_85get_static_int_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_84get_static_int_field},
  {"get_static_long_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_87get_static_long_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_86get_static_long_field},
  {"get_static_float_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_89get_static_float_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_88get_static_float_field},
  {"get_static_double_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_91get_static_double_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_90get_static_double_field},
  {"set_static_object_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_93set_static_object_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_92set_static_object_field},
  {"set_static_boolean_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_95set_static_boolean_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_94set_static_boolean_field},
  {"set_static_char_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_97set_static_char_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_96set_static_char_field},
  {"set_static_byte_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_99set_static_byte_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_98set_static_byte_field},
  {"set_static_char_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_101set_static_char_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_100set_static_char_field},
  {"set_static_short_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_103set_static_short_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_102set_static_short_field},
  {"set_static_int_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_105set_static_int_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_104set_static_int_field},
  {"set_static_long_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_107set_static_long_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_106set_static_long_field},
  {"set_static_float_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_109set_static_float_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_108set_static_float_field},
  {"set_static_double_field", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_111set_static_double_field, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_110set_static_double_field},
  {"new_object", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_113new_object, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_112new_object},
  {"new_string", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_115new_string, METH_O, __pyx_doc_11_javabridge_6JB_Env_114new_string},
  {"new_string_utf", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_117new_string_utf, METH_O, __pyx_doc_11_javabridge_6JB_Env_116new_string_utf},
  {"get_string", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_119get_string, METH_O, __pyx_doc_11_javabridge_6JB_Env_118get_string},
  {"get_string_utf", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_121get_string_utf, METH_O, __pyx_doc_11_javabridge_6JB_Env_120get_string_utf},
  {"get_array_length", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_123get_array_length, METH_O, __pyx_doc_11_javabridge_6JB_Env_122get_array_length},
  {"get_boolean_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_125get_boolean_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_124get_boolean_array_elements},
  {"get_byte_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_127get_byte_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_126get_byte_array_elements},
  {"get_short_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_129get_short_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_128get_short_array_elements},
  {"get_int_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_131get_int_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_130get_int_array_elements},
  {"get_long_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_133get_long_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_132get_long_array_elements},
  {"get_float_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_135get_float_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_134get_float_array_elements},
  {"get_double_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_137get_double_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_136get_double_array_elements},
  {"get_object_array_elements", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_139get_object_array_elements, METH_O, __pyx_doc_11_javabridge_6JB_Env_138get_object_array_elements},
  {"make_boolean_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_141make_boolean_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_140make_boolean_array},
  {"make_byte_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_143make_byte_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_142make_byte_array},
  {"make_short_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_145make_short_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_144make_short_array},
  {"make_int_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_147make_int_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_146make_int_array},
  {"make_long_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_149make_long_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_148make_long_array},
  {"make_float_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_151make_float_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_150make_float_array},
  {"make_double_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_153make_double_array, METH_O, __pyx_doc_11_javabridge_6JB_Env_152make_double_array},
  {"make_object_array", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_155make_object_array, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_154make_object_array},
  {"set_object_array_element", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_157set_object_array_element, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11_javabridge_6JB_Env_156set_object_array_element},
  {"make_jb_object", (PyCFunction)__pyx_pw_11_javabridge_6JB_Env_159make_jb_object, METH_O, __pyx_doc_11_javabridge_6JB_Env_158make_jb_object},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11_javabridge_JB_Env = {
  PyVarObject_HEAD_INIT(0, 0)
  "_javabridge.JB_Env", /*tp_name*/
  sizeof(struct __pyx_obj_11_javabridge_JB_Env), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11_javabridge_JB_Env, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11_javabridge_6JB_Env_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "\n    Represents the Java VM and the Java execution environment as\n    returned by JNI_CreateJavaVM.\n\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11_javabridge_JB_Env, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11_javabridge_6JB_Env_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11_javabridge_JB_Env, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "_javabridge",
    __pyx_k_javabridge_pyx_low_level_interf, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_Argument_must_be_a_jobject_in_a, __pyx_k_Argument_must_be_a_jobject_in_a, sizeof(__pyx_k_Argument_must_be_a_jobject_in_a), 0, 0, 1, 0},
  {&__pyx_n_s_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 0, 1, 1},
  {&__pyx_kp_s_Bad_function_signature_s, __pyx_k_Bad_function_signature_s, sizeof(__pyx_k_Bad_function_signature_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Bad_signature_s, __pyx_k_Bad_signature_s, sizeof(__pyx_k_Bad_signature_s), 0, 0, 1, 0},
  {&__pyx_n_s_C, __pyx_k_C, sizeof(__pyx_k_C), 0, 0, 1, 1},
  {&__pyx_kp_s_Capsule_did_not_contain_a_jobjec, __pyx_k_Capsule_did_not_contain_a_jobjec, sizeof(__pyx_k_Capsule_did_not_contain_a_jobjec), 0, 0, 1, 0},
  {&__pyx_kp_s_Class_None_on_call_to_get_method, __pyx_k_Class_None_on_call_to_get_method, sizeof(__pyx_k_Class_None_on_call_to_get_method), 0, 0, 1, 0},
  {&__pyx_n_s_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 0, 1, 1},
  {&__pyx_n_s_Event, __pyx_k_Event, sizeof(__pyx_k_Event), 0, 0, 1, 1},
  {&__pyx_n_s_F, __pyx_k_F, sizeof(__pyx_k_F), 0, 0, 1, 1},
  {&__pyx_kp_s_Failed_to_allocate_JavaVMInitArg, __pyx_k_Failed_to_allocate_JavaVMInitArg, sizeof(__pyx_k_Failed_to_allocate_JavaVMInitArg), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_byte_array_of, __pyx_k_Failed_to_allocate_byte_array_of, sizeof(__pyx_k_Failed_to_allocate_byte_array_of), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_double_array, __pyx_k_Failed_to_allocate_double_array, sizeof(__pyx_k_Failed_to_allocate_double_array), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_float_array_o, __pyx_k_Failed_to_allocate_float_array_o, sizeof(__pyx_k_Failed_to_allocate_float_array_o), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_int_array_of, __pyx_k_Failed_to_allocate_int_array_of, sizeof(__pyx_k_Failed_to_allocate_int_array_of), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_long_array_of, __pyx_k_Failed_to_allocate_long_array_of, sizeof(__pyx_k_Failed_to_allocate_long_array_of), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_object_array, __pyx_k_Failed_to_allocate_object_array, sizeof(__pyx_k_Failed_to_allocate_object_array), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_short_array_o, __pyx_k_Failed_to_allocate_short_array_o, sizeof(__pyx_k_Failed_to_allocate_short_array_o), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_allocate_string, __pyx_k_Failed_to_allocate_string, sizeof(__pyx_k_Failed_to_allocate_string), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_attach_to_current_thre, __pyx_k_Failed_to_attach_to_current_thre, sizeof(__pyx_k_Failed_to_attach_to_current_thre), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_create_Java_VM_Return, __pyx_k_Failed_to_create_Java_VM_Return, sizeof(__pyx_k_Failed_to_create_Java_VM_Return), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_get_class, __pyx_k_Failed_to_get_class, sizeof(__pyx_k_Failed_to_get_class), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_make_new_global_refere, __pyx_k_Failed_to_make_new_global_refere, sizeof(__pyx_k_Failed_to_make_new_global_refere), 0, 0, 1, 0},
  {&__pyx_kp_u_Format_string_allocated_too_shor, __pyx_k_Format_string_allocated_too_shor, sizeof(__pyx_k_Format_string_allocated_too_shor), 0, 1, 0, 0},
  {&__pyx_kp_u_Format_string_allocated_too_shor_2, __pyx_k_Format_string_allocated_too_shor_2, sizeof(__pyx_k_Format_string_allocated_too_shor_2), 0, 1, 0, 0},
  {&__pyx_n_s_I, __pyx_k_I, sizeof(__pyx_k_I), 0, 0, 1, 1},
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
  {&__pyx_n_s_J, __pyx_k_J, sizeof(__pyx_k_J), 0, 0, 1, 1},
  {&__pyx_kp_s_JB_Env_at_0x_x, __pyx_k_JB_Env_at_0x_x, sizeof(__pyx_k_JB_Env_at_0x_x), 0, 0, 1, 0},
  {&__pyx_kp_s_Java_class_at_0x_x, __pyx_k_Java_class_at_0x_x, sizeof(__pyx_k_Java_class_at_0x_x), 0, 0, 1, 0},
  {&__pyx_kp_s_Java_field_with_sig_s_at_0x_x, __pyx_k_Java_field_with_sig_s_at_0x_x, sizeof(__pyx_k_Java_field_with_sig_s_at_0x_x), 0, 0, 1, 0},
  {&__pyx_kp_s_Java_method_with_sig_s_at_0x_x, __pyx_k_Java_method_with_sig_s_at_0x_x, sizeof(__pyx_k_Java_method_with_sig_s_at_0x_x), 0, 0, 1, 0},
  {&__pyx_kp_s_Java_object_at_0x_x, __pyx_k_Java_object_at_0x_x, sizeof(__pyx_k_Java_object_at_0x_x), 0, 0, 1, 0},
  {&__pyx_n_s_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 0, 1, 1},
  {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {&__pyx_kp_s_Method_ID_is_None_check_your_met, __pyx_k_Method_ID_is_None_check_your_met, sizeof(__pyx_k_Method_ID_is_None_check_your_met), 0, 0, 1, 0},
  {&__pyx_kp_u_Non_native_byte_order_not_suppor, __pyx_k_Non_native_byte_order_not_suppor, sizeof(__pyx_k_Non_native_byte_order_not_suppor), 0, 1, 0, 0},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 0, 1, 1},
  {&__pyx_kp_s_Too_few_arguments_d_for_signatur, __pyx_k_Too_few_arguments_d_for_signatur, sizeof(__pyx_k_Too_few_arguments_d_for_signatur), 0, 0, 1, 0},
  {&__pyx_kp_s_Unhandled_return_type_Signature, __pyx_k_Unhandled_return_type_Signature, sizeof(__pyx_k_Unhandled_return_type_Signature), 0, 0, 1, 0},
  {&__pyx_kp_s_Unhandled_signature_s, __pyx_k_Unhandled_signature_s, sizeof(__pyx_k_Unhandled_signature_s), 0, 0, 1, 0},
  {&__pyx_n_s_V, __pyx_k_V, sizeof(__pyx_k_V), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_Z, __pyx_k_Z, sizeof(__pyx_k_Z), 0, 0, 1, 1},
  {&__pyx_kp_s__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 0, 1, 0},
  {&__pyx_kp_s__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 0, 1, 0},
  {&__pyx_kp_s__37, __pyx_k__37, sizeof(__pyx_k__37), 0, 0, 1, 0},
  {&__pyx_kp_s__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 0, 1, 0},
  {&__pyx_kp_s__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 0},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_astype, __pyx_k_astype, sizeof(__pyx_k_astype), 0, 0, 1, 1},
  {&__pyx_n_s_attach_as_daemon, __pyx_k_attach_as_daemon, sizeof(__pyx_k_attach_as_daemon), 0, 0, 1, 1},
  {&__pyx_n_s_bool8, __pyx_k_bool8, sizeof(__pyx_k_bool8), 0, 0, 1, 1},
  {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
  {&__pyx_kp_s_call_method_called_with_a_static, __pyx_k_call_method_called_with_a_static, sizeof(__pyx_k_call_method_called_with_a_static), 0, 0, 1, 0},
  {&__pyx_n_s_chr, __pyx_k_chr, sizeof(__pyx_k_chr), 0, 0, 1, 1},
  {&__pyx_n_s_class_name, __pyx_k_class_name, sizeof(__pyx_k_class_name), 0, 0, 1, 1},
  {&__pyx_n_s_clear, __pyx_k_clear, sizeof(__pyx_k_clear), 0, 0, 1, 1},
  {&__pyx_n_s_dead_objects, __pyx_k_dead_objects, sizeof(__pyx_k_dead_objects), 0, 0, 1, 1},
  {&__pyx_n_s_dealloc_jobject, __pyx_k_dealloc_jobject, sizeof(__pyx_k_dealloc_jobject), 0, 0, 1, 1},
  {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
  {&__pyx_n_s_detach, __pyx_k_detach, sizeof(__pyx_k_detach), 0, 0, 1, 1},
  {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
  {&__pyx_n_s_env, __pyx_k_env, sizeof(__pyx_k_env), 0, 0, 1, 1},
  {&__pyx_n_s_env_stack, __pyx_k_env_stack, sizeof(__pyx_k_env_stack), 0, 0, 1, 1},
  {&__pyx_n_s_envstack, __pyx_k_envstack, sizeof(__pyx_k_envstack), 0, 0, 1, 1},
  {&__pyx_n_s_field, __pyx_k_field, sizeof(__pyx_k_field), 0, 0, 1, 1},
  {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
  {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
  {&__pyx_n_s_float32, __pyx_k_float32, sizeof(__pyx_k_float32), 0, 0, 1, 1},
  {&__pyx_n_s_float64, __pyx_k_float64, sizeof(__pyx_k_float64), 0, 0, 1, 1},
  {&__pyx_n_s_get_env, __pyx_k_get_env, sizeof(__pyx_k_get_env), 0, 0, 1, 1},
  {&__pyx_n_s_get_thread_local, __pyx_k_get_thread_local, sizeof(__pyx_k_get_thread_local), 0, 0, 1, 1},
  {&__pyx_n_s_get_vm, __pyx_k_get_vm, sizeof(__pyx_k_get_vm), 0, 0, 1, 1},
  {&__pyx_kp_s_home_leek_projects_leekamentsky, __pyx_k_home_leek_projects_leekamentsky, sizeof(__pyx_k_home_leek_projects_leekamentsky), 0, 0, 1, 0},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_int16, __pyx_k_int16, sizeof(__pyx_k_int16), 0, 0, 1, 1},
  {&__pyx_n_s_int32, __pyx_k_int32, sizeof(__pyx_k_int32), 0, 0, 1, 1},
  {&__pyx_n_s_int64, __pyx_k_int64, sizeof(__pyx_k_int64), 0, 0, 1, 1},
  {&__pyx_n_s_is_active, __pyx_k_is_active, sizeof(__pyx_k_is_active), 0, 0, 1, 1},
  {&__pyx_n_s_is_static, __pyx_k_is_static, sizeof(__pyx_k_is_static), 0, 0, 1, 1},
  {&__pyx_n_s_javabridge, __pyx_k_javabridge, sizeof(__pyx_k_javabridge), 0, 0, 1, 1},
  {&__pyx_n_s_jb_attach, __pyx_k_jb_attach, sizeof(__pyx_k_jb_attach), 0, 0, 1, 1},
  {&__pyx_n_s_jb_detach, __pyx_k_jb_detach, sizeof(__pyx_k_jb_detach), 0, 0, 1, 1},
  {&__pyx_n_s_jbo, __pyx_k_jbo, sizeof(__pyx_k_jbo), 0, 0, 1, 1},
  {&__pyx_n_s_jni_enter, __pyx_k_jni_enter, sizeof(__pyx_k_jni_enter), 0, 0, 1, 1},
  {&__pyx_n_s_jni_exit, __pyx_k_jni_exit, sizeof(__pyx_k_jni_exit), 0, 0, 1, 1},
  {&__pyx_n_s_jvm_enter, __pyx_k_jvm_enter, sizeof(__pyx_k_jvm_enter), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_klass, __pyx_k_klass, sizeof(__pyx_k_klass), 0, 0, 1, 1},
  {&__pyx_n_s_len, __pyx_k_len, sizeof(__pyx_k_len), 0, 0, 1, 1},
  {&__pyx_n_s_local, __pyx_k_local, sizeof(__pyx_k_local), 0, 0, 1, 1},
  {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
  {&__pyx_n_s_mac_enter_run_loop, __pyx_k_mac_enter_run_loop, sizeof(__pyx_k_mac_enter_run_loop), 0, 0, 1, 1},
  {&__pyx_n_s_mac_is_main_thread, __pyx_k_mac_is_main_thread, sizeof(__pyx_k_mac_is_main_thread), 0, 0, 1, 1},
  {&__pyx_n_s_mac_poll_run_loop, __pyx_k_mac_poll_run_loop, sizeof(__pyx_k_mac_poll_run_loop), 0, 0, 1, 1},
  {&__pyx_n_s_mac_reset_run_loop, __pyx_k_mac_reset_run_loop, sizeof(__pyx_k_mac_reset_run_loop), 0, 0, 1, 1},
  {&__pyx_n_s_mac_run_loop_init, __pyx_k_mac_run_loop_init, sizeof(__pyx_k_mac_run_loop_init), 0, 0, 1, 1},
  {&__pyx_n_s_mac_stop_run_loop, __pyx_k_mac_stop_run_loop, sizeof(__pyx_k_mac_stop_run_loop), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_method, __pyx_k_method, sizeof(__pyx_k_method), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_u_ndarray_is_not_C_contiguous, __pyx_k_ndarray_is_not_C_contiguous, sizeof(__pyx_k_ndarray_is_not_C_contiguous), 0, 1, 0, 0},
  {&__pyx_kp_u_ndarray_is_not_Fortran_contiguou, __pyx_k_ndarray_is_not_Fortran_contiguou, sizeof(__pyx_k_ndarray_is_not_Fortran_contiguou), 0, 1, 0, 0},
  {&__pyx_n_s_new_env, __pyx_k_new_env, sizeof(__pyx_k_new_env), 0, 0, 1, 1},
  {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_kp_s_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 0, 1, 0},
  {&__pyx_kp_s_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 0, 1, 0},
  {&__pyx_n_s_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 0, 1, 1},
  {&__pyx_kp_s_of_arguments_d_in_call_did_not, __pyx_k_of_arguments_d_in_call_did_not, sizeof(__pyx_k_of_arguments_d_in_call_did_not), 0, 0, 1, 0},
  {&__pyx_n_s_old_env, __pyx_k_old_env, sizeof(__pyx_k_old_env), 0, 0, 1, 1},
  {&__pyx_n_s_options, __pyx_k_options, sizeof(__pyx_k_options), 0, 0, 1, 1},
  {&__pyx_n_s_path_to_libjli, __pyx_k_path_to_libjli, sizeof(__pyx_k_path_to_libjli), 0, 0, 1, 1},
  {&__pyx_n_s_path_to_libjvm, __pyx_k_path_to_libjvm, sizeof(__pyx_k_path_to_libjvm), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_reap, __pyx_k_reap, sizeof(__pyx_k_reap), 0, 0, 1, 1},
  {&__pyx_kp_s_s_is_not_a_Java_object, __pyx_k_s_is_not_a_Java_object, sizeof(__pyx_k_s_is_not_a_Java_object), 0, 0, 1, 0},
  {&__pyx_n_s_set, __pyx_k_set, sizeof(__pyx_k_set), 0, 0, 1, 1},
  {&__pyx_n_s_set_env, __pyx_k_set_env, sizeof(__pyx_k_set_env), 0, 0, 1, 1},
  {&__pyx_kp_s_set_env_called_with_non_environm, __pyx_k_set_env_called_with_non_environm, sizeof(__pyx_k_set_env_called_with_non_environm), 0, 0, 1, 0},
  {&__pyx_kp_s_set_env_called_with_something_ot, __pyx_k_set_env_called_with_something_ot, sizeof(__pyx_k_set_env_called_with_something_ot), 0, 0, 1, 0},
  {&__pyx_n_s_set_thread_local, __pyx_k_set_thread_local, sizeof(__pyx_k_set_thread_local), 0, 0, 1, 1},
  {&__pyx_n_s_set_vm, __pyx_k_set_vm, sizeof(__pyx_k_set_vm), 0, 0, 1, 1},
  {&__pyx_kp_s_set_vm_called_with_non_environme, __pyx_k_set_vm_called_with_non_environme, sizeof(__pyx_k_set_vm_called_with_non_environme), 0, 0, 1, 0},
  {&__pyx_kp_s_set_vm_called_with_something_oth, __pyx_k_set_vm_called_with_something_oth, sizeof(__pyx_k_set_vm_called_with_something_oth), 0, 0, 1, 0},
  {&__pyx_n_s_set_wake_event, __pyx_k_set_wake_event, sizeof(__pyx_k_set_wake_event), 0, 0, 1, 1},
  {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
  {&__pyx_n_s_sig, __pyx_k_sig, sizeof(__pyx_k_sig), 0, 0, 1, 1},
  {&__pyx_kp_s_static_call_method_called_with_a, __pyx_k_static_call_method_called_with_a, sizeof(__pyx_k_static_call_method_called_with_a), 0, 0, 1, 0},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_thread_local_env, __pyx_k_thread_local_env, sizeof(__pyx_k_thread_local_env), 0, 0, 1, 1},
  {&__pyx_n_s_threading, __pyx_k_threading, sizeof(__pyx_k_threading), 0, 0, 1, 1},
  {&__pyx_n_s_timeout, __pyx_k_timeout, sizeof(__pyx_k_timeout), 0, 0, 1, 1},
  {&__pyx_n_s_to_die, __pyx_k_to_die, sizeof(__pyx_k_to_die), 0, 0, 1, 1},
  {&__pyx_n_s_uint8, __pyx_k_uint8, sizeof(__pyx_k_uint8), 0, 0, 1, 1},
  {&__pyx_n_s_unichr, __pyx_k_unichr, sizeof(__pyx_k_unichr), 0, 0, 1, 1},
  {&__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_k_unknown_dtype_code_in_numpy_pxd, sizeof(__pyx_k_unknown_dtype_code_in_numpy_pxd), 0, 1, 0, 0},
  {&__pyx_kp_s_utf_16, __pyx_k_utf_16, sizeof(__pyx_k_utf_16), 0, 0, 1, 0},
  {&__pyx_kp_s_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 0, 1, 0},
  {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
  {&__pyx_n_s_vm, __pyx_k_vm, sizeof(__pyx_k_vm), 0, 0, 1, 1},
  {&__pyx_n_s_vm_2, __pyx_k_vm_2, sizeof(__pyx_k_vm_2), 0, 0, 1, 1},
  {&__pyx_n_s_wait, __pyx_k_wait, sizeof(__pyx_k_wait), 0, 0, 1, 1},
  {&__pyx_n_s_wait_for_wake_event, __pyx_k_wait_for_wake_event, sizeof(__pyx_k_wait_for_wake_event), 0, 0, 1, 1},
  {&__pyx_n_s_wake_event, __pyx_k_wake_event, sizeof(__pyx_k_wake_event), 0, 0, 1, 1},
  {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_chr = __Pyx_GetBuiltinName(__pyx_n_s_chr); if (!__pyx_builtin_chr) __PYX_ERR(0, 22, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 462, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 542, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 545, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(0, 639, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(0, 648, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 1822, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(1, 989, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "_javabridge.pyx":400
 * def get_env():
 *     '''Get the environment for this thread'''
 *     return get_thread_local("env")             # <<<<<<<<<<<<<<
 * 
 * def jb_attach():
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_n_s_env); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "_javabridge.pyx":414
 *     assert __vm is not None
 *     assert get_env() is not None
 *     set_thread_local("env", None)             # <<<<<<<<<<<<<<
 *     __vm.detach()
 * 
 */
  __pyx_tuple__2 = PyTuple_Pack(2, __pyx_n_s_env, Py_None); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "_javabridge.pyx":425
 *     a JNI native call.
 *     '''
 *     env_stack = get_thread_local("envstack", None)             # <<<<<<<<<<<<<<
 *     if env_stack is None:
 *         env_stack = []
 */
  __pyx_tuple__3 = PyTuple_Pack(2, __pyx_n_s_envstack, Py_None); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "_javabridge.pyx":438
 * def jni_exit():
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")             # <<<<<<<<<<<<<<
 *     if len(env_stack) == 0:
 *         set_thread_local("env", None)
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_n_s_envstack); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "_javabridge.pyx":440
 *     env_stack = get_thread_local("envstack")
 *     if len(env_stack) == 0:
 *         set_thread_local("env", None)             # <<<<<<<<<<<<<<
 *     else:
 *         set_thread_local("env", env_stack.pop())
 */
  __pyx_tuple__5 = PyTuple_Pack(2, __pyx_n_s_env, Py_None); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "_javabridge.pyx":549
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)
 */
  __pyx_slice__7 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__7)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__7);
  __Pyx_GIVEREF(__pyx_slice__7);

  /* "_javabridge.pyx":552
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'C': #char
 *             values[i].c = ord(arg[0])
 */
  __pyx_slice__8 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__8)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__8);
  __Pyx_GIVEREF(__pyx_slice__8);

  /* "_javabridge.pyx":555
 *         elif sig[0] == 'C': #char
 *             values[i].c = ord(arg[0])
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)
 */
  __pyx_slice__9 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__9)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__9);
  __Pyx_GIVEREF(__pyx_slice__9);

  /* "_javabridge.pyx":558
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)
 */
  __pyx_slice__10 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__10)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__10);
  __Pyx_GIVEREF(__pyx_slice__10);

  /* "_javabridge.pyx":561
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)
 */
  __pyx_slice__11 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__11)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__11);
  __Pyx_GIVEREF(__pyx_slice__11);

  /* "_javabridge.pyx":564
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)
 */
  __pyx_slice__12 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__12)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__12);
  __Pyx_GIVEREF(__pyx_slice__12);

  /* "_javabridge.pyx":567
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)
 */
  __pyx_slice__13 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__13)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__13);
  __Pyx_GIVEREF(__pyx_slice__13);

  /* "_javabridge.pyx":570
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):
 */
  __pyx_slice__14 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__14)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__14);
  __Pyx_GIVEREF(__pyx_slice__14);

  /* "_javabridge.pyx":596
 *                      sig = sig[(non_bracket_ind+1):]
 *                      continue
 *             sig = sig[sig.find(';')+1:]             # <<<<<<<<<<<<<<
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_s__16); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "_javabridge.pyx":617
 *         '''
 *         if not PyCapsule_CheckExact(capsule):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_vm called with something other than a wrapped environment")
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_s_set_vm_called_with_something_oth); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "_javabridge.pyx":621
 *         self.vm = <JavaVM *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.vm:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_vm called with non-environment capsule")
 * 
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_s_set_vm_called_with_non_environme); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "_javabridge.pyx":639
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option) for option in options]
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_s_Failed_to_allocate_JavaVMInitArg); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "_javabridge.pyx":643
 *         optionutf8=[] # list for temporarily storing utf-8 copies of strings
 *         for i, option in enumerate(options):
 *             optionutf8.append(option.encode('utf-8'))             # <<<<<<<<<<<<<<
 *             args.options[i].optionString = optionutf8[-1]
 *         result = CreateJavaVM(&self.vm, <void **>&env, &args)
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "_javabridge.pyx":678
 *         path_to_libjli - path to libjli.dylib
 *         '''
 *         class_name = str(class_name).encode("utf-8")             # <<<<<<<<<<<<<<
 *         path_to_libjvm = str(path_to_libjvm).encode("utf-8")
 *         path_to_libjli = str(path_to_libjli).encode("utf-8")
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "_javabridge.pyx":679
 *         '''
 *         class_name = str(class_name).encode("utf-8")
 *         path_to_libjvm = str(path_to_libjvm).encode("utf-8")             # <<<<<<<<<<<<<<
 *         path_to_libjli = str(path_to_libjli).encode("utf-8")
 *         cdef:
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "_javabridge.pyx":680
 *         class_name = str(class_name).encode("utf-8")
 *         path_to_libjvm = str(path_to_libjvm).encode("utf-8")
 *         path_to_libjli = str(path_to_libjli).encode("utf-8")             # <<<<<<<<<<<<<<
 *         cdef:
 *             JavaVMInitArgs args
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "_javabridge.pyx":695
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option).encode("utf-8") for option in options]
 *         for i, option in enumerate(options):
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_s_Failed_to_allocate_JavaVMInitArg); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "_javabridge.pyx":696
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option).encode("utf-8") for option in options]             # <<<<<<<<<<<<<<
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "_javabridge.pyx":759
 *         '''
 *         if not PyCapsule_CheckExact(capsule):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_env called with something other than a wrapped environment")
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_s_set_env_called_with_something_ot); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "_javabridge.pyx":763
 *         self.env = <JNIEnv *>PyCapsule_GetPointer(capsule, NULL)
 *         if not self.env:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *             "set_env called with non-environment capsule")
 * 
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_s_set_env_called_with_non_environm); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "_javabridge.pyx":793
 *             jclass c
 *             JB_Class result
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         c = self.env[0].FindClass(self.env, utf8name)
 *         if c == NULL:
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "_javabridge.pyx":860
 *             jmethodID id
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 *         if c is None:
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "_javabridge.pyx":861
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "_javabridge.pyx":863
 *         utf8sig = sig.encode('utf-8')
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_s_Class_None_on_call_to_get_method); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "_javabridge.pyx":887
 *             jmethodID id
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "_javabridge.pyx":888
 *             __JB_MethodID result
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "_javabridge.pyx":944
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use"
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_kp_s_Method_ID_is_None_check_your_met); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "_javabridge.pyx":946
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use"             # <<<<<<<<<<<<<<
 *                              " call_static_method instead")
 *         sig = m.sig  # m.sig should be unicode already, no need to decode
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_kp_s_call_method_called_with_a_static); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "_javabridge.pyx":951
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_kp_s__38); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "_javabridge.pyx":1041
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 */
  __pyx_tuple__40 = PyTuple_Pack(1, __pyx_kp_s_Method_ID_is_None_check_your_met); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "_javabridge.pyx":1043
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")             # <<<<<<<<<<<<<<
 *         sig = m.sig
 *         if sig[0] != '(':
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_s_static_call_method_called_with_a); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "_javabridge.pyx":1047
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_kp_s__38); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "_javabridge.pyx":1122
 *             __JB_FieldID jbid
 * 
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 * 
 */
  __pyx_tuple__43 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "_javabridge.pyx":1123
 * 
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 1123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "_javabridge.pyx":1352
 *             __JB_FieldID jbid
 * 
 *         utf8name = name.encode('utf-8')             # <<<<<<<<<<<<<<
 *         utf8sig = sig.encode('utf-8')
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 */
  __pyx_tuple__45 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 1352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "_javabridge.pyx":1353
 * 
 *         utf8name = name.encode('utf-8')
 *         utf8sig = sig.encode('utf-8')             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, utf8name, utf8sig)
 *         if id == NULL:
 */
  __pyx_tuple__46 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "_javabridge.pyx":1603
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_tuple__47 = PyTuple_Pack(1, __pyx_kp_s__38); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 1603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "_javabridge.pyx":1633
 *             jsize nchars
 *             jobject o
 *         u16 = u.encode("utf-16")             # <<<<<<<<<<<<<<
 *         nchars = len(u16) / 2 - 1
 *         s = u16
 */
  __pyx_tuple__48 = PyTuple_Pack(1, __pyx_kp_s_utf_16); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 1633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "_javabridge.pyx":1638
 *         o = self.env[0].NewString(self.env, <jchar *>s+1, nchars)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")             # <<<<<<<<<<<<<<
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_kp_s_Failed_to_allocate_string); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 1638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "_javabridge.pyx":1653
 *         cdef:
 *             jobject o
 *         o = self.env[0].NewStringUTF(self.env, s.encode('utf-8'))             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 */
  __pyx_tuple__50 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "_javabridge.pyx":1655
 *         o = self.env[0].NewStringUTF(self.env, s.encode('utf-8'))
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")             # <<<<<<<<<<<<<<
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 */
  __pyx_tuple__51 = PyTuple_Pack(1, __pyx_kp_s_Failed_to_allocate_string); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 1655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "_javabridge.pyx":1983
 *             JB_Object jbo
 *         if not PyCapsule_CheckExact(pCapsule):
 *             raise ValueError("Argument must be a jobject in a capsule")             # <<<<<<<<<<<<<<
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 *         if not jobj:
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_kp_s_Argument_must_be_a_jobject_in_a); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 1983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "_javabridge.pyx":1986
 *         jobj = <jobject>PyCapsule_GetPointer(pCapsule, NULL)
 *         if not jobj:
 *             raise ValueError("Capsule did not contain a jobject")             # <<<<<<<<<<<<<<
 *         jbo = JB_Object()
 *         jbo.o = jobj
 */
  __pyx_tuple__53 = PyTuple_Pack(1, __pyx_kp_s_Capsule_did_not_contain_a_jobjec); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 1986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "_javabridge.pyx":2005
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))             # <<<<<<<<<<<<<<
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()
 */
  __pyx_tuple__54 = PyTuple_Pack(1, __pyx_kp_s_Failed_to_make_new_global_refere); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 2005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":218
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_C_contiguous); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(1, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":222
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_tuple__56 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_Fortran_contiguou); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(1, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":259
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_tuple__57 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(1, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":799
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
  __pyx_tuple__58 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(1, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(1, 803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_tuple__60 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor_2); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(1, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":989
 *         _import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_kp_s_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(1, 989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":995
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__62 = PyTuple_Pack(1, __pyx_kp_s_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(1, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":1001
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__63 = PyTuple_Pack(1, __pyx_kp_s_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(1, 1001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "_javabridge.pyx":20
 * cimport cpython
 * 
 * if sys.version_info >= (3, 0, 0):             # <<<<<<<<<<<<<<
 *     # unchir -> chr in Python 3
 *     unichr = chr
 */
  __pyx_tuple__64 = PyTuple_Pack(3, __pyx_int_3, __pyx_int_0, __pyx_int_0); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "_javabridge.pyx":319
 *     int CreateJavaVM(JavaVM **pvm, void **pEnv, void *args) nogil
 * 
 * def mac_run_loop_init():             # <<<<<<<<<<<<<<
 *     MacRunLoopInit()
 * 
 */
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_mac_run_loop_init, 319, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(0, 319, __pyx_L1_error)

  /* "_javabridge.pyx":322
 *     MacRunLoopInit()
 * 
 * def mac_reset_run_loop():             # <<<<<<<<<<<<<<
 *     '''Reset the run loop's internal state so that it's ready to run
 *     '''
 */
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_mac_reset_run_loop, 322, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(0, 322, __pyx_L1_error)

  /* "_javabridge.pyx":328
 *         MacRunLoopReset()
 * 
 * def mac_enter_run_loop():             # <<<<<<<<<<<<<<
 *     '''Enter the run loop and stay there until mac_stop_run_loop is called
 * 
 */
  __pyx_codeobj__67 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_mac_enter_run_loop, 328, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__67)) __PYX_ERR(0, 328, __pyx_L1_error)

  /* "_javabridge.pyx":337
 *         MacRunLoopRun()
 * 
 * def mac_poll_run_loop(timeout):             # <<<<<<<<<<<<<<
 *     MacRunLoopRunInMode(timeout)
 * 
 */
  __pyx_tuple__68 = PyTuple_Pack(1, __pyx_n_s_timeout); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);
  __pyx_codeobj__69 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__68, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_mac_poll_run_loop, 337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__69)) __PYX_ERR(0, 337, __pyx_L1_error)

  /* "_javabridge.pyx":340
 *     MacRunLoopRunInMode(timeout)
 * 
 * def mac_stop_run_loop():             # <<<<<<<<<<<<<<
 *     '''Signal the run loop to stop
 * 
 */
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_mac_stop_run_loop, 340, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 340, __pyx_L1_error)

  /* "_javabridge.pyx":349
 *         MacRunLoopStop()
 * 
 * def mac_is_main_thread():             # <<<<<<<<<<<<<<
 *     '''Return True if the current thread runs the main OS/X run loop
 * 
 */
  __pyx_codeobj__71 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_mac_is_main_thread, 349, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__71)) __PYX_ERR(0, 349, __pyx_L1_error)

  /* "_javabridge.pyx":375
 * __wake_event = threading.Event()
 * 
 * def wait_for_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wait for dead objects to be enqueued or other event on monitor thread'''
 *     __wake_event.wait()
 */
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_wait_for_wake_event, 375, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(0, 375, __pyx_L1_error)

  /* "_javabridge.pyx":380
 *     __wake_event.clear()
 * 
 * def set_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wake up the monitor thread'''
 *     __wake_event.set()
 */
  __pyx_codeobj__73 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_set_wake_event, 380, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__73)) __PYX_ERR(0, 380, __pyx_L1_error)

  /* "_javabridge.pyx":384
 *     __wake_event.set()
 * 
 * def get_vm():             # <<<<<<<<<<<<<<
 *     global __vm
 *     if __vm is None:
 */
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_get_vm, 384, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(0, 384, __pyx_L1_error)

  /* "_javabridge.pyx":390
 *     return __vm
 * 
 * def get_thread_local(key, default=None):             # <<<<<<<<<<<<<<
 *     if not hasattr(__thread_local_env, key):
 *         setattr(__thread_local_env, key, default)
 */
  __pyx_tuple__75 = PyTuple_Pack(2, __pyx_n_s_key, __pyx_n_s_default); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__75, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_get_thread_local, 390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) __PYX_ERR(0, 390, __pyx_L1_error)

  /* "_javabridge.pyx":395
 *     return getattr(__thread_local_env, key)
 * 
 * def set_thread_local(key, value):             # <<<<<<<<<<<<<<
 *     setattr(__thread_local_env, key, value)
 * 
 */
  __pyx_tuple__77 = PyTuple_Pack(2, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_set_thread_local, 395, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) __PYX_ERR(0, 395, __pyx_L1_error)

  /* "_javabridge.pyx":398
 *     setattr(__thread_local_env, key, value)
 * 
 * def get_env():             # <<<<<<<<<<<<<<
 *     '''Get the environment for this thread'''
 *     return get_thread_local("env")
 */
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_get_env, 398, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(0, 398, __pyx_L1_error)

  /* "_javabridge.pyx":402
 *     return get_thread_local("env")
 * 
 * def jb_attach():             # <<<<<<<<<<<<<<
 *     '''Attach to this thread's environment'''
 *     assert __vm is not None
 */
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_jb_attach, 402, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) __PYX_ERR(0, 402, __pyx_L1_error)

  /* "_javabridge.pyx":410
 *     return get_env()
 * 
 * def jb_detach():             # <<<<<<<<<<<<<<
 *     '''Detach from this thread's environment'''
 *     assert __vm is not None
 */
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_jb_detach, 410, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(0, 410, __pyx_L1_error)

  /* "_javabridge.pyx":417
 *     __vm.detach()
 * 
 * def jni_enter(env):             # <<<<<<<<<<<<<<
 *     '''Enter Python from Java
 * 
 */
  __pyx_tuple__82 = PyTuple_Pack(4, __pyx_n_s_env, __pyx_n_s_env_stack, __pyx_n_s_old_env, __pyx_n_s_new_env); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(1, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__82, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_jni_enter, 417, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 417, __pyx_L1_error)

  /* "_javabridge.pyx":436
 *     set_thread_local("env", new_env)
 * 
 * def jni_exit():             # <<<<<<<<<<<<<<
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")
 */
  __pyx_tuple__84 = PyTuple_Pack(1, __pyx_n_s_env_stack); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_jni_exit, 436, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(0, 436, __pyx_L1_error)

  /* "_javabridge.pyx":444
 *         set_thread_local("env", env_stack.pop())
 * 
 * def jvm_enter(vm):             # <<<<<<<<<<<<<<
 *     '''Initialize the JVM on entry into Python
 * 
 */
  __pyx_tuple__86 = PyTuple_Pack(1, __pyx_n_s_vm_2); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__86, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_jvm_enter, 444, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(0, 444, __pyx_L1_error)

  /* "_javabridge.pyx":453
 *     get_vm().set_vm(vm)
 * 
 * def reap():             # <<<<<<<<<<<<<<
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:
 */
  __pyx_tuple__88 = PyTuple_Pack(2, __pyx_n_s_env, __pyx_n_s_to_die); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(0, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_leek_projects_leekamentsky, __pyx_n_s_reap, 453, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_javabridge(void); /*proto*/
PyMODINIT_FUNC init_javabridge(void)
#else
PyMODINIT_FUNC PyInit__javabridge(void); /*proto*/
PyMODINIT_FUNC PyInit__javabridge(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__javabridge(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("_javabridge", __pyx_methods, __pyx_k_javabridge_pyx_low_level_interf, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main__javabridge) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "_javabridge")) {
      if (unlikely(PyDict_SetItemString(modules, "_javabridge", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  __pyx_ptype_11_javabridge_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_11_javabridge_ndarray)) __PYX_ERR(0, 41, __pyx_L1_error)
  if (PyType_Ready(&__pyx_type_11_javabridge_JB_Object) < 0) __PYX_ERR(0, 465, __pyx_L1_error)
  __pyx_type_11_javabridge_JB_Object.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "JB_Object", (PyObject *)&__pyx_type_11_javabridge_JB_Object) < 0) __PYX_ERR(0, 465, __pyx_L1_error)
  __pyx_ptype_11_javabridge_JB_Object = &__pyx_type_11_javabridge_JB_Object;
  if (PyType_Ready(&__pyx_type_11_javabridge_JB_Class) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  __pyx_type_11_javabridge_JB_Class.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "JB_Class", (PyObject *)&__pyx_type_11_javabridge_JB_Class) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  __pyx_ptype_11_javabridge_JB_Class = &__pyx_type_11_javabridge_JB_Class;
  if (PyType_Ready(&__pyx_type_11_javabridge___JB_MethodID) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
  __pyx_type_11_javabridge___JB_MethodID.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "__JB_MethodID", (PyObject *)&__pyx_type_11_javabridge___JB_MethodID) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
  __pyx_ptype_11_javabridge___JB_MethodID = &__pyx_type_11_javabridge___JB_MethodID;
  if (PyType_Ready(&__pyx_type_11_javabridge___JB_FieldID) < 0) __PYX_ERR(0, 517, __pyx_L1_error)
  __pyx_type_11_javabridge___JB_FieldID.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "__JB_FieldID", (PyObject *)&__pyx_type_11_javabridge___JB_FieldID) < 0) __PYX_ERR(0, 517, __pyx_L1_error)
  __pyx_ptype_11_javabridge___JB_FieldID = &__pyx_type_11_javabridge___JB_FieldID;
  if (PyType_Ready(&__pyx_type_11_javabridge_JB_VM) < 0) __PYX_ERR(0, 603, __pyx_L1_error)
  __pyx_type_11_javabridge_JB_VM.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "JB_VM", (PyObject *)&__pyx_type_11_javabridge_JB_VM) < 0) __PYX_ERR(0, 603, __pyx_L1_error)
  __pyx_ptype_11_javabridge_JB_VM = &__pyx_type_11_javabridge_JB_VM;
  if (PyType_Ready(&__pyx_type_11_javabridge_JB_Env) < 0) __PYX_ERR(0, 738, __pyx_L1_error)
  __pyx_type_11_javabridge_JB_Env.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "JB_Env", (PyObject *)&__pyx_type_11_javabridge_JB_Env) < 0) __PYX_ERR(0, 738, __pyx_L1_error)
  __pyx_ptype_11_javabridge_JB_Env = &__pyx_type_11_javabridge_JB_Env;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "type", 
  #if CYTHON_COMPILING_IN_PYPY
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  0); if (unlikely(!__pyx_ptype_7cpython_4type_type)) __PYX_ERR(2, 9, __pyx_L1_error)
  __pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "bool", sizeof(PyBoolObject), 0); if (unlikely(!__pyx_ptype_7cpython_4bool_bool)) __PYX_ERR(3, 8, __pyx_L1_error)
  __pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "complex", sizeof(PyComplexObject), 0); if (unlikely(!__pyx_ptype_7cpython_7complex_complex)) __PYX_ERR(4, 15, __pyx_L1_error)
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType("numpy", "dtype", sizeof(PyArray_Descr), 0); if (unlikely(!__pyx_ptype_5numpy_dtype)) __PYX_ERR(1, 155, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType("numpy", "flatiter", sizeof(PyArrayIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_flatiter)) __PYX_ERR(1, 168, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType("numpy", "broadcast", sizeof(PyArrayMultiIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_broadcast)) __PYX_ERR(1, 172, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_5numpy_ndarray)) __PYX_ERR(1, 181, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType("numpy", "ufunc", sizeof(PyUFuncObject), 0); if (unlikely(!__pyx_ptype_5numpy_ufunc)) __PYX_ERR(1, 861, __pyx_L1_error)
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "_javabridge.pyx":12
 * """
 * 
 * import numpy as np             # <<<<<<<<<<<<<<
 * import sys
 * import threading
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_numpy, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_1) < 0) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":13
 * 
 * import numpy as np
 * import sys             # <<<<<<<<<<<<<<
 * import threading
 * cimport numpy as np
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":14
 * import numpy as np
 * import sys
 * import threading             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * cimport cython
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_threading, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_threading, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":20
 * cimport cpython
 * 
 * if sys.version_info >= (3, 0, 0):             # <<<<<<<<<<<<<<
 *     # unchir -> chr in Python 3
 *     unichr = chr
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_tuple__64, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "_javabridge.pyx":22
 * if sys.version_info >= (3, 0, 0):
 *     # unchir -> chr in Python 3
 *     unichr = chr             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "Python.h":
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_unichr, __pyx_builtin_chr) < 0) __PYX_ERR(0, 22, __pyx_L1_error)

    /* "_javabridge.pyx":20
 * cimport cpython
 * 
 * if sys.version_info >= (3, 0, 0):             # <<<<<<<<<<<<<<
 *     # unchir -> chr in Python 3
 *     unichr = chr
 */
  }

  /* "_javabridge.pyx":48
 *     cdef int  PyArray_ITEMSIZE(np.ndarray)
 * 
 * import_array()             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "jni.h":
 */
  import_array();

  /* "_javabridge.pyx":319
 *     int CreateJavaVM(JavaVM **pvm, void **pEnv, void *args) nogil
 * 
 * def mac_run_loop_init():             # <<<<<<<<<<<<<<
 *     MacRunLoopInit()
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_1mac_run_loop_init, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mac_run_loop_init, __pyx_t_1) < 0) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":322
 *     MacRunLoopInit()
 * 
 * def mac_reset_run_loop():             # <<<<<<<<<<<<<<
 *     '''Reset the run loop's internal state so that it's ready to run
 *     '''
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_3mac_reset_run_loop, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mac_reset_run_loop, __pyx_t_1) < 0) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":328
 *         MacRunLoopReset()
 * 
 * def mac_enter_run_loop():             # <<<<<<<<<<<<<<
 *     '''Enter the run loop and stay there until mac_stop_run_loop is called
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_5mac_enter_run_loop, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mac_enter_run_loop, __pyx_t_1) < 0) __PYX_ERR(0, 328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":337
 *         MacRunLoopRun()
 * 
 * def mac_poll_run_loop(timeout):             # <<<<<<<<<<<<<<
 *     MacRunLoopRunInMode(timeout)
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_7mac_poll_run_loop, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mac_poll_run_loop, __pyx_t_1) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":340
 *     MacRunLoopRunInMode(timeout)
 * 
 * def mac_stop_run_loop():             # <<<<<<<<<<<<<<
 *     '''Signal the run loop to stop
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_9mac_stop_run_loop, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mac_stop_run_loop, __pyx_t_1) < 0) __PYX_ERR(0, 340, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":349
 *         MacRunLoopStop()
 * 
 * def mac_is_main_thread():             # <<<<<<<<<<<<<<
 *     '''Return True if the current thread runs the main OS/X run loop
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_11mac_is_main_thread, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mac_is_main_thread, __pyx_t_1) < 0) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":370
 * #######################################################
 * 
 * __vm = None             # <<<<<<<<<<<<<<
 * __thread_local_env = threading.local()
 * __dead_objects = []
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_vm, Py_None) < 0) __PYX_ERR(0, 370, __pyx_L1_error)

  /* "_javabridge.pyx":371
 * 
 * __vm = None
 * __thread_local_env = threading.local()             # <<<<<<<<<<<<<<
 * __dead_objects = []
 * __wake_event = threading.Event()
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_threading); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_local); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 371, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 371, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_thread_local_env, __pyx_t_1) < 0) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":372
 * __vm = None
 * __thread_local_env = threading.local()
 * __dead_objects = []             # <<<<<<<<<<<<<<
 * __wake_event = threading.Event()
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dead_objects, __pyx_t_1) < 0) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":373
 * __thread_local_env = threading.local()
 * __dead_objects = []
 * __wake_event = threading.Event()             # <<<<<<<<<<<<<<
 * 
 * def wait_for_wake_event():
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_threading); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_Event); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wake_event, __pyx_t_1) < 0) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":375
 * __wake_event = threading.Event()
 * 
 * def wait_for_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wait for dead objects to be enqueued or other event on monitor thread'''
 *     __wake_event.wait()
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_13wait_for_wake_event, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wait_for_wake_event, __pyx_t_1) < 0) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":380
 *     __wake_event.clear()
 * 
 * def set_wake_event():             # <<<<<<<<<<<<<<
 *     '''Wake up the monitor thread'''
 *     __wake_event.set()
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_15set_wake_event, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set_wake_event, __pyx_t_1) < 0) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":384
 *     __wake_event.set()
 * 
 * def get_vm():             # <<<<<<<<<<<<<<
 *     global __vm
 *     if __vm is None:
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_17get_vm, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_vm, __pyx_t_1) < 0) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":390
 *     return __vm
 * 
 * def get_thread_local(key, default=None):             # <<<<<<<<<<<<<<
 *     if not hasattr(__thread_local_env, key):
 *         setattr(__thread_local_env, key, default)
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_19get_thread_local, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_thread_local, __pyx_t_1) < 0) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":395
 *     return getattr(__thread_local_env, key)
 * 
 * def set_thread_local(key, value):             # <<<<<<<<<<<<<<
 *     setattr(__thread_local_env, key, value)
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_21set_thread_local, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set_thread_local, __pyx_t_1) < 0) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":398
 *     setattr(__thread_local_env, key, value)
 * 
 * def get_env():             # <<<<<<<<<<<<<<
 *     '''Get the environment for this thread'''
 *     return get_thread_local("env")
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_23get_env, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_env, __pyx_t_1) < 0) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":402
 *     return get_thread_local("env")
 * 
 * def jb_attach():             # <<<<<<<<<<<<<<
 *     '''Attach to this thread's environment'''
 *     assert __vm is not None
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_25jb_attach, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_jb_attach, __pyx_t_1) < 0) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":410
 *     return get_env()
 * 
 * def jb_detach():             # <<<<<<<<<<<<<<
 *     '''Detach from this thread's environment'''
 *     assert __vm is not None
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_27jb_detach, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_jb_detach, __pyx_t_1) < 0) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":417
 *     __vm.detach()
 * 
 * def jni_enter(env):             # <<<<<<<<<<<<<<
 *     '''Enter Python from Java
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_29jni_enter, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_jni_enter, __pyx_t_1) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":436
 *     set_thread_local("env", new_env)
 * 
 * def jni_exit():             # <<<<<<<<<<<<<<
 *     '''Exit the JNI from Python'''
 *     env_stack = get_thread_local("envstack")
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_31jni_exit, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_jni_exit, __pyx_t_1) < 0) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":444
 *         set_thread_local("env", env_stack.pop())
 * 
 * def jvm_enter(vm):             # <<<<<<<<<<<<<<
 *     '''Initialize the JVM on entry into Python
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_33jvm_enter, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_jvm_enter, __pyx_t_1) < 0) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":453
 *     get_vm().set_vm(vm)
 * 
 * def reap():             # <<<<<<<<<<<<<<
 *     '''Reap all of the garbage-collected Java objects on the dead_objects list'''
 *     if len(__dead_objects) > 0:
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_11_javabridge_35reap, NULL, __pyx_n_s_javabridge); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reap, __pyx_t_1) < 0) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_javabridge.pyx":1
 * """_javabridge.pyx - low-level interface to the JVM             # <<<<<<<<<<<<<<
 * 
 * python-javabridge is licensed under the BSD license.  See the
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../../../anaconda2/envs/javabridge/lib/python2.7/site-packages/Cython/Includes/numpy/__init__.pxd":997
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init _javabridge", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init _javabridge");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* PyCFunctionFastCall */
  #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs, NULL);
}
#endif  // CYTHON_FAST_PYCCALL

/* PyFunctionFastCall */
  #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = PyThreadState_GET();
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif  // CPython < 3.6
#endif  // CYTHON_FAST_PYCALL

/* PyObjectCall */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
  #if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCallNoArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* RaiseDoubleKeywords */
      static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
      static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
      static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* GetAttr */
      static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* PyObjectCallMethod1 */
      static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto done;
#if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *args;
            PyObject *function = PyMethod_GET_FUNCTION(method);
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(function)) {
                PyObject *args[2] = {self, arg};
                result = __Pyx_PyFunction_FastCall(function, args, 2);
                goto done;
            }
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(function)) {
                PyObject *args[2] = {self, arg};
                result = __Pyx_PyCFunction_FastCall(function, args, 2);
                goto done;
            }
            #endif
            args = PyTuple_New(2);
            if (unlikely(!args)) goto done;
            Py_INCREF(self);
            PyTuple_SET_ITEM(args, 0, self);
            Py_INCREF(arg);
            PyTuple_SET_ITEM(args, 1, arg);
            Py_INCREF(function);
            Py_DECREF(method); method = NULL;
            result = __Pyx_PyObject_Call(function, args, NULL);
            Py_DECREF(args);
            Py_DECREF(function);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallOneArg(method, arg);
done:
    Py_XDECREF(method);
    return result;
}

/* append */
      static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* PyObjectCallMethod0 */
      static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
#if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *function = PyMethod_GET_FUNCTION(method);
            result = __Pyx_PyObject_CallOneArg(function, self);
            Py_DECREF(method);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* UnpackUnboundCMethod */
      static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(PyObject_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
      static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* pop */
      static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (Py_TYPE(L) == &PySet_Type) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_n_s_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        Py_SIZE(L) -= 1;
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* SaveResetException */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    return PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* PyErrFetchRestore */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* KeywordStringCheck */
      static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* WriteUnraisableException */
      static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* GetItemInt */
      static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (wraparound & unlikely(i < 0)) i += PyList_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (wraparound & unlikely(i < 0)) i += PyTuple_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* BytesEquals */
      static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
      static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* SliceObject */
      static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* UnicodeAsUCS4 */
      static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
   Py_ssize_t length;
   #if CYTHON_PEP393_ENABLED
   length = PyUnicode_GET_LENGTH(x);
   if (likely(length == 1)) {
       return PyUnicode_READ_CHAR(x, 0);
   }
   #else
   length = PyUnicode_GET_SIZE(x);
   if (likely(length == 1)) {
       return PyUnicode_AS_UNICODE(x)[0];
   }
   #if Py_UNICODE_SIZE == 2
   else if (PyUnicode_GET_SIZE(x) == 2) {
       Py_UCS4 high_val = PyUnicode_AS_UNICODE(x)[0];
       if (high_val >= 0xD800 && high_val <= 0xDBFF) {
           Py_UCS4 low_val = PyUnicode_AS_UNICODE(x)[1];
           if (low_val >= 0xDC00 && low_val <= 0xDFFF) {
               return 0x10000 + (((high_val & ((1<<10)-1)) << 10) | (low_val & ((1<<10)-1)));
           }
       }
   }
   #endif
   #endif
   PyErr_Format(PyExc_ValueError,
                "only single character unicode strings can be converted to Py_UCS4, "
                "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
   return (Py_UCS4)-1;
}

/* object_ord */
      static long __Pyx__PyObject_Ord(PyObject* c) {
    Py_ssize_t size;
    if (PyBytes_Check(c)) {
        size = PyBytes_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyBytes_AS_STRING(c)[0];
        }
#if PY_MAJOR_VERSION < 3
    } else if (PyUnicode_Check(c)) {
        return (long)__Pyx_PyUnicode_AsPy_UCS4(c);
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    } else if (PyByteArray_Check(c)) {
        size = PyByteArray_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyByteArray_AS_STRING(c)[0];
        }
#endif
    } else {
        PyErr_Format(PyExc_TypeError,
            "ord() expected string of length 1, but %.200s found", c->ob_type->tp_name);
        return (long)(Py_UCS4)-1;
    }
    PyErr_Format(PyExc_TypeError,
        "ord() expected a character, but string of length %zd found", size);
    return (long)(Py_UCS4)-1;
}

/* pyobject_as_double */
      static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if !CYTHON_USE_TYPE_SLOTS
    float_value = PyNumber_Float(obj);  if (0) goto bad;
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

/* ExtTypeTest */
      static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* RaiseException */
      #if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyIntBinop */
        #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* GetException */
        #if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
#endif
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* ArgTypeTest */
          static void __Pyx_RaiseArgumentTypeInvalid(const char* name, PyObject *obj, PyTypeObject *type) {
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
}
static CYTHON_INLINE int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (likely(Py_TYPE(obj) == type)) return 1;
        #if PY_MAJOR_VERSION == 2
        else if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(PyObject_TypeCheck(obj, type))) return 1;
    }
    __Pyx_RaiseArgumentTypeInvalid(name, obj, type);
    return 0;
}

/* None */
          static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* None */
          static CYTHON_INLINE long __Pyx_mod_long(long a, long b) {
    long r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* RaiseTooManyValuesToUnpack */
          static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
          static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
          static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
          static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* PyIntBinop */
          #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) {
            Py_RETURN_TRUE;
        } else {
            Py_RETURN_FALSE;
        }
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a;
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                #if PyLong_SHIFT < 30 && PyLong_SHIFT != 15
                default: return PyLong_Type.tp_richcompare(op1, op2, Py_EQ);
                #else
                default: Py_RETURN_FALSE;
                #endif
            }
        }
            if (a == b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            if ((double)a == (double)b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    return PyObject_RichCompare(op1, op2, Py_EQ);
}
#endif

/* None */
          static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t a, Py_ssize_t b) {
    Py_ssize_t q = a / b;
    Py_ssize_t r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* decode_c_string */
          static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    length = stop - start;
    if (unlikely(length <= 0))
        return PyUnicode_FromUnicode(NULL, 0);
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* BufferFormatCheck */
          static CYTHON_INLINE int __Pyx_IsLittleEndian(void) {
  unsigned int n = 1;
  return *(unsigned char*)(&n) != 0;
}
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t < '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static CYTHON_INLINE PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number;
    int ndim = ctx->head->field->type->ndim;
;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
      case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if (ctx->enc_type == *ts && got_Z == ctx->is_complex &&
            ctx->enc_packmode == ctx->new_packmode) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}
static CYTHON_INLINE void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static CYTHON_INLINE int __Pyx_GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  if (obj == Py_None || obj == NULL) {
    __Pyx_ZeroBuffer(buf);
    return 0;
  }
  buf->buf = NULL;
  if (__Pyx_GetBuffer(obj, buf, flags) == -1) goto fail;
  if (buf->ndim != nd) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if ((unsigned)buf->itemsize != dtype->size) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_ZeroBuffer(buf);
  return -1;
}
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (info->buf == NULL) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}

/* BufferFallbackError */
            static void __Pyx_RaiseBufferFallbackError(void) {
  PyErr_SetString(PyExc_ValueError,
     "Buffer acquisition failed on assignment; and then reacquiring the old buffer failed too!");
}

/* RaiseNoneIterError */
            static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* Import */
            static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* CodeObjectCache */
            static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
            #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) return __pyx_pw_5numpy_7ndarray_1__getbuffer__(obj, view, flags);
    PyErr_Format(PyExc_TypeError, "'%.200s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) { __pyx_pw_5numpy_7ndarray_3__releasebuffer__(obj, view); return; }
    Py_DECREF(obj);
    view->obj = NULL;
}
#endif


            /* CIntFromPyVerify */
            #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jint(jint value) {
    const jint neg_one = (jint) -1, const_zero = (jint) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(jint) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(jint) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jint) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(jint) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jint) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(jint),
                                     little, !is_unsigned);
    }
}

/* Print */
            #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0) {
                switch (s[len-1]) {
                    case ' ': break;
                    case '\f': case '\r': case '\n': case '\t': case '\v':
                        PyFile_SoftSpace(f, 0);
                        break;
                    default:  break;
                }
            }
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = PyObject_GetAttr(__pyx_b, __pyx_n_s_print);
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItem(kwargs, __pyx_n_s_file, stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItem(kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItem(__pyx_print_kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jbyte(jbyte value) {
    const jbyte neg_one = (jbyte) -1, const_zero = (jbyte) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(jbyte) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(jbyte) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jbyte) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(jbyte) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jbyte) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(jbyte),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jchar(jchar value) {
    const jchar neg_one = (jchar) -1, const_zero = (jchar) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(jchar) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(jchar) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jchar) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(jchar) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jchar) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(jchar),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jshort(jshort value) {
    const jshort neg_one = (jshort) -1, const_zero = (jshort) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(jshort) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(jshort) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jshort) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(jshort) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jshort) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(jshort),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_jlong(jlong value) {
    const jlong neg_one = (jlong) -1, const_zero = (jlong) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(jlong) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(jlong) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jlong) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(jlong) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(jlong) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(jlong),
                                     little, !is_unsigned);
    }
}

/* Declarations */
            #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
            #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = 1.0 / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = 1.0 / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0, -1);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
            #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
            #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = 1.0 / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = 1.0 / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0, -1);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value) {
    const enum NPY_TYPES neg_one = (enum NPY_TYPES) -1, const_zero = (enum NPY_TYPES) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum NPY_TYPES) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum NPY_TYPES) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum NPY_TYPES) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum NPY_TYPES),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
            static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
            static CYTHON_INLINE jbyte __Pyx_PyInt_As_jbyte(PyObject *x) {
    const jbyte neg_one = (jbyte) -1, const_zero = (jbyte) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(jbyte) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(jbyte, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (jbyte) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jbyte) 0;
                case  1: __PYX_VERIFY_RETURN_INT(jbyte, digit, digits[0])
                case 2:
                    if (8 * sizeof(jbyte) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) >= 2 * PyLong_SHIFT) {
                            return (jbyte) (((((jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jbyte) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) >= 3 * PyLong_SHIFT) {
                            return (jbyte) (((((((jbyte)digits[2]) << PyLong_SHIFT) | (jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jbyte) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) >= 4 * PyLong_SHIFT) {
                            return (jbyte) (((((((((jbyte)digits[3]) << PyLong_SHIFT) | (jbyte)digits[2]) << PyLong_SHIFT) | (jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (jbyte) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(jbyte) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jbyte, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jbyte) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jbyte, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jbyte) 0;
                case -1: __PYX_VERIFY_RETURN_INT(jbyte, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(jbyte,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(jbyte) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) - 1 > 2 * PyLong_SHIFT) {
                            return (jbyte) (((jbyte)-1)*(((((jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(jbyte) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) - 1 > 2 * PyLong_SHIFT) {
                            return (jbyte) ((((((jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(jbyte) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) - 1 > 3 * PyLong_SHIFT) {
                            return (jbyte) (((jbyte)-1)*(((((((jbyte)digits[2]) << PyLong_SHIFT) | (jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jbyte) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) - 1 > 3 * PyLong_SHIFT) {
                            return (jbyte) ((((((((jbyte)digits[2]) << PyLong_SHIFT) | (jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(jbyte) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) - 1 > 4 * PyLong_SHIFT) {
                            return (jbyte) (((jbyte)-1)*(((((((((jbyte)digits[3]) << PyLong_SHIFT) | (jbyte)digits[2]) << PyLong_SHIFT) | (jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jbyte) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jbyte, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jbyte) - 1 > 4 * PyLong_SHIFT) {
                            return (jbyte) ((((((((((jbyte)digits[3]) << PyLong_SHIFT) | (jbyte)digits[2]) << PyLong_SHIFT) | (jbyte)digits[1]) << PyLong_SHIFT) | (jbyte)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(jbyte) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jbyte, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jbyte) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jbyte, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            jbyte val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (jbyte) -1;
        }
    } else {
        jbyte val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (jbyte) -1;
        val = __Pyx_PyInt_As_jbyte(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to jbyte");
    return (jbyte) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to jbyte");
    return (jbyte) -1;
}

/* CIntFromPy */
            static CYTHON_INLINE jshort __Pyx_PyInt_As_jshort(PyObject *x) {
    const jshort neg_one = (jshort) -1, const_zero = (jshort) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(jshort) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(jshort, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (jshort) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jshort) 0;
                case  1: __PYX_VERIFY_RETURN_INT(jshort, digit, digits[0])
                case 2:
                    if (8 * sizeof(jshort) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) >= 2 * PyLong_SHIFT) {
                            return (jshort) (((((jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jshort) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) >= 3 * PyLong_SHIFT) {
                            return (jshort) (((((((jshort)digits[2]) << PyLong_SHIFT) | (jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jshort) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) >= 4 * PyLong_SHIFT) {
                            return (jshort) (((((((((jshort)digits[3]) << PyLong_SHIFT) | (jshort)digits[2]) << PyLong_SHIFT) | (jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (jshort) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(jshort) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jshort, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jshort) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jshort, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jshort) 0;
                case -1: __PYX_VERIFY_RETURN_INT(jshort, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(jshort,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(jshort) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) - 1 > 2 * PyLong_SHIFT) {
                            return (jshort) (((jshort)-1)*(((((jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(jshort) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) - 1 > 2 * PyLong_SHIFT) {
                            return (jshort) ((((((jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(jshort) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) - 1 > 3 * PyLong_SHIFT) {
                            return (jshort) (((jshort)-1)*(((((((jshort)digits[2]) << PyLong_SHIFT) | (jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jshort) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) - 1 > 3 * PyLong_SHIFT) {
                            return (jshort) ((((((((jshort)digits[2]) << PyLong_SHIFT) | (jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(jshort) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) - 1 > 4 * PyLong_SHIFT) {
                            return (jshort) (((jshort)-1)*(((((((((jshort)digits[3]) << PyLong_SHIFT) | (jshort)digits[2]) << PyLong_SHIFT) | (jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jshort) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jshort, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jshort) - 1 > 4 * PyLong_SHIFT) {
                            return (jshort) ((((((((((jshort)digits[3]) << PyLong_SHIFT) | (jshort)digits[2]) << PyLong_SHIFT) | (jshort)digits[1]) << PyLong_SHIFT) | (jshort)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(jshort) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jshort, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jshort) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jshort, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            jshort val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (jshort) -1;
        }
    } else {
        jshort val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (jshort) -1;
        val = __Pyx_PyInt_As_jshort(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to jshort");
    return (jshort) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to jshort");
    return (jshort) -1;
}

/* CIntFromPy */
            static CYTHON_INLINE jint __Pyx_PyInt_As_jint(PyObject *x) {
    const jint neg_one = (jint) -1, const_zero = (jint) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(jint) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(jint, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (jint) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jint) 0;
                case  1: __PYX_VERIFY_RETURN_INT(jint, digit, digits[0])
                case 2:
                    if (8 * sizeof(jint) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) >= 2 * PyLong_SHIFT) {
                            return (jint) (((((jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jint) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) >= 3 * PyLong_SHIFT) {
                            return (jint) (((((((jint)digits[2]) << PyLong_SHIFT) | (jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jint) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) >= 4 * PyLong_SHIFT) {
                            return (jint) (((((((((jint)digits[3]) << PyLong_SHIFT) | (jint)digits[2]) << PyLong_SHIFT) | (jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (jint) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(jint) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jint, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jint) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jint, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jint) 0;
                case -1: __PYX_VERIFY_RETURN_INT(jint, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(jint,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(jint) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) - 1 > 2 * PyLong_SHIFT) {
                            return (jint) (((jint)-1)*(((((jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(jint) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) - 1 > 2 * PyLong_SHIFT) {
                            return (jint) ((((((jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(jint) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) - 1 > 3 * PyLong_SHIFT) {
                            return (jint) (((jint)-1)*(((((((jint)digits[2]) << PyLong_SHIFT) | (jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jint) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) - 1 > 3 * PyLong_SHIFT) {
                            return (jint) ((((((((jint)digits[2]) << PyLong_SHIFT) | (jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(jint) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) - 1 > 4 * PyLong_SHIFT) {
                            return (jint) (((jint)-1)*(((((((((jint)digits[3]) << PyLong_SHIFT) | (jint)digits[2]) << PyLong_SHIFT) | (jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jint) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jint, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jint) - 1 > 4 * PyLong_SHIFT) {
                            return (jint) ((((((((((jint)digits[3]) << PyLong_SHIFT) | (jint)digits[2]) << PyLong_SHIFT) | (jint)digits[1]) << PyLong_SHIFT) | (jint)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(jint) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jint, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jint) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jint, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            jint val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (jint) -1;
        }
    } else {
        jint val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (jint) -1;
        val = __Pyx_PyInt_As_jint(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to jint");
    return (jint) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to jint");
    return (jint) -1;
}

/* CIntFromPy */
            static CYTHON_INLINE jlong __Pyx_PyInt_As_jlong(PyObject *x) {
    const jlong neg_one = (jlong) -1, const_zero = (jlong) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(jlong) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(jlong, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (jlong) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jlong) 0;
                case  1: __PYX_VERIFY_RETURN_INT(jlong, digit, digits[0])
                case 2:
                    if (8 * sizeof(jlong) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) >= 2 * PyLong_SHIFT) {
                            return (jlong) (((((jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jlong) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) >= 3 * PyLong_SHIFT) {
                            return (jlong) (((((((jlong)digits[2]) << PyLong_SHIFT) | (jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jlong) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) >= 4 * PyLong_SHIFT) {
                            return (jlong) (((((((((jlong)digits[3]) << PyLong_SHIFT) | (jlong)digits[2]) << PyLong_SHIFT) | (jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (jlong) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(jlong) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jlong, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jlong) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jlong, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (jlong) 0;
                case -1: __PYX_VERIFY_RETURN_INT(jlong, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(jlong,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(jlong) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) - 1 > 2 * PyLong_SHIFT) {
                            return (jlong) (((jlong)-1)*(((((jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(jlong) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) - 1 > 2 * PyLong_SHIFT) {
                            return (jlong) ((((((jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(jlong) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) - 1 > 3 * PyLong_SHIFT) {
                            return (jlong) (((jlong)-1)*(((((((jlong)digits[2]) << PyLong_SHIFT) | (jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(jlong) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) - 1 > 3 * PyLong_SHIFT) {
                            return (jlong) ((((((((jlong)digits[2]) << PyLong_SHIFT) | (jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(jlong) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) - 1 > 4 * PyLong_SHIFT) {
                            return (jlong) (((jlong)-1)*(((((((((jlong)digits[3]) << PyLong_SHIFT) | (jlong)digits[2]) << PyLong_SHIFT) | (jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(jlong) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(jlong, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(jlong) - 1 > 4 * PyLong_SHIFT) {
                            return (jlong) ((((((((((jlong)digits[3]) << PyLong_SHIFT) | (jlong)digits[2]) << PyLong_SHIFT) | (jlong)digits[1]) << PyLong_SHIFT) | (jlong)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(jlong) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(jlong, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(jlong) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(jlong, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            jlong val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (jlong) -1;
        }
    } else {
        jlong val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (jlong) -1;
        val = __Pyx_PyInt_As_jlong(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to jlong");
    return (jlong) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to jlong");
    return (jlong) -1;
}

/* PrintOne */
            #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

/* CIntFromPy */
            static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CheckBinaryVersion */
            static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* ModuleImport */
            #ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

/* TypeImport */
            #ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. Expected %zd, got %zd",
            module_name, class_name, basicsize, size);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s has the wrong size, try recompiling. Expected %zd, got %zd",
            module_name, class_name, basicsize, size);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

/* InitStrings */
            static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if CYTHON_COMPILING_IN_CPYTHON && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
  #else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
  #endif
#else
  res = PyNumber_Int(x);
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
